@@ -4,9 +4,9 @@
 
 -- SYSCONTROL (default) CONFIGURATION FIELDS
 insert into ax_config (config_name,config_fields)
-values ('sys_control','a:4:{s:11:"Lucene_Host";O:11:"configfield":4:{s:4:"name";s:11:"Lucene_Host";s:4:"type";s:4:"text";s:4:"list";s:0:"";s:7:"default";s:0:"";}s:11:"Lucene_Port";O:11:"configfield":4:{s:4:"name";s:11:"Lucene_Port";s:4:"type";s:4:"text";s:4:"list";s:0:"";s:7:"default";s:0:"";}s:20:"Lucene_Site_Indexing";O:11:"configfield":4:{s:4:"name";s:20:"Lucene_Site_Indexing";s:4:"type";s:4:"bool";s:4:"list";s:0:"";s:7:"default";b:0;}s:15:"Max_Latest_News";O:11:"configfield":4:{s:4:"name";s:15:"Max_Latest_News";s:4:"type";s:4:"text";s:4:"list";s:0:"";s:7:"default";s:1:"3";}}');
+values ('sys_control','a:3:{s:15:"Max_Latest_News";O:11:"configfield":4:{s:4:"name";s:15:"Max_Latest_News";s:4:"type";s:4:"text";s:4:"list";s:0:"";s:7:"default";s:1:"3";}s:18:"Search_Engine_Host";O:11:"configfield":4:{s:4:"name";s:18:"Search_Engine_Host";s:4:"type";s:4:"text";s:4:"list";s:0:"";s:7:"default";s:0:"";}s:18:"Search_Engine_Port";O:11:"configfield":4:{s:4:"name";s:18:"Search_Engine_Port";s:4:"type";s:4:"text";s:4:"list";s:0:"";s:7:"default";s:0:"";}}');
 insert into ax_configuration (config_name,config_id,config_set)
-values ('sys_control','default','a:4:{s:11:"Lucene_Host";s:9:"localhost";s:11:"Lucene_Port";s:5:"22222";s:20:"Lucene_Site_Indexing";b:1;s:15:"Max_Latest_News";s:1:"3";}');
+values ('sys_control','default','a:3:{s:15:"Max_Latest_News";s:1:"3";s:18:"Search_Engine_Host";s:9:"localhost";s:18:"Search_Engine_Port";s:5:"22222";}');
 
 -- LANGUAGES
 insert into ax_language (lang_id,lang_desc,char_encoding,direction,is_default,display_order,enabled) values (0,'default','','LTR','t',0,'t');
@@ -79,11 +79,14 @@ insert into ax_organisation (org_id,contactinfo_id,org_name,org_desc,org_contact
 insert into ax_contactinfo (contactinfo_id) values ((select nextval('seq_contactinfo_id')));
 insert into ax_organisation (org_id,contactinfo_id,org_name,org_desc,org_contact,enabled) values (1,(select currval('seq_contactinfo_id')),'Axyl Default',NULL,NULL,'t');
 
--- Pre-defined Axyl users - do not remove 'guest', and make sure
--- you always keep at least one Administrator account.
-insert into ax_user (user_id,password,full_name,user_type,email,address,phone,fax,mobile,last_login,total_logins,limit_logins,enabled,auth_code,org_id) values ('guest',NULL,'Guest User','user',NULL,NULL,NULL,NULL,NULL,'2004-02-25 00:00:00+13',0,0,true,NULL,0);
-insert into ax_user (user_id,password,full_name,user_type,email,address,phone,fax,mobile,last_login,total_logins,limit_logins,enabled,auth_code,org_id) values ('axyl','axyl','Admin User','sys',NULL,NULL,NULL,NULL,NULL,'2004-02-25 00:00:00+13',0,0,true,NULL,1);
-insert into ax_user (user_id,password,full_name,user_type,email,address,phone,fax,mobile,last_login,total_logins,limit_logins,enabled,auth_code,org_id) values ('ed','ed','Ed the Editor','user',NULL,NULL,NULL,NULL,NULL,'2004-02-25 00:00:00+13',0,0,true,NULL,1);
+-- Pre-defined Axyl users - do not remove 'guest', and make sure you always keep at least one Administrator account.
+-- NOTE: these accounts are set to trigger password expiry on first login.
+insert into ax_user (user_id,password,full_name,user_type,total_logins,limit_logins,passwd_forever,passwd_expiry,passwd_failures,locked,enabled,org_id)
+ values ('guest',NULL,'Guest User','user',0,0,true,NULL,0,false,true,0);
+insert into ax_user (user_id,password,full_name,user_type,total_logins,limit_logins,passwd_forever,passwd_expiry,passwd_failures,locked,enabled,org_id)
+ values ('axyl','axyl','Admin User','sys',0,0,false,'2000-01-01 00:00:00',0,false,true,0);
+insert into ax_user (user_id,password,full_name,user_type,total_logins,limit_logins,passwd_forever,passwd_expiry,passwd_failures,locked,enabled,org_id)
+ values ('ed','ed','Ed the Editor','user',0,0,false,'2000-01-01 00:00:00',0,false,true,0);
 
 -- Pre-defined Axyl groups - do not remove any of these.
 insert into ax_group (group_id,group_desc) values (0,'Guest');
