@@ -20,7 +20,7 @@
 /*   Boston, MA  02111-1307  USA                                        */
 /* -------------------------------------------------------------------- */
 /*                                                                      */
-/* Filename:    /var/cm/axyl-tour-12.3.php                                         */
+/* Filename:    /var/cm/axyl-tour-11.3.php                                         */
 /* Author:      Paul Waite                                              */
 /* Description: Php webpage with Content Management Layout.             */
 /*                                                                      */
@@ -36,8 +36,8 @@ include_once("layout-defs.php");
 // -----------------------------------------------------------------------
 // Content Managed Webpage
 // Set these as appropriate:
-$PAGE_TITLE = "Axyl Tour: Section 12.3 - Content Management Options";
-$LAYOUT_ID  = "78_Axyl_Tour:_Section_12.3_-_Content_Management_Options";    // Must be unique
+$PAGE_TITLE = "Axyl Tour: Section 11.3 - Spreadsheet Content";
+$LAYOUT_ID  = "101_Axyl_Tour:_Section_11.3_-_Spreadsheet_Content";    // Must be unique
 $TEMPLATE   = "tour";
 
 // -----------------------------------------------------------------------
