@@ -1,4 +1,4 @@
-#!/bin/sh
+#!/bin/bash
 # Prints out the following virtualhost configuration settings
 # to stdout for the virtualhost specified on command-line:
 #     DocumentRoot
@@ -20,7 +20,7 @@ set -f
 
 THIS=`basename $0`
 
-function usage_exit () {
+usage_exit () {
   echo "usage: $THIS configfile -d DocumentRoot|-s ServerName"
   exit 0
 }
@@ -39,13 +39,10 @@ TMPFILE=`tempfile --prefix vhdata` || true
 cat $CONF | (
   vh=""; dr=""; sn=""; sa=""
   found=0
-  while read line
-  do
-    if [ "$vh" = "" ]
-    then
+  while read line ; do
+    if [ "$vh" = "" ] ; then
       A=`echo $line | perl -ne 'm;^[\s]*<VirtualHost;i && print;'`
-      if [ "$A" != "" ]
-      then
+      if [ "$A" != "" ] ; then
         vh=`echo $line | perl -ne 's/^[\s]*<VirtualHost[\s]*(.+)>.*$/$1/ && print;'`
         vh=`echo $vh | sed -e "s;\*;ASTERISK;g"`
         sn="" ; sa=""; dr=""
@@ -54,36 +51,29 @@ cat $CONF | (
     else
       # Check for ServerName
       A=`echo $line | perl -ne 'm;^[\s]*ServerName;i && print;'`
-      if [ "$A" != "" ]
-      then
+      if [ "$A" != "" ] ; then
         sn=`echo $line | perl -ne 's/^[\s]*ServerName[\s]*(.+).*$/$1/ && print;'`
-        if [ "$MODE" = "-s" ]
-        then
+        if [ "$MODE" = "-s" ] ; then
           [ "$sn" = "$PATTERN" ] && found=1
         fi
       else
         # Check for DocumentRoot
         A=`echo $line | perl -ne 'm;^[\s]*DocumentRoot;i && print;'`
-        if [ "$A" != "" ]
-        then
+        if [ "$A" != "" ] ; then
           dr=`echo $line | perl -ne 's;^[\s]*DocumentRoot[\s]*(.+).*$;$1; && print;'`
-          if [ "$MODE" = "-d" ]
-          then
+          if [ "$MODE" = "-d" ] ; then
             [ "$dr" = "${PATTERN}" -o "$dr" = "${PATTERN}/" ] && found=1
           fi
         else
           # Check for ServerAdmin
           A=`echo $line | perl -ne 'm;^[\s]*ServerAdmin;i && print;'`
-          if [ "$A" != "" ]
-          then
+          if [ "$A" != "" ] ; then
             sa=`echo $line | perl -ne 's;^[\s]*ServerAdmin[\s]*(.+).*$;$1; && print;'`
           else
             # Check for /VirtualHost
             A=`echo $line | perl -ne 'm;^[\s]*</VirtualHost;i && print;'`
-            if [ "$A" != "" ]
-            then
-              if [ $found -eq 1 ]
-              then
+            if [ "$A" != "" ] ; then
+              if [ $found -eq 1 ] ; then
                 [ "$sn" = "" ] && sn=undef
                 [ "$dr" = "" ] && dr=undef
                 [ "$sa" = "" ] && sa=undef
