@@ -14,8 +14,8 @@ mkthisdir () {
    mkdir --verbose --parents $1
  fi
  if [ ! -d $1 ] ; then
-   echo "ERROR: failed to create $1"
-   echo "check permissions, and try again."
+   tell "ERROR: failed to create $1"
+   tell "check permissions, and try again."
    exit 1
  fi
 }
@@ -168,55 +168,112 @@ rewrite_axylconf () {
     exit 1
   fi
   # Plug in the relevant values to the Axyl config..
-  sed -e "s;_AXYL_ADMIN_USER_;$1;" $CONF > $$.tmp && mv $$.tmp $CONF
-  sed -e "s;_AXYL_INSTALLATION_DIR_;$2;" $CONF > $$.tmp && mv $$.tmp $CONF
-  sed -e "s;_AXYL_DATA_DIR_;$3;" $CONF > $$.tmp && mv $$.tmp $CONF
-  sed -e "s;_AXYL_LOGS_DIR_;$4;" $CONF > $$.tmp && mv $$.tmp $CONF
+  wrk=`tempfile -p wrk`
+  sed -e "s;_AXYL_ADMIN_USER_;$1;" $CONF > $wrk && mv $wrk $CONF
+  sed -e "s;_AXYL_INSTALLATION_DIR_;$2;" $CONF > $wrk && mv $wrk $CONF
+  sed -e "s;_AXYL_DATA_DIR_;$3;" $CONF > $wrk && mv $wrk $CONF
+  sed -e "s;_AXYL_LOGS_DIR_;$4;" $CONF > $wrk && mv $wrk $CONF
   if [ -e ${2}/lucene -a "$5" != "null" ] ; then
-    sed -e "s;^LUCENE_PORT=$;LUCENE_PORT=$5;" $CONF > $$.tmp && mv $$.tmp $CONF
+    sed -e "s;^LUCENE_PORT=$;LUCENE_PORT=$5;" $CONF > $wrk && mv $wrk $CONF
   fi
-  rm -f $$.tmp
+  rm -f $wrk
 }
 
 # ...........................................................................
 # If interactive mode then echo message, else dont. We cater for being
 # called from a Debian postinst here, by checking for the telltale
 # var DEBIAN_FRONTEND being set, othersie just a straight shell echo.
-function tell () {
-  if [ ! -z $DEBIAN_FRONTEND ] ; then
+tell () {
+  if [ "$DEBIAN_FRONTEND" ] ; then
     if [ "$DEBIAN_FRONTEND" != "noninteractive" ] ; then
-      echo "$1" >/dev/tty
+      if [ "$1" = "-n" ] ; then
+        shift
+        echo -n $1 >/dev/tty
+      else
+        echo $1 >/dev/tty
+      fi
     fi
   else
     if [ "$MODE" = "interactive" ] ; then
       if [ "$1" = "-n" ] ; then
         shift
-        echo -n "$1"
+        echo -n $1
       else
-        echo "$1"
+        echo $1
       fi
     fi
   fi
 }
 
+# ...........................................................................
+# If interactive mode then readin input, else set ANS=$1 (the default). We
+# cater for being called from a Debian postinst here, by checking for the
+# telltale var DEBIAN_FRONTEND being set. If we are not in an interative
+# mode then we return $1 - which should be the required default.
+getans () {
+  ANS=$1
+  if [ "$DEBIAN_FRONTEND" ] ; then
+    if [ "$DEBIAN_FRONTEND" != "noninteractive" ] ; then
+      read ANS </dev/tty
+    fi
+  else
+    if [ "$MODE" = "interactive" ] ; then
+      read ANS </dev/tty
+    fi
+  fi
+}
+
+# ...........................................................................
+# Asserts that a named logfile exists, owned by the AXUSER. Only
+# the logfile file-name is required. The directory is always assumed
+# to be what $AXYL_LOGS is defined as. If it isn't defined, then
+# /var/log/axyl is used as a failsafe.
+mklogfile() {
+  if [ "$1" != "" ] ; then
+    logfile=$1
+    if [ -z $AXYL_LOGS ] ; then
+      logdir=/var/log/axyl
+    else
+  	  logdir=$AXYL_LOGS
+    fi
+    mkthisdir $logdir
+    
+    # Assert logfile in that directory. NB LOGFILE
+    # is a global variable used by logit()
+    LOGFILE=${logdir}/${logfile}
+    if [ ! -f $LOGFILE ] ; then
+      >$LOGFILE
+    fi
+
+    # Always make sure it is accessible to AXYL apps
+    [ -z $AXUSER ] && AXUSER=axyl
+    chown ${AXUSER}:${AXUSER} $LOGFILE
+    chmod 0664 $LOGFILE
+  fi
+}
+
 # ...........................................................................
 # Log a given message. If a global $LOGFILE variable is available, and
 # exists as a file, then log to that. In any case also log the message
 # to the syslog.
-function logit() {
+logit() {
+  if [ "$SCRIPTNAME" = "" ] ; then
+    SCRIPTNAME=AXYL
+  fi
   if [ "$1" != "" ] ; then
     # Out to logfile
     if [ ! -z $LOGFILE -a -w $LOGFILE ] ; then
-      echo `date +"%a %F %H:%M:%S"` $1 >>$LOGFILE
+      msg="[$$] ${SCRIPTNAME}: $1"
+      echo `date +"%Y/%m/%d %H:%M:%S"` $msg >>$LOGFILE
     fi
     # And to syslog logger
-    echo $1 | logger -t $NAME
+    echo $1 | logger -t $SCRIPTNAME
   fi
 }
 
 # ...........................................................................
 # Variable substitution in a directory tree..
-function sub_vars () {
+sub_vars () {
   A=`find $1 -type f -exec grep -l "$2" {} \;`
   if [ "$A" != "" ]; then
     wrk=`tempfile --prefix sub`
@@ -245,7 +302,7 @@ function sub_vars () {
 #   find_location_of directory bin in /usr/lib/postgresql /usr /usr/local
 #   find_location_of file pg_hba.conf in /etc/postgresql /var/lib/postgresql
 
-function find_location_of () {
+find_location_of () {
   LOC=
   recog_item_type=$1
   recog_item_name=$2
