@@ -95,26 +95,16 @@ function fix_phpini () {
   fi
 }
 
-# Versions of php..
-PHP=php4
-PHPDET=0
-PHP_VERSIONS="php5 php4"
-for phpver in $PHP_VERSIONS ; do
-  if [ -x /usr/bin/${phpver} ] ; then
-    # Check for apache module..
-    if [ -e /usr/lib/${APACHE_NAME}/modules/lib${phpver}.so ] ; then
-      PHP=$phpver
-      PHPDET=1
-      break
-    fi
-  fi
-done
-# Report Php module detection status
+# Report Php module detection status. This will have been done
+# along with Apache detection, in axyl-common.sh.
 if [ $PHPDET -eq 1 ] ; then
-  echo "Php module version was detected: $PHP"
+	echo "Php version was detected as $PHP"
+	if [ $PHP_APACHE_MOD -eq 1 ] ; then
+		echo "Apache Php module seems to be installed also"
+	fi
 else
-  echo "Warning: did not detect Php module installed. Defaulting to $PHP"
-  echo "which may or may not work."
+	echo "Warning: did not detect Php installed. Please install it."
+	exit 6
 fi
 
 # Setup CONF depending on the apache config system..
@@ -152,9 +142,11 @@ then
   fi
 
   # Insert NameVirtualHost directive..
-  A=`perl -n -e "m;^[\s]*NameVirtualHost.*${VHOST_MATCH}; && print;" $CONF`
-  if [ "$A" = "" ] ; then
-    echo "NameVirtualHost $VHOST" >>${CONF_NEW}
+  if [ "$APACHE_CONFSYS" != "ap2" ] ; then
+    A=`perl -n -e "m;^[\s]*NameVirtualHost.*${VHOST_MATCH}; && print;" $CONF`
+    if [ "$A" = "" ] ; then
+      echo "NameVirtualHost $VHOST" >>${CONF_NEW}
+    fi
   fi
 
   # Logging directory. We use an Axyl location, since various distros
@@ -226,25 +218,17 @@ else
 fi
 rm -f $CONF_NEW
 
-# Make sure Apache is configured for PHP..
+# Make sure PHP ini files are ok
 TSTAMP=`date +"%Y%m%d%H%M%S"`
-ETCPHP=/etc/${PHP}
-# Php ini file for Apache processes..
-PHP_INI_APACHE=${ETCPHP}/${APACHE_NAME}/php.ini
-PHP_INI_APACHE_OLD=${PHP_INI_APACHE}.axyl-saved.${TSTAMP}
-# Php ini file for command-line scripts..
-PHP_INI_CLI=${ETCPHP}/cli/php.ini
-PHP_INI_CLI_OLD=${PHP_INI_CLI}.axyl-saved.${TSTAMP}
-# Php global ini file, used in some distros..
-PHP_INI_ETC=/etc/php.ini
-PHP_INI_ETC_OLD=${PHP_INI_ETC}.axyl-saved.${TSTAMP}
 
 # Apache is done via virtual hosts, and the global php.ini is probably
 # best left alone. Uncomment as appropriate for your system..
+# NOTICE: Left commented out as virtualhosts usually do what's required
+#PHP_INI_APACHE_OLD=${PHP_INI_APACHE}.axyl-saved.${TSTAMP}
 #fix_phpini "Apache" $AXYL_HOME $PHP_INI_APACHE $PHP_INI_APACHE_OLD
-#fix_phpini "All" $AXYL_HOME $PHP_INI_ETC $PHP_INI_ETC_OLD
 
 tell "checking your CLI/CGI script php.ini settings.."
+PHP_INI_CLI_OLD=${PHP_INI_CLI}.axyl-saved.${TSTAMP}
 fix_phpini "CLI" $AXYL_HOME $PHP_INI_CLI $PHP_INI_CLI_OLD
 
 # Restart apache..
@@ -253,4 +237,4 @@ if [ $apache_reload -eq 1 ] ; then
   ${AXYL_HOME}/install/prod-apache.sh reload $APACHE_NAME
 fi
 
-# END
\ No newline at end of file
+# END
