@@ -1,4 +1,4 @@
-#!/bin/sh
+#!/bin/bash
 # Install a new Axyl website instance
 # This script will also make sure certain basics are installed
 # such as the /var/lib/axyl area with the Lucene system.
@@ -11,8 +11,7 @@ set -e
 # Acquire the local configuration..
 CONFDIR=/etc/axyl
 CONF=${CONFDIR}/axyl.conf
-if [ ! -f $CONF ]
-then
+if [ ! -f $CONF ] ; then
   echo "Axyl configuration file $CONF not found!"
   exit 2
 else
@@ -26,8 +25,7 @@ fi
 
 # This script requires that Axyl is properly installed. If it isn't
 # then the following vars will not be defined, which is an error.
-if [ "$AXUSER" = "" -o "$AXYL_DATA" = "" ]
-then
+if [ "$AXUSER" = "" -o "$AXYL_DATA" = "" ] ; then
   echo "ERROR: Axyl is not configured properly and one of AXUSER, and/or"
   echo "AXYL_DATA are undefined. Check /etc/axyl/axyl.conf exists and"
   echo "contains these settings. Otherwise, do you need to run script"
@@ -42,13 +40,10 @@ fi
 # 2) Installation name or '__axyl__demo__' provided as $1
 
 INSTALLTYPE=empty
-if [ "$1" != "" ]
-then
-  if [ "$1" = "__axyl__demo__" ]
-  then
+if [ "$1" != "" ] ; then
+  if [ "$1" = "__axyl__demo__" ] ; then
     # Call to install the Axyl demo website..
-    if [ -f ${AXYL_HOME}/db/postgres/axyl_demo.db ]
-    then
+    if [ -f ${AXYL_HOME}/db/postgres/axyl_demo.db ] ; then
       INSTALLTYPE=demo
     else
       echo "error: install axyl-doc package for demo installation"
@@ -62,12 +57,10 @@ fi
 
 echo ""
 echo -n "AXYL "
-if [ "$AXYL_VERSION" != "unknown" ]
-then
+if [ "$AXYL_VERSION" != "unknown" ] ; then
   echo -n "$AXYL_VERSION "
 fi
-if [ "$INSTALLTYPE" = "empty" ]
-then
+if [ "$INSTALLTYPE" = "empty" ] ; then
   echo "- NEW WEBSITE CREATION"
 else
   echo "- DEMO WEBSITE INSTALLATION"
@@ -81,15 +74,9 @@ fi
 mkuser $AXUSER system default any default default "Axyl Administrator"
 
 # Webserver user and group..
-WWWUSER=www-data
-WWWGROUP=www-data
+WWWUSER=$APACHE_USER
+WWWGROUP=$APACHE_GROUP
 WWWADMIN=wwwadmin
-if [ -r ${APACHE_CONFDIR}/httpd.conf ] ; then
-  G=`grep "^Group " ${APACHE_CONFDIR}/httpd.conf | cut -d" " -f2`
-  U=`grep "^User " ${APACHE_CONFDIR}/httpd.conf | cut -d" " -f2`
-  [ "$G" != "" ] && WWWGROUP=$G
-  [ "$U" != "" ] && WWWUSER=$U
-fi
 mkuser $WWWUSER system $WWWGROUP any /var/www default "WWW User"
 
 # Web hosting administration group..
@@ -97,8 +84,7 @@ mkgroup $WWWADMIN any
 
 # +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 # AXYL INSTALLATION LOCATION
-if [ -z $AXYL_HOME ]
-then
+if [ -z $AXYL_HOME ] ; then
   AXYL_HOME=/usr/lib/axyl
   echo ""
   echo "Axyl Location"
@@ -112,11 +98,9 @@ fi
 
 # +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 # INSTALLATION NAME
-if [ -z $INST_NAME ]
-then
+if [ -z $INST_NAME ] ; then
   echo ""
-  if [ "$INSTALLTYPE" = "demo" ]
-  then
+  if [ "$INSTALLTYPE" = "demo" ] ; then
     INST_NAME=axyl_demo
     echo "Axyl Demo Website Installation Name"
     echo "Enter a name for this Axyl demo website installation. The name "
@@ -140,8 +124,7 @@ then
     echo -n "New Axyl website installation name (no spaces or hyphens) :"
   fi
   read ANS
-  if [ "$ANS" != "" ]
-  then
+  if [ "$ANS" != "" ] ; then
     INST_NAME=$ANS
   else
     echo "A name is mandatory. Aborting.."
@@ -157,8 +140,7 @@ fi
 # with Axyl, and stores Lucene configs, and indexes here. The
 # Lucene indexes can get big, so symlink as necessary to manage
 # that aspect of the operation.
-if [ -z $AXYL_DATA ]
-then
+if [ -z $AXYL_DATA ] ; then
   AXYL_DATA=/var/lib/axyl
   echo ""
   echo "Axyl Data Area"
@@ -178,8 +160,7 @@ find ${AXYL_DATA} -type d -exec chmod 6755 {} \;
 
 # +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 # AXYL LOGGING AREA
-if [ -d /var/log ]
-then
+if [ -d /var/log ] ; then
   AXYL_LOGS=/var/log/axyl
 else
   AXYL_LOGS=${AXYL_DATA}/log
@@ -232,21 +213,18 @@ read ANS
 
 # Database user password..
 PASSOK=0
-while [ $PASSOK -eq 0 ]
-do
+while [ $PASSOK -eq 0 ] ; do
   DBPASSWD="none"
   echo ""
   echo "Enter a password for this user or just hit ENTER to indicate that no"
   echo "password is required."
   echo -n "Database connect password: [$DBPASSWD] :"
   read ANS
-  if [ "$ANS" != "" ]
-  then
+  if [ "$ANS" != "" ] ; then
     DBPASSWD=$ANS
     echo -n "Confirm password :"
     read ANS
-    if [ "$ANS" = "$DBPASSWD" ]
-    then
+    if [ "$ANS" = "$DBPASSWD" ] ; then
       PASSOK=1
     else
       echo ""
@@ -268,11 +246,11 @@ read ANS
 [ "$ANS" != "" ] && DBHOST=$ANS
 
 DBPORT=5432
-if [ "$DBHOST" != "direct" ]
-then
+if [ "$DBHOST" != "direct" ] ; then
   echo ""
   echo "Enter the port that the remote database server is listening on. For"
-  echo "Postgresql, the default port of $DBPORT will probably be right."
+  echo "Postgresql, the default port of $DBPORT will probably be right, unless"
+  echo "you are running a multi-version cluster."
   echo -n "Remote database server port: [$DBPORT] :"
   read ANS
   [ "$ANS" != "" ] && DBPORT=$ANS
@@ -280,8 +258,7 @@ fi
 
 # Axyl Metadata Extension
 META=n
-if [ "$INSTALLTYPE" = "empty" ]
-then
+if [ "$INSTALLTYPE" = "empty" ] ; then
   echo ""
   echo "Axyl can be created with fully-defined Meta Data Schemas, namely"
   echo "the Dublin Core, AGLS, and NZGLS definitions. This is appropriate if"
@@ -295,8 +272,7 @@ fi
 
 # Axyl Microsites Extension
 MICRO=n
-if [ "$INSTALLTYPE" = "empty" ]
-then
+if [ "$INSTALLTYPE" = "empty" ] ; then
   echo ""
   echo "Axyl can be created with the ability to create and manage 'microsites'"
   echo "which make use of Axyl themeing. You can create simple content-managed"
@@ -325,12 +301,10 @@ dupedir ${AXYL_HOME}/www ${WWW_PATH}
 # Axyl library images and javascript. These need
 # to be actually in the website hiearchy..
 mkthisdir ${WWW_PATH}/lib
-if [ ! -L ${WWW_PATH}/lib/img ]
-then
+if [ ! -L ${WWW_PATH}/lib/img ] ; then
   ln -s ${AXYL_HOME}/lib/img ${WWW_PATH}/lib/img
 fi
-if [ ! -L ${WWW_PATH}/lib/js ]
-then
+if [ ! -L ${WWW_PATH}/lib/js ] ; then
   ln -s ${AXYL_HOME}/lib/js ${WWW_PATH}/lib/js
 fi
 
@@ -338,16 +312,14 @@ fi
 # maintenance scripts with ones which are compatible with other
 # databases. The standard scripts use the Axyl maintainer-defs.php
 # module which is currently not DB-independent.
-if [ $DBTYPE -ne 1 ]
-then
+if [ $DBTYPE -ne 1 ] ; then
   cp ${AXYL_HOME}/compat/www/*.php ${WWW_PATH}
 fi
 
 # If demo, then copy across the demo content. This includes
 # the managed-content pages, and the catalog images which are
 # referred-to by the demo database content layouts.
-if [ "$INSTALLTYPE" = "demo" ]
-then
+if [ "$INSTALLTYPE" = "demo" ] ; then
   find ${AXYL_HOME}/demo/var/catalog -type f -exec cp {} ${WWW_PATH}/var/catalog/ \;
   find ${AXYL_HOME}/demo/var/cm -type f -exec cp {} ${WWW_PATH}/var/cm/ \;
 fi
@@ -377,11 +349,10 @@ echo "Do you want to create a virtual host for apache?"
 echo -n "Enter Y or N [Y] :"
 read ANS
 [ "$ANS" = "" ] && ANS="y"
-if [ "$ANS" = "y" -o "$ANS" = "Y" -o "$ANS" = "yes" ]
-then
+if [ "$ANS" = "y" -o "$ANS" = "Y" -o "$ANS" = "yes" ] ; then
   CONFIG_APACHE=yes
   CONF=${APACHE_CONFDIR}/httpd.conf
-  TMP=/tmp/$$
+  TMP=`tempfile -p CREAX`
 
   echo ""
   echo "Ok, you now have to specify the IP address, or hostname of the"
@@ -400,7 +371,11 @@ then
   fi
   
   DISP="Everything on Port 80"
-  VHOST="*:80"
+  if [ "$APACHE_NAME" = "apache" ] ; then
+    VHOST="*:80"
+  else
+    VHOST="*"
+  fi
   set -f
   echo -n "Enter IP or hostname for this virtual host [${DISP}] :"
   read ANS
@@ -427,9 +402,29 @@ then
   read ANS
   [ "$ANS" != "" ] && VSERVERNAME=$ANS
 
-  # Admin e-mail address
-  ADMIN_EMAIL="webmaster@"
-  ADMIN_EMAIL="${ADMIN_EMAIL}${VSERVERNAME}"
+  # Admin e-mail address, try a few options in order of preference
+  if [ "$DEBEMAIL" != "" ] ; then
+    email=$DEBEMAIL
+  else
+  	# email name
+  	if [ "$SUDO_USER" != "" ] ; then
+      email_name=$SUDO_USER
+  	elif [ "$USER" != "" ] ; then
+      email_name=$USER
+    elif [ "$LOGNAME" != "" ] ; then
+      email_name=$LOGNAME
+  	else
+      email_name=webmaster
+    fi
+  	# mail domain
+    if [ -r /etc/mailname ] ; then
+      email_domain=`cat /etc/mailname`
+    else
+      email_domain=$VSERVERNAME
+    fi
+    email="${email_name}@${email_domain}"
+  fi
+  ADMIN_EMAIL="$email"
   echo -n "Enter the admin e-mail address [${ADMIN_EMAIL}] :"
   read ANS
   [ "$ANS" != "" ] && ADMIN_EMAIL=$ANS
@@ -468,10 +463,8 @@ fi
 # standard Axyl Luceneserver. A single Luceneserver can service numerous
 # domains (websites).
 # We only do anything if the axyl-lucene package is installed...
-if [ -e ${AXYL_HOME}/lucene/servers ]
-then
-  if [ ! -f ${AXYL_DATA}/lucene/servers/axyl/etc/application/${INST_NAME}.properties ]
-  then
+if [ -e ${AXYL_HOME}/lucene/servers ] ; then
+  if [ ! -f ${AXYL_DATA}/lucene/servers/axyl/etc/application/${INST_NAME}.properties ] ; then
     echo ""
     echo "LuceneServer Domain"
     echo "Even if you have no large-scale document indexing requirement"
@@ -483,15 +476,13 @@ then
     echo -n "Set up a Luceneserver Domain for $INST_NAME? Y or N [Y] :"
     read ANS
     [ "$ANS" = "" ] && ANS="y"
-    if [ "$ANS" = "y" -o "$ANS" = "Y" -o "$ANS" = "yes" ]
-    then
+    if [ "$ANS" = "y" -o "$ANS" = "Y" -o "$ANS" = "yes" ] ; then
       PROPS=${AXYL_DATA}/lucene/servers/axyl/etc/application/${INST_NAME}.properties
       cp ${AXYL_HOME}/lucene/servers/axyl/etc/application/axyl.properties ${PROPS}
       sed -e "s;_LU_DOMAIN_;$INST_NAME;g" ${PROPS} > $$.tmp && mv $$.tmp ${PROPS}
       echo "Lucene domain for $INST_NAME installed."
       # Make sure Axyl lucene started..
-      if [ -x /etc/init.d/axyl-lucene ]
-      then
+      if [ -x /etc/init.d/axyl-lucene ] ; then
         /etc/init.d/axyl-lucene start
       fi
     fi
@@ -517,8 +508,7 @@ chmod 0664 ${WWW_PATH}/application.xml
 
 # Customise Apache if required..
 echo ""
-if [ "$CONFIG_APACHE" = "yes" ]
-then
+if [ "$CONFIG_APACHE" = "yes" ] ; then
   echo "Configuring Apache"
   set -f
   ${AXYL_HOME}/install/config-apache.sh $VHOST $VSERVERNAME $ADMIN_EMAIL $DOCROOT $MAXMEM $MAXUPLOAD
@@ -529,7 +519,9 @@ fi
 # Update Axyl websites database
 echo ""
 echo "updating Axyl website database.."
+set -f
 ${AXYL_HOME}/install/register-axyl-website.sh $INST_NAME $DBTYPE $DBNAME $DBUSER $DBPASSWD $DBHOST $DBPORT $DOCROOT $VHOST $VSERVERNAME $ADMIN_EMAIL
+set +f
 
 # +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 # PERMISSIONS
@@ -542,12 +534,10 @@ ${AXYL_HOME}/install/set-axyl-website-perms.sh
 # FINISHED
 echo ""
 echo "Axyl has been installed."
-if [ "$DBTYPE" -eq 1 ]
-then
+if [ "$DBTYPE" -eq 1 ] ; then
   echo "The Postgres database '$DBNAME' has been created, owned by '$DBUSER'"
   echo -n "and populated with "
-  if [ "$INSTALLTYPE" = "demo" ]
-  then
+  if [ "$INSTALLTYPE" = "demo" ] ; then
     echo "all data required for the demo website."
   else
     echo "only the basic Axyl core data, ready for you"
@@ -564,13 +554,14 @@ else
   echo "Please ensure that your database is set up such that user '$DBUSER'"
   echo "can connect to it."
 fi
+
 echo ""
-if [ "$CONFIG_APACHE" = "yes" ]
-then
+if [ "$CONFIG_APACHE" = "yes" ] ; then
   echo "Apache was configured with server name '${VSERVERNAME}'"
   echo "however you will now have to set up your DNS or /etc/hosts file"
   echo "appropriately to resolve this for visiting web clients."
 fi
+
 echo ""
 echo "The Axyl configuration is in your 'application.xml' in the website"
 echo "root directory '${WWW_PATH}'. To maintain this the"
@@ -587,4 +578,4 @@ echo "always kept as non-writeable to the web-server."
 echo ""
 echo "The Axyl Team"
 
-# END
+# END
\ No newline at end of file
