@@ -12,7 +12,7 @@
 set -e
 
 # Name of this script
-THIS=`basename $0`
+SCRIPTNAME=${0##*/}
 
 # Get common funcs and config vars etc.
 # Acquire the local configuration..
@@ -40,7 +40,7 @@ fi
 
 # Add a docroot to our list, avoiding duplicates, and
 # ensuring the docroot physically exists on filesystem..
-function add_docroot () {
+add_docroot () {
   if [ "$1" != "" ] ; then
     X=`echo $DOCROOTS | perl -ne "m;^.*[\s]{1,1}$1[\s]{1,1}.*$; && print;"`
     if [ "$X" = "" ] ; then
@@ -53,7 +53,7 @@ function add_docroot () {
 
 # Scan the file given in $1 for virtualhosts. Add those
 # docroots found to our list..
-function scan_virtualhosts () {
+scan_virtualhosts () {
   if [ "$1" != "" ] ; then
     candidates=`perl -ne 'm;^[\s]*DocumentRoot ;i && s/^\s+DocumentRoot // && print;' $1`
     if [ "$candidates" != "" ] ; then
@@ -68,7 +68,7 @@ function scan_virtualhosts () {
 # Scan all apache configuration files for a virtualhost
 # identified by docroot in $1. Sets $vhdata if found.
 vhdata=""
-function scan_conffiles () {
+scan_conffiles () {
   vhdata=""
   if [ "$1" != "" ] ; then
     DR=$1
