@@ -102,7 +102,9 @@ if [ -x ${AXYL_HOME}/install/unregister-axyl-website.sh ] ; then
   AXYL_DB=${AXYL_SYSTEM}/axyl_websites.csv
   ${AXYL_HOME}/install/unregister-axyl-website.sh $APP_NAME
   VHOST=`echo $VHOST | sed -e "s;ASTERISK;*;g"`
+  set -f
   echo "$APP_NAME,$DBTYPE,$DBNAME,$DBUSER,$DBPASSWD,$DBHOST,$DBPORT,$DOCROOT,$VHOST,$VSERVERNAME,$ADMIN_EMAIL" >>${AXYL_DB}
+  set +f
 fi
 
 # +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
