@@ -1,4 +1,4 @@
-#! /bin/sh
+#! /bin/bash
 # Set up Axyl
 # This script is intended for use when you have grabbed a CVS copy
 # of the Axyl system, and need to set up the config file(s) as if
@@ -24,18 +24,36 @@ then
   exit 0
 fi
 
-# Get common funcs etc..
-if [ -x ./axyl-common.sh ]
+# Defaults..
+AXUSER=
+AXYL_HOME=
+AXYL_DATA=
+AXYL_LOGS=
+LUCENE_PORT=
+AXYL_VERSION="unknown"
+
+CONFDIR=/etc/axyl
+CONF=${CONFDIR}/axyl.conf
+if [ -f $CONF ]
 then
-  . ./axyl-common.sh
-else
-  echo "ERROR: axyl-common.sh not found or not executable. You must"
-  echo "execute this from within the Axyl 'install' directory, or"
-  echo "check file permissions."
-  exit 1
+  . $CONF
+  # But if they are invalid dirs, then nullify them again..
+  [ ! -d $AXYL_HOME ] && AXYL_HOME=
+  [ ! -d $AXYL_DATA ] && AXYL_DATA=
+  [ ! -d $AXYL_LOGS ] && AXYL_LOGS=
 fi
 
-if [ "${AXYL_HOME}" != "" ]
+VERSIONFILE=${CONFDIR}/axyl.version
+if [ -f $VERSIONFILE ]
+then
+  AXYL_VERSION=`cat $VERSIONFILE`
+  if [ "$AXYL_VERSION" = "" ]
+  then
+    AXYL_VERSION="unknown"
+  fi
+fi
+
+if [ "$AXYL_HOME" != "" ]
 then
   echo "Axyl seems to be already installed."
   echo "The config file ($CONF) says it is in $AXYL_HOME"
@@ -49,13 +67,13 @@ then
   fi
 
   # Nullify old config file. Definitions come from
-  # the include of axyl-common.sh above..
+  # the include of axyl-common.sh
   if [ -d $CONFDIR ]
   then
     rm -f $CONF
   fi
   AXYL_HOME=
-  AXYL_DATA=/var/lib/axyl
+  AXYL_DATA=
   AXYL_LOGS=
 fi
 
@@ -77,6 +95,47 @@ echo -n "[$AXYL_HOME] :"
 read ANS
 [ "$ANS" != "" ] && AXYL_HOME=$ANS
 
+# +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+# Get common funcs etc..
+if [ -e ./axyl-common-funcs.sh ]
+then
+  . ./axyl-common-funcs.sh
+else
+  echo "ERROR: axyl-common-funcs.sh not found or not executable. You must"
+  echo "execute this from within the Axyl 'install' directory, or else"
+  echo "fix file permissions."
+  exit 1
+fi
+
+# +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+# Detect Apache and Php settings
+# These two detection scripts set up environment vars for use by
+# other scripts.
+if [ "$AXYL_HOME" != "" ] ; then
+
+	# Detect the APACHE configuration settings. Sets up the following vars:
+	# APACHE_NAME     # Name of the apache instance eg. 'apache2'
+	# APACHE_CONFDIR  # Configuration files live here
+	# APACHE_CONFSYS  # Type of config system: 'ap2', 'confd' or 'httpd'
+	# APACHE_CONF     # Path to main apache configuration file
+	# APACHE_USER     # User apache runs as eg. 'www-data'
+	# APACHE_GROUP    # Group apache runs under eg. 'www-data'
+	if [ -f ${AXYL_HOME}/install/detect-apache.sh ] ; then
+		. ${AXYL_HOME}/install/detect-apache.sh
+	fi
+
+	# Detect the PHP configuration settings. Sets up the following vars:
+	# PHP             # The 'preferred' version we found
+	# PHP_BIN         # The path to the php binary itself
+	# PHP_INI_APACHE  # Path to Apache ini file
+	# PHP_INI_CLI     # Path to CLI ini file
+	# PHPDET          # Flag: =1 if we found at least one Php
+	# PHP_APACHE_MOD  # Flag: =1 if apache module is installed
+	if [ -f ${AXYL_HOME}/install/detect-php.sh ] ; then
+  		. ${AXYL_HOME}/install/detect-php.sh
+	fi
+fi
+
 # +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 # USERS AND GROUPS
 
@@ -166,36 +225,6 @@ then
   fi
 fi
 
-# +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-# HTMLAREA acquisition
-# The htmlarea javascript package is required for content-managed
-# HTML wysiwyg editing in Axyl. It is acquired from the relevant
-# CVS repository on SourceForge here, as an export.
-if [ ! -f ${AXYL_HOME}/lib/js/htmlarea/htmlarea.js ]
-then
-  echo ""
-  echo "HTMLArea is a required Axyl package for wysiwyg content"
-  echo "editing. It is acquired via CVS export from SourceForge. Do"
-  echo -n "you want to acquire it now (recommended)? [Y] :"
-  read ANS
-  if [ "$ANS" = "y" -o "$ANS" = "Y" -o "$ANS" = "" ]
-  then
-    cd ${AXYL_HOME}/install
-    ./get-htmlarea.sh
-  fi
-fi
-# Confirm end result..
-echo ""
-if [ -f ${AXYL_HOME}/lib/js/htmlarea/htmlarea.js ]
-then
-  echo "HTMLArea is installed in ${AXYL_HOME}/lib/js/htmlarea."
-else
-  echo "HTMLArea is NOT installed in ${AXYL_HOME}/lib/js/htmlarea."
-  echo "You will not have wysiwyg content editing facilities until"
-  echo "such time as it is. See ${AXYL_HOME}/install/get-htmlarea.sh"
-  echo "which is provided for this purpose."
-fi
-
 # +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 # FINISH UP
 # Confirm directly from the configuration file itself..
