@@ -1,4 +1,4 @@
-#!/bin/sh
+#!/bin/bash
 # Un-register an Axyl website from our CSV database
 # Paul Waite
 #
@@ -9,8 +9,7 @@ set -e
 # Acquire the local configuration..
 CONFDIR=/etc/axyl
 CONF=${CONFDIR}/axyl.conf
-if [ ! -f $CONF ]
-then
+if [ ! -f $CONF ] ; then
   echo "Axyl configuration file $CONF not found!"
   exit 2
 else
@@ -24,8 +23,7 @@ fi
 
 # This script requires that Axyl is properly installed. If it isn't
 # then the following vars will not be defined, which is an error.
-if [ "$AXUSER" = "" -o "$AXYL_DATA" = "" ]
-then
+if [ "$AXUSER" = "" -o "$AXYL_DATA" = "" ] ; then
   echo "ERROR: Axyl is not configured properly and one of AXUSER, and/or"
   echo "AXYL_DATA are undefined. Check /etc/axyl/axyl.conf exists and"
   echo "contains these settings. Otherwise, do you need to run script"
@@ -48,8 +46,7 @@ while [ $# -gt 0 ] ; do
   shift
 done
 
-if [ "$APP_NAME" = "" ]
-then
+if [ "$APP_NAME" = "" ] ; then
   echo "ERROR: unregister-axyl-website.sh: parameters."
   echo "usage: unregister-axyl-website.sh app_name"
   exit 0
@@ -59,13 +56,11 @@ fi
 # Update Axyl websites database
 AXYL_SYSTEM=${AXYL_DATA}/system
 AXYL_DB=${AXYL_SYSTEM}/axyl_websites.csv
-mkaxyldir ${AXYL_SYSTEM}
-if [ -d $AXYL_SYSTEM ]
-then
+mkthisdir ${AXYL_SYSTEM}
+if [ -d $AXYL_SYSTEM ] ; then
   chown ${AXUSER}:${AXUSER} ${AXYL_SYSTEM}
   chmod 0775 ${AXYL_SYSTEM}
-  if [ ! -f $AXYL_DB ]
-  then
+  if [ ! -f $AXYL_DB ] ; then
     echo "# Axyl Website Database" >${AXYL_DB}
     echo "# APPNAME,DBTYPE,DBNAME,DBUSER,DBPASSWD,DBHOST,DBPORT,DOCROOT,VHOST,SERVERNAME,ADMIN_EMAIL" >>${AXYL_DB}
     chown $AXUSER:$AXUSER ${AXYL_DB}
