@@ -321,9 +321,9 @@ class blockeditor extends RenderableObject {
     global $colourCombo, $tstylesCombo, $langsCombo;
 
     /** HTMLArea form element */
-    include_once("htmlarea-defs.php");
+    include_once("wysiwyg-editor-defs.php");
     // Define which plugins to load..
-    htmlarea_plugins("ContextMenu,CSS,TableOperations,ListType,CharacterMap");
+    add_wysiwyg_plugins("ContextMenu,CSS,TableOperations,ListType,CharacterMap");
 
     // This is a Wysiwyg block. If it is new, then we will need to
     // create its single associated blocklet..
@@ -1257,7 +1257,7 @@ class blockeditor extends RenderableObject {
       } while ($Qimg->get_next());
     }
     // Add this catalog item as an IMAGE tag..
-    $img_addbtn = $gen_addbtn;
+    $img_addbtn = clone($gen_addbtn);
     $img_addbtn->name = "_add_img";
     $img_addbtn->settitle("Add image to content");
     switch ($this->block->block_type) {
@@ -1387,7 +1387,7 @@ class blockeditor extends RenderableObject {
       } while ($Qdoc->get_next());
     }
     // Add this catalog item as a DOCUMENT tag..
-    $doc_addbtn = $gen_addbtn;
+    $doc_addbtn = clone($gen_addbtn);
     $doc_addbtn->name = "_add_doc";
     $doc_addbtn->settitle("Add document to content");
     switch ($this->block->block_type) {
@@ -1478,7 +1478,7 @@ class blockeditor extends RenderableObject {
       } while ($QMM->get_next());
     }
     // Add this catalog item as a MEDIA  tag..
-    $mm_addbtn = $gen_addbtn;
+    $mm_addbtn = clone($gen_addbtn);
     $mm_addbtn->name = "_add_mm";
     $mm_addbtn->settitle("Add media to content");
     switch ($this->block->block_type) {
@@ -1588,7 +1588,7 @@ class blockeditor extends RenderableObject {
       } while ($Qdata->get_next());
     }
     // Add this catalog item as a DATA  tag..
-    $dat_addbtn = $gen_addbtn;
+    $dat_addbtn = clone($gen_addbtn);
     $dat_addbtn->name = "_add_dat";
     $dat_addbtn->settitle("Add data query to content");
     switch ($this->block->block_type) {
