@@ -32,30 +32,71 @@ include_once("search-query-defs.php");
 /** Filesystem access */
 include_once("file-defs.php");
 
+// Definitions
+define("STD_THUMB_WIDTH",  "90");
+define("STD_THUMB_HEIGHT", "68");
+
+// -----------------------------------------------------------------------
+/**
+* A class which contains additional versions of the physical media associated
+* with an item. If the main item is an image, for example, it may also
+* need to have a version of it named 'thumb' which is the thumbnail
+* version of the main image. A movie catalogitem might need a short clip
+* version of itself called 'movieclip' etc.
+* @package catalog
+*/
+class catalogitem_version {
+  var $filepath = "";           // Website URL path to the item (with leading '/')
+  var $physicalpath = "";       // Full physical path of image on the filesystem
+  var $fileexists = false;      // True if file exists at filepath
+  var $width = 0;               // Pixel width of this item
+  var $height = 0;              // Pixel height of this item
+  
+  function catalogitem_version() { }
+  function set_paths($physicalpath, $filepath) {
+    $this->physicalpath = $physicalpath;
+    $this->filepath = $filepath;
+  }
+  function set_size($width, $height) {
+    $this->width = $width;
+    $this->height = $height;
+  }
+} // catalogitem_version class
+
 // -----------------------------------------------------------------------
 /**
 * A class which encpasulates an item which can be in the catalog.
 * @package catalog
 */
 class catalogitem extends RenderableObject {
-  var $cat_id;               // Unique catalog record key for the catalog item
-  var $cat_name = "";        // Name of this catalog item
-  var $cat_desc = "";        // Full description of catalog item
-  var $mime_type = "";       // Mime-type of catalog item
-  var $mime_category = "";   // Mime category eg: document, movie, audio etc.
-  var $keywords = "";        // Any keywords associated with it
-  var $category = "";        // Optional user-defined category for item
-  var $filesize = "";        // Size of catalog item in bytes
-  var $filepath = "";        // Website URL path to the item (with leading '/')
-  var $physicalpath = "";    // Full physical path on the filesystem
-  var $fileexists = false;   // True if file exists at filepath
-  var $width = 0;            // Pixel width of this item
-  var $height = 0;           // Pixel height of this item
-  var $uploaded_ts = 0;      // Unix timestamp of datetime item was added to catalog
-  var $uploaded = "";        // Datetime uploaded, NICE_FULLDATETIME format
-  var $errmsg = "";          // Contains error message if invalid
-  var $valid = false;        // True if item was retreived successfully
-  var $newcat = false;       // True if we just created this story
+  var $cat_id;                  // Unique catalog record key for the catalog item
+  var $cat_name = "";           // Name of this catalog item
+  var $cat_desc = "";           // Full description of catalog item
+  var $mime_type = "";          // Mime-type of catalog item
+  var $mime_category = "";      // Mime category eg: document, movie, audio etc.
+  var $keywords = "";           // Any keywords associated with it
+  var $category = "";           // Optional user-defined category for item
+  var $filesize = "";           // Size of catalog item in bytes
+  var $filepath = "";           // Website URL path to the item (with leading '/')
+  var $physicalpath = "";       // Full physical path of image on the filesystem
+  var $fileexists = false;      // True if file exists at filepath
+  var $versions = array();      // Other versions of this catalog item
+  var $width = 0;               // Pixel width of this item
+  var $height = 0;              // Pixel height of this item
+  var $uploaded_ts = 0;         // Unix timestamp of datetime item was added to catalog
+  var $uploaded = "";           // Datetime uploaded, NICE_FULLDATETIME format
+  var $errmsg = "";             // Contains error message if invalid
+  var $valid = false;           // True if item was retreived successfully
+  var $newcat = false;          // True if we just created this story
+
+  // Allowed versions for a catalog item
+  var $AllowedVersions = array(
+    "thumb"     => "image|90|68",
+    "medium"    => "image|160|120",
+    "flash"     => "image|320|240",
+    "movieclip" => "movie|320|240",
+    "soundclip" => "audio||"
+    );
 
   // .....................................................................
   /** Constructor
@@ -98,20 +139,66 @@ class catalogitem extends RenderableObject {
         $this->height        = $catQ->field("height");
         $this->uploaded_ts   = datetime_to_timestamp($catQ->field("upload_timestamp"));
         $this->uploaded      = timestamp_to_displaydate(NICE_FULLDATETIME, $this->uploaded_ts);
-        // Update status of physical file..
-        $this->physicalpath = $RESPONSE->site_docroot . $this->filepath;
-        $this->fileexists = file_exists($this->physicalpath);
+        $this->physicalpath  = $RESPONSE->site_docroot . $this->filepath;
+        $this->fileexists    = file_exists($this->physicalpath);
+
+        // Populate version details, if any versions exist.
+        $this->locate_versions();
         $res = true;
         $this->newcat = false;
       }
-      else $this->errmsg = "No record of catalog item: $this->cat_id";
+      else {
+        $this->errmsg = "No record of catalog item: $this->cat_id";
+      }
+    }
+    else {
+      $this->errmsg = "No catalog ID was given";
     }
-    else $this->errmsg = "No catalog ID was given";
     // Did we succeed..?
     $this->valid = $res;
     return $res;
   } // get
   // .....................................................................
+  /**
+   * Go and look for possible versions out there on disk. Versions are
+   * additional versions of the main media, for example 'thumb' for an
+   * image thumbnail version. These are just file-named after the main
+   * file, but with the version name (eg. 'thumb') added into the name.
+   * If found, then we insert the version in our local array.
+   */
+  function locate_versions() {
+    global $RESPONSE;
+    $dir  = dirname($this->filepath);
+    $name = get_file_stem($this->filepath);
+    $extn = get_file_extn($this->filepath);
+    $this->versions = array();
+    if (count($this->AllowedVersions) > 0) {
+      foreach ($this->AllowedVersions as $ver => $info) {
+        debugbr("AllowedVersion: $ver => $info");
+      }
+    }
+    else {
+      debugbr("AllowedVersions empty!");
+    }
+    foreach ($this->AllowedVersions as $version => $versioninfo) {
+      $verbits = explode("|", $versioninfo);
+      $mime_category = $verbits[0];
+      if ($this->mime_category == $mime_category) {
+        // Derive location details by naming standard
+        $verpath = "$dir/$name.$version.$extn";
+        $verphys = $RESPONSE->site_docroot . $verpath;
+        if (file_exists($verphys)) {
+          $ver = new catalogitem_version();
+          $ver->set_paths($verphys, $verpath);
+          $ver->fileexists = true;
+          $ver->width = $verbits[1];
+          $ver->height = $verbits[2];
+          $this->versions[$version] = $ver;
+        }
+      }
+    } // foreach
+  } // get_versions
+  // .....................................................................
   /** Save current catalog item definition to the database. Inserts
   * if brand new, else performs an update.
   */
@@ -164,37 +251,48 @@ class catalogitem extends RenderableObject {
   */
   function delete($deletefile=true) {
     global $RESPONSE, $IMAGESDIR;
-    $deleted = false;
-    $err = false;
+    $ok = true;
     if ($this->cat_id && $this->valid) {
-      // First, deal to the physical file..
-      if ($deletefile) {
-        if (file_exists($this->physicalpath)) {
-          // Avoid deleting images which are part of the standard issue..
-          if (substr($this->filepath, 0, strlen($IMAGESDIR)) != $IMAGESDIR) {
-            if (!is_writeable($this->physicalpath) || !unlink($this->physicalpath)) {
-              $err = true;
+      // Avoid deleting images which are part of the standard issue..
+      if (substr($this->filepath, 0, strlen($IMAGESDIR)) != $IMAGESDIR) {
+
+        // Now deal to the physical file..
+        if ($deletefile) {
+          if (file_exists($this->physicalpath)) {
+            $ok = (is_writeable($this->physicalpath) && unlink($this->physicalpath));
+            if ($ok) {
+              $this->delete_all_versions();
             }
           }
         }
-      }
-      // Delete the database record now..
-      if (!$err) {
-        $dcat = new dbdelete("ax_catalog");
-        $dcat->where("cat_id=$this->cat_id");
-        $res = $dcat->execute();
-        if ($res) {
-          // Remove from search engine index..
-          $this->unindex();
-          $this->valid = false;
-          $deleted = true;
+
+        // Delete the database record
+        if ($ok) {
+          $dcat = new dbdelete("ax_catalog");
+          $dcat->where("cat_id=$this->cat_id");
+          $ok = $dcat->execute();
+          if ($ok) {
+            // Remove from search engine index..
+            $this->unindex();
+            $this->valid = false;
+          }
         }
       }
     }
-    return $deleted;
+    return $ok;
   }  // delete
   // .....................................................................
   /**
+  * Remove the catalog item from the database only. This is just a wrapper
+  * for a call to delete() with the boolean set false for deleting the
+  * physical file.
+  * @return boolean True if the operation succeeded, else false.
+  */
+  function detach() {
+    return $this->delete(false);
+  }  // detach
+  // .....................................................................
+  /**
   * Index this catalog item to the search engine.
   * If it exists already, index entry for this item is replaced.
   */
@@ -208,6 +306,8 @@ class catalogitem extends RenderableObject {
       $I->define_field("mimecat", "Text", STORED);
       $I->define_field("uploaded", "Date", STORED);
       $I->define_field("path", "text", STORED);
+      $I->define_field("width", "text", STORED);
+      $I->define_field("height", "text", STORED);
       // Index the fields..
       $I->index_field("Id",       "CAT_" . $this->cat_id);
       $I->index_field("keywords", $this->keywords);
@@ -216,6 +316,8 @@ class catalogitem extends RenderableObject {
       $I->index_field("mimecat",  $this->mime_category);
       $I->index_field("uploaded", $this->uploaded_ts);
       $I->index_field("path",     $this->filepath);
+      $I->index_field("width",    $this->width);
+      $I->index_field("height",   $this->height);
       // Index the content..
       $allcontent[] = $this->cat_name;
       $allcontent[] = $this->cat_desc;
@@ -235,6 +337,22 @@ class catalogitem extends RenderableObject {
     }
   } // unindex
   // .....................................................................
+  /**
+  * Return the keyinfo string for this catalog item. This is encoded
+  * as follows, and can be used for such things as key values in selects:
+  *   'cat_id|filepath|width|height'
+  */
+  function keyinfo() {
+    $info = array();
+    if ($this->valid) {
+      $info[] = $this->cat_id;
+      $info[] = $this->filepath;
+      $info[] = $this->width;
+      $info[] = $this->height;
+    }
+    return implode("|", $info);
+  } // keyinfo
+  // .....................................................................
   /** Return the catalog item as a clickable icon.
   * @param boolean $autostart Movies etc. if true start automatically
   */
@@ -310,7 +428,186 @@ class catalogitem extends RenderableObject {
         $catmedia = $this->AsIcon();
     } // switch
     return $catmedia;
-  } // In-situ
+  } // Insitu
+  // .....................................................................
+  /** Return the catalog item as its thumbnail if it is an image, else
+   * as an icon or link depending on the type. If the image does not have
+   * an existing thumbnail, one will be created to the width/height
+   * specified. If the thumbnail exists and its size differs from the
+   * passed-in size, and 'recreate' is true, the thumbnail will be rebuilt
+   * to the new size.
+   * @param integer $width Width of new thumbnail, if it is created
+   * @param integer $height Width of a new thumbnail, if created
+   * @param boolean $recreate Recreate if thumbnail size differs
+   */
+  function AsThumbnail($width=STD_THUMB_WIDTH, $height=STD_THUMB_HEIGHT, $recreate=false) {
+    $catmedia = "";
+    $tooltip = basename($this->filepath);
+    // Set commonsense values for movies..
+    switch ($this->mime_category) {
+      case "image":
+        if (!isset($this->versions["thumb"])) {
+          $this->make_version("thumb", $width, $height);
+        }
+        $thumb = $this->versions["thumb"];
+        if ($thumb->fileexists) {
+          $media = new img(
+            $thumb->filepath,
+            str_replace(" ", "", $this->cat_name),
+            ($this->cat_desc != "" ? $this->cat_desc : $this->cat_name)
+            );
+          if ( ($media->width != $width || $media->height != $height) && $recreate) {
+            $media = $this->make_version("thumb", $width, $height);
+          }
+        }        
+        if (is_object($media)) {
+          $catmedia = $media->render();
+        }
+        break;
+      default:
+        $catmedia = $this->Insitu();
+    } // switch
+    return $catmedia;
+  } // AsThumbnail
+  // .....................................................................
+  /**
+   * Creates all allowed versions of this current media item. If the
+   * version already exists, it will not recreate it unless the flag
+   * 'recreate' is set to true.
+   * @param boolean $recreate Force re-creation of existing versions
+   */
+  function make_all_versions($recreate=false) {
+    foreach ($this->AllowedVersions as $version => $versioninfo) {
+      $info = explode("|", $versioninfo);
+      $mimecat = $info[0];
+      if ($mimecat == $this->mime_category) {
+        if (!isset($this->versions[$version]) || $recreate) {
+          $width = $info[1];
+          $height = $info[2];
+          $this->make_version($version, $width, $height, $recreate);
+        }
+      }
+    }
+  } // make_all_vesions
+  // .....................................................................
+  /**
+   * Deletes all existing versions of this current media item.
+   */
+  function delete_all_versions() {
+    foreach ($this->AllowedVersions as $version => $versioninfo) {
+      $info = explode("|", $versioninfo);
+      $mimecat = $info[0];
+      if ($mimecat == $this->mime_category) {
+        if (!isset($this->versions[$version])) {
+          $ver = $this->versions[$version];
+          if (file_exists($ver->physicalpath)) {
+            if (unlink($ver->physicalpath)) {
+              unset($this->versions[$version]);
+            }
+          }
+        }
+      }
+    }
+  } // delete_all_vesions
+  // .....................................................................
+  /**
+   * Make a version of this catalog item to the width x height given
+   * by the incoming parameters. Currently we only support mime-category
+   * 'image' for this method. Returns the media object when done. The
+   * default mode is to only create missing versions. If you want to
+   * recreate then set $recreate to true.
+   * @param string Type of version to create: 'thumb', 'medium' or 'flash'
+   * @param integer $dest_width Width of new version, if it is created
+   * @param integer $dest_height Width of a new version, if created
+   * @param boolean $recreate Force re-creation of existing version
+   * @return mixed The 'img' object of the new version, or false
+   */
+  function make_version(
+    $version="thumb",
+    $dest_width=0,
+    $dest_height=0,
+    $recreate=false)
+  {
+    global $RESPONSE;
+    
+    // Initialise return value to false
+    $new_version = false;
+
+    if (isset($this->AllowedVersions[$version])) {
+      // Process width settings - set defaults if not specified
+      $verinfo = explode("|", $this->AllowedVersions[$version]);
+      if ($dest_width == 0) {
+        $dest_width = $verinfo[1];
+      }
+      if ($dest_height == 0) {
+        $dest_height = $verinfo[2];
+      }
+      
+      // Derive a destination for this version
+      $dir  = dirname($this->filepath);
+      $name = get_file_stem($this->filepath);
+      $extn = get_file_extn($this->filepath);
+      $verpath = "$dir/$name.$version.$extn";
+      $verphys = $RESPONSE->site_docroot . $verpath;
+      if ($recreate || !file_exists($verphys)) {
+        if ($this->fileexists) {
+          $org_width  = $this->width;
+          $org_height = $this->height;
+          
+          switch ($this->mime_category) {
+            case "image":
+              // pick resize which makes the image larger than target size
+              $ratio = $org_width / $org_height;
+              $test_height = $dest_width / $ratio;
+              $test_width  = $dest_height * $ratio;
+              $resize_to = "";
+              if ($test_height >= $dest_height) {
+                  $resize_to = $dest_width . "x";
+              }
+              elseif ($test_width >= $dest_width) {
+                $resize_to = "x" . $dest_height;
+              }
+              if ($resize_to != "") {
+                // create the image in /tmp and then move in place
+                $tmp_dest = tempnam("/tmp","make_thumb");
+                $convcmd = "convert -resize $resize_to -crop $scale+0+0 $this->physicalpath jpg:$tmp_dest";
+                if ( system($convcmd) == 0 ) {
+                  system("chmod +r $tmp_dest");
+                  if ( system("mv $tmp_dest $verphys") == 0 ) {
+                    // get final image to return
+                    $new_version = new img(
+                                    $verpath,
+                                    str_replace(" ", "", $this->cat_name),
+                                    ($this->cat_desc != "" ? $this->cat_desc : $this->cat_name)
+                                    );
+                    if ($new_version->physfileexists) {
+                      // Insert into our local versions array
+                      $ver = new catalogitem_version();
+                      $ver->set_paths($verphys, $verpath);
+                      $ver->fileexists = true;
+                      $this->versions[$version] = $ver;
+                      debugbr("CI VERSION CREATED: at [$verphys]", DBG_DEBUG);
+                    }
+                    else {
+                      debugbr("new version file not found at $verphys", DBG_DEBUG);
+                    }
+                  }
+                  else {
+                    unlink($tmp_dest);
+                    debugbr("error moving $tmp_dest to $verphys", DBG_DEBUG);
+                  }
+                }
+                else {
+                  debugbr("error making image version $verpath ($scale)", DBG_DEBUG);
+                }
+              }
+              break;
+          } // switch
+        }
+      }
+    }
+    return $new_version;
+  } // make_version
   // .....................................................................
   /** Return the catalog item as a clickable hyperlink. */
   function AsLink() {
@@ -403,7 +700,7 @@ class catalogitem extends RenderableObject {
   /**
   * Process an uploaded media file, and define this catalog item to be
   * the newly uploaded file. Assuming a valid upload is performed, this
-  * catalog item will be added to the database, and the file stahsed
+  * catalog item will be added to the database, and the file stashed
   * in the media directory. This method is provided to allow for easy
   * handling of upload form submission particularly for the Axyl media
   * catalog. Ie. use this if you have a form which is just for uploading
@@ -425,8 +722,10 @@ class catalogitem extends RenderableObject {
       // Process uploaded file..
       $file_mime = $up->mimetype;
 
-      // The relative URL path we will save on the DB record..
-      $filepath = "$CATALOGDIR/$up->filename";
+      // The relative URL path we will save on the DB record. Note that
+      // we get rid of spaces, since these can screw various third-party
+      // applications which need to make use of the filepath.
+      $filepath = "$CATALOGDIR/" . str_replace(" ", "_", $up->filename);
       // The physical path on the filesystem..
       $destpath = $RESPONSE->site_docroot . $filepath;
 
@@ -486,6 +785,70 @@ class catalogitem extends RenderableObject {
     }
     return $errmsgs;
   } // upload
+
+  // -----------------------------------------------------------------------
+  /**
+   * Resize the image in the catalog. This will limit either the width or
+   * height or both to the given values. If either are false, then the scaling
+   * limits to the one which is provided, and keeps the same aspect ratio.
+   * @parm $maxw mixed False=ignore, else integer pixels for max width
+   * @parm $maxh mixed False=ignore, else integer pixels for max height
+   */
+  function resize($maxw=false, $maxh=false) {
+    if ($this->valid) {
+      $dest = $this->physicalpath;
+      $org_dims = getimagesize($dest);
+      $orgw  = $org_dims[0];
+      $orgh  = $org_dims[1];
+      $ratio = $orgw / $orgh;
+
+      debugbr("resize: orgw=$orgw orgh=$orgh ration=$ratio", DBG_DEBUG);
+      debugbr("resize: maxw=$maxw maxh=$maxh", DBG_DEBUG);
+    
+      // Determine target size..
+      $do_resize = false;
+      if ($maxw && $maxh) {
+        $target_size = $maxw . 'x' . $maxh;
+        $do_resize = true;
+      }
+      elseif ($maxw) {
+        if ($orgw > $maxw) {
+          $target_size = $maxw . 'x' . intval($maxw / $ratio);
+          $do_resize = true;
+        }
+      }
+      elseif ($maxh) {
+        if ($orgh > $maxh) {
+          $target_size = intval($maxh * $ratio) . 'x' . $maxh;
+          $do_resize = true;
+        }
+      }  
+      if ($do_resize) {
+        debugbr("resize: resizing to $target_size", DBG_DEBUG);
+        // Create the image in /tmp and then move into place
+        $tmp_dest = tempnam("/tmp","imgrsiz");
+        if (system("convert -resize $target_size $dest jpg:$tmp_dest") != 0) {
+          die("error resizing image $dest (catalog id=$catid) to $target_size");
+        }
+        system("chmod +r $tmp_dest");
+        if (system("mv $tmp_dest $dest") != 0) {
+          unlink($tmp_dest);
+          die("error moving $tmp_dest to $dest");
+        }
+      
+        // Save final image size to catalog, since we've actually
+        // resized it on disk, we better had.
+        $final_size = getimagesize($dest);
+        $this->width  = $final_size[0];
+        $this->height = $final_size[1];
+        $this->save();
+      }
+      else {
+        debugbr("resize: NOT resizing image!", DBG_DEBUG);
+      }
+    }
+  } // resize
+
   // .....................................................................
   /**
   * Render the catalog item. We render it as either and icon or a link,
@@ -510,6 +873,33 @@ class catalogitem extends RenderableObject {
 
 } // catalogitem class
 
+// -----------------------------------------------------------------------
+// Class to hold all the data items. This is designed such that when
+// it is converted to JSON format it is perfect for a DOJO toolkit
+// itemDataStore to read and digest.
+class dataitems {
+  var $identifier;
+  var $items = array();
+  function dataitems() {
+  }
+  function additem($item) {
+    $this->items[] = $item;
+  }
+}
+class dataitem {
+  var $thumb;
+  var $large;
+  var $title;
+  var $link;
+  var $catid;
+  function dataitem($catid, $thumb, $large, $title, $link) {
+    $this->thumb = $thumb;
+    $this->large = $large;
+    $this->title = $title;
+    $this->link = $link;
+    $this->catid = $catid;
+  }
+}
 // -----------------------------------------------------------------------
 /**
 * This class encapsulates a media catalog, which is a collection of
@@ -676,14 +1066,7 @@ class catalog extends RenderableObject {
           $ci = new catalogitem();
           $bits = explode("_", $hit["Id"]);
           $ci->cat_id = $bits[1];
-          $ci->cat_name = $hit["catname"];
-          $ci->category = $hit["category"];
-          $ci->mime_category = $hit["mimecat"];
-          $ci->uploaded_ts = $hit["uploaded"];
-          $ci->uploaded = timestamp_to_displaydate(NICE_FULLDATETIME, $ci->uploaded_ts);
-          $ci->filepath = $hit["path"];
-          $ci->valid = true;
-          $ci->newcat = false;
+          $ci->get();
           $this->catalogitems[$ci->cat_id] = $ci;
         }
       }
@@ -736,20 +1119,54 @@ class catalog extends RenderableObject {
         do {
           $ci = new catalogitem();
           $ci->cat_id = $cQ->field("cat_id");
-          $ci->cat_name = $cQ->field("cat_name");
-          $ci->category = $cQ->field("category");
-          $ci->mime_category = $cQ->field("mime_category");
-          $ci->uploaded_ts = datetime_to_timestamp($cQ->field("upload_timestamp"));
-          $ci->uploaded = timestamp_to_displaydate(NICE_FULLDATETIME, $ci->uploaded_ts);
-          $ci->filepath = $cQ->field("filepath");
-          $ci->valid = true;
-          $ci->newcat = false;
+          $ci->get();
           $this->catalogitems[$ci->cat_id] = $ci;
         } while ($cQ->get_next());
       }
     }
 
   } // search
+  
+  // .....................................................................
+  /**
+   * This will emit a JSON-formatted stream containing this catalog of
+   * items in a format which is compatible with the Dojo toolkit's
+   * itemDataStore. Calling it has the side-effect of creating a
+   * thumbnail image for each image in the catalog, since the data
+   * emitted contains URL's pointing to both the thumbnail and its
+   * full image. Thumbnails are stored in the same directory as the
+   * image, but with '.thumb' before the extension. Eg. a file called
+   * 'foo.jpg would have a thumbnail called 'foo.thumb.jpg'.
+   */
+  function send_as_json() {
+    include_once("json-defs.php");
+    $items = new dataitems();
+    $items->identifier = "catid";
+    foreach ($this->catalogitems as $catid => $ci) {
+      if ($ci->fileexists) {
+        if (!isset($ci->versions["thumb"])) {
+          $ci->make_version("thumb");
+        }
+        $thumb = $ci->versions["thumb"];
+        $item = new dataitem(
+                  $ci->cat_id,
+                  $thumb->filepath, // thumb url
+                  $ci->filepath,    // large url
+                  ($ci->cat_desc != "" ? $ci->cat_desc : $ci->cat_name), // title
+                  $ci->keyinfo()    // link (ab-used to contain image metadata here)
+                  );
+        $items->additem($item);
+      }
+    } // while
+    
+    // Make JSON and return it
+    global $RESPONSE;
+    $RESPONSE->discard();
+    header("Content-Type: application/json");
+    $convert = new JSONconverter();
+    $JSON =  $convert->toJSON($items);
+    echo $JSON;
+  } // send_as_json
   // .....................................................................
   /** Return the HTML for this catalog. Returns the list of catalog items
   * as an HTML table.
