@@ -549,7 +549,7 @@ if (!$error) {
     switch ($cp_view) {
       case CP_VIEW_AUTH:
         // Defaults
-        if ($cp_passwd_encryption == "") $cp_passwd_encryption = "none";
+        if ($cp_passwd_encryption == "") $cp_passwd_encryption = "md5";
         if ($cp_passwd_expiry_days == "") $cp_passwd_expiry_days = "180";
         if ($cp_passwd_max_attempts == "") $cp_passwd_max_attempts = "0";
         if ($cp_passwd_history_cycle == "") $cp_passwd_history_cycle = "0";
@@ -1125,7 +1125,7 @@ if (!$error) {
   // Installs text field in $Tin table..
   function entryField($label, $fieldname, &$valarray, $tooltip="") {
     global $app, $Tin, $tbox, $bg;
-    $mybox = $tbox;
+    $mybox = clone($tbox);
     $bg = ($bg == "axbgdark" ? "axbglite" : "axbgdark");
     $Tin->tr($bg);
     $Tin->td( $label, "axfg" );
@@ -1147,7 +1147,7 @@ if (!$error) {
   // Installs text field in $Tin table..
   function integerField($label, $fieldname, &$valarray, $intlimit, $pxwidth=100, $tooltip="") {
     global $app, $Tin, $tbox, $bg;
-    $mybox = $tbox;
+    $mybox = clone($tbox);
     $bg = ($bg == "axbgdark" ? "axbglite" : "axbgdark");
     $Tin->tr($bg);
     $Tin->td( $label, "axfg" );
@@ -1188,7 +1188,7 @@ if (!$error) {
       $Fenc->setvalue($app->getparameter("security_profile", "passwd_encryption"));
       $Tin->td( $Fenc->render() );
       
-      $mybox = $tbox;
+      $mybox = clone($tbox);
       $label = "Password expiry days"; $fld = "passwd_expiry_days"; $style = "width:50px"; $intlimit = 999;  
       $mybox->setstyle($style);
       $mybox->set_onblur("limitInt(this, 1, $intlimit)");
@@ -1255,7 +1255,7 @@ if (!$error) {
       $Fpunq->setvalue($app->getparameter("security_profile", "passwd_char_uniqueness"));
       $Tin->td( $Fpunq->render("cp_passwd_char_uniqueness") );
     
-      $mychkbox = $chkbox;
+      $mychkbox = clone($chkbox);
       $mychkbox->checked = $app->getparameter("security_profile", "passwd_alphanum_mixed");
       $mychkbox->settitle(
             "If checked, this will require a mix of numbers and alphabetic characters in "
@@ -1265,7 +1265,7 @@ if (!$error) {
       $Tin->td( "Require mix of alpha & numerics:", "axfg" );
       $Tin->td( $mychkbox->render("cp_passwd_alphanum_mixed") );
       
-      $mychkbox = $chkbox;
+      $mychkbox = clone($chkbox);
       $mychkbox->checked = $app->getparameter("security_profile", "passwd_apply_stopwords");
       $mychkbox->settitle(
             "If checked, the system will check a new password against a database of common "
@@ -1323,7 +1323,7 @@ if (!$error) {
     
       $Tin->tr("axbgdark");
       $Tin->td( "Failed login re-direct URL:", "axfg" );
-      $mybox = $tbox;
+      $mybox = clone($tbox);
       $mybox->settitle(
             "Supply the URL to re-direct to on failed login."
           );
@@ -1332,7 +1332,7 @@ if (!$error) {
       
       $Tin->tr("axbglite");
       $Tin->td( "Login delay after failure (mS):", "axfg" );
-      $mybox = $tbox;
+      $mybox = clone($tbox);
       $mybox->setstyle("width:90px");
       $mybox->set_onblur("limitInt(this, 0, 9999)");
       $mybox->settitle(
@@ -1364,7 +1364,7 @@ if (!$error) {
     
       $Tin->tr("axbglite");
       $Tin->td( "Login excess re-direct URL:", "axfg" );
-      $mybox = $tbox;
+      $mybox = clone($tbox);
       $mybox->settitle(
             "If re-directing to a webpage, enter the URL for the page here."
           );
@@ -1450,7 +1450,7 @@ if (!$error) {
     
       $Tin->tr("axbglite");
       $Tin->td( "Remote user table name:", "axfg" );
-      $mybox = $tbox;
+      $mybox = clone($tbox);
       $mybox->setid("auth_fields");
       $mybox->setstyle("width:$cwidth");
       $mybox->settitle(
@@ -1463,7 +1463,7 @@ if (!$error) {
       foreach ($REMOTE_AUTH_FIELDNAMES as $axyl_field) {      
         $Tin->tr("axbgdark");
         $Tin->td( "&raquo;&nbsp;remote field for $axyl_field:", "axfg" );
-        $mybox = $tbox;
+        $mybox = clone($tbox);
         $mybox->setid("auth_fields");
         $mybox->setstyle("width:$cwidth");
         $mybox->settitle(
@@ -1496,7 +1496,7 @@ if (!$error) {
     
       $Tin->tr("axbglite");
       $Tin->td( "IP addresses to block:", "axfg" );
-      $mybox = $tbox;
+      $mybox = clone($tbox);
       $mybox->settitle(
             "This is used to block specific IP addresses which are causing a problem "
             . "accessing the website. Any IP listed here will be denied access."
@@ -1758,7 +1758,7 @@ if (!$error) {
       $Tapp->tr("axsubhdg");
       $Tapp->td("<b>Misc settings</b>", "axsubhdg");
     
-      $mychkbox = $chkbox;
+      $mychkbox = clone($chkbox);
       $mychkbox->checked = $app->getparameter("database_backed", "database_backed");
       $mychkbox->settitle(
             "Check this if your website connects to a database. Most do, but this allows "
@@ -1770,7 +1770,7 @@ if (!$error) {
     
       $Tin->tr("axbglite");
       $Tin->td( "Hosts for persistent DB connection:", "axfg" );
-      $mybox = $tbox;
+      $mybox = clone($tbox);
       $mybox->settitle(
             "If the database hostname contains the string you enter here, then database "
             . "connections will be made persistently, improving performance when the "
@@ -1802,7 +1802,7 @@ if (!$error) {
       $Tin->setpadding(2);
     
       $debugging = $app->getparameter("debug_on", "debug_on");
-      $mychkbox = $chkbox;
+      $mychkbox = clone($chkbox);
       $mychkbox->settitle(
             "If you want site-wide debugging to be displayed then check this box. It "
             . "will cause every page to display debug information."
@@ -1832,11 +1832,12 @@ if (!$error) {
       $Fdebugcl->additem(32,  "Include traceback info");
       $Fdebugcl->additem(64,  "Show table outlines");
       $Fdebugcl->additem(128, "Execution profiler");
+      $Fdebugcl->additem(256, "Authentication");
       $Fdebugcl->additem(1,   "System diagnostics");
       // Build value as array of set bits..
       $debugcl = $app->getparameter("debug_classes", "debug_classes");
       $debug_value = array();
-      for ($i=1; $i < 256; $i*=2) {
+      for ($i=1; $i < 512; $i*=2) {
         if ($debugcl & $i) {
           $debug_value[] = $i;
         }
@@ -1865,7 +1866,7 @@ if (!$error) {
       // Build value as array of set bits..
       $debugop = $app->getparameter("debug_output", "debug_output");
       $debugop_value = array();
-      for ($i=1; $i < 256; $i*=2) {
+      for ($i=1; $i < 512; $i*=2) {
         if ($debugop & $i) {
           $debugop_value[] = $i;
         }
@@ -1898,7 +1899,7 @@ if (!$error) {
           );
     
       $resptimer = $app->getparameter("response_timer", "response_timer");
-      $mychkbox = $chkbox;
+      $mychkbox = clone($chkbox);
       $mychkbox->checked = $resptimer;
       $mychkbox->settitle(
             "Use this option to find out how long your website pages are taking to "
@@ -2114,7 +2115,7 @@ if (!$error) {
       $Tin->td( "Character encoding:", "axfg" );
       $Tin->td( $cboENC->render("cp_encoding") );
     
-      $mychkbox = $chkbox;
+      $mychkbox = clone($chkbox);
       $mychkbox->checked = $app->getparameter("multilang", "multilang");
       $mychkbox->set_onclick("setUTF8mode(this.checked)");
       $mychkbox->settitle(
@@ -2147,7 +2148,7 @@ if (!$error) {
       if ($http_host == "") {
         $http_host = "(default to webserver)";
       }
-      $mybox = $tbox;
+      $mybox = clone($tbox);
       $mybox->setvalue($http_host);
       $mybox->settitle(
           "This allows you to specify a different hostname from the local webserver. Normally "
@@ -2173,7 +2174,7 @@ if (!$error) {
       if ($cookiename == "") {
         $cookiename = $app->definitions["APP_PREFIX"] . "_session_id";
       }
-      $mybox = $tbox;
+      $mybox = clone($tbox);
       $mybox->setvalue($cookiename);
       $mybox->settitle(
           "If you don't like the default Axyl name for your cookie, then just "
@@ -2237,7 +2238,7 @@ if (!$error) {
           );
       $Tin->td( $Fexpiry->render("cp_expiry") );
     
-      $mychkbox = $chkbox;
+      $mychkbox = clone($chkbox);
       $mychkbox->checked = $app->getparameter("guest_browser_lifetime", "guest_browser_lifetime");
       $mychkbox->settitle(
           "Non-logged-in users in Axyl get allocated a 'guest' session cookie. This option will "
@@ -2248,7 +2249,7 @@ if (!$error) {
       $Tin->td( "Guest cookies browser lifetime:", "axfg" );
       $Tin->td( $mychkbox->render("cp_guest_browser_lifetime") );
     
-      $mychkbox = $chkbox;
+      $mychkbox = clone($chkbox);
       $mychkbox->checked = $app->getparameter("session_track_logins", "session_track_logins");
       $mychkbox->settitle(
           "If checked then Axyl will keep track of each user's logins, counting them as they "
@@ -2270,7 +2271,7 @@ if (!$error) {
       $Tin = new table("content");
       $Tin->setpadding(2);
     
-      $mychkbox = $chkbox;
+      $mychkbox = clone($chkbox);
       $mychkbox->checked = $app->getparameter("metadata_enabled", "metadata_enabled");
       $mychkbox->settitle(
           "If you installed the Axyl Metadata Extension when you created the website, then "
@@ -2281,7 +2282,7 @@ if (!$error) {
       $Tin->td( "Enable metadata edit/generation:", "axfg" );
       $Tin->td( $mychkbox->render("cp_metadata_enabled") );
     
-      $mychkbox = $chkbox;
+      $mychkbox = clone($chkbox);
       $mychkbox->checked = $app->getparameter("microsites_enabled", "microsites_enabled");
       $mychkbox->set_onchange(
                 "if(this.checked) "
@@ -2301,7 +2302,7 @@ if (!$error) {
       $Tin->td( "Enable microsite(s) creation:", "axfg" );
       $Tin->td( $mychkbox->render("cp_microsites_enabled") );
     
-      $mychkbox = $chkbox;
+      $mychkbox = clone($chkbox);
       $mychkbox->checked = $app->getparameter("buffered_output", "buffered_output");
       $mychkbox->settitle(
           "Whether or not to run the website using buffered Php output. Buffering allows Axyl "
@@ -2362,7 +2363,7 @@ if (!$error) {
       $Tin = new table("getpost");
       $Tin->setpadding(2);
     
-      $mychkbox = $chkbox;
+      $mychkbox = clone($chkbox);
       $mychkbox->checked = $app->getparameter("keep", "keep");
       $mychkbox->settitle(
           "This option causes Axyl to set a second browser cookie. You can then use Php "
@@ -2373,7 +2374,7 @@ if (!$error) {
       $Tin->td( "Enable Axyl KEEP feature:", "axfg" );
       $Tin->td( $mychkbox->render("cp_keep") );
     
-      $mychkbox = $chkbox;
+      $mychkbox = clone($chkbox);
       $mychkbox->checked = $app->getparameter("globalise", "globalise");
       $mychkbox->settitle(
           "When checked this causes Axyl to auto globalise variables submitted to the "
