@@ -98,6 +98,10 @@ class datasources {
         include_once("db-oracle.php");
         $this->database[$name] = new db_oracle($name, $user, $passwd, $host, $port, $enc, $datestyle);
         break;
+      case "sqlite":
+        include_once("db-sqlite.php");
+        $this->database[$name] = new db_sqlite($name, $user, $passwd, $host, $port, $enc, $datestyle);
+        break;
     }
     // Make sure the default database is selected..
     if ($default) {
