@@ -56,6 +56,12 @@ define("NICE_FULLDATETIME",        "M jS Y g:ia");
 /** Example: Friday, 20th July 2001 */
 define("DAY_AND_DATE",             "l, jS F Y");
 
+/** Example:  1:30pm Friday, 20th July 2001 */
+define("DAY_AND_DATETIME",         "l, jS F Y g:ia");
+
+/** Example: Fri, 02 July 2001 08:00:00 +1200 */
+define("RFC_822",                  "r");
+
 /** Example: 23:59 */
 define("DISPLAY_TIME_ONLY",        "H:i");
 
@@ -80,8 +86,14 @@ define("SQL_FORMAT",               "m/d/Y H:i:s");
 /** Example: Sun 23:59 */
 define("DOW_HHMM",                 "D H:i");
 
-/** ISO 8601 Example: YYYYMMDDTHHMMSS-HHMM */
-define("ISO_8601",                 "Ymd\THisO");
+/** ISO 8601 Example: 2008-03-31T08:15:30+1300 */
+define("ISO_8601",                 "Y-m-d\TH:i:sO");
+
+/** ISO 8601 Example: 2008-03-3 */
+define("ISO_8601_DATE_ONLY",       "Y-m-d");
+
+/** ISO 8601 Example: T08:15:00 */
+define("ISO_8601_TIME_ONLY",       "\TH:i:s");
 
 // -----------------------------------------------------------------------
 // Handy vars..
@@ -145,14 +157,15 @@ function isLeapYear($year) {
 
 // .......................................................................
 /**
-* Tell nice difference between too datetimes
-* Returns a nice expression of the difference between the
-* two given datetimes written in a nice English sentence
-* @param string $dfrom From date in Postgres datetime format
-* @param string $dto   To date in Postgres datetime format
-* @return string Nice sentence describing difference
-*/
-function prose_diff($dfrom, $dto) {
+ * Returns a nice expression of the difference between the two given
+ * datetimes written in a nice English sentence. Optionally round the
+ * reply to just weeks and days, omitting hours and minutes.
+ * @param string $dfrom From date in Postgres datetime format
+ * @param string $dto To date in Postgres datetime format
+ * @param boolean $rounded Round to weeks and days (no hours, mins)
+ * @return string Nice sentence describing difference
+ */
+function prose_diff($dfrom, $dto, $rounded=false) {
   $prose = "";
   if ($dfrom == "now") $fromts = time();
   else $fromts = datetime_to_timestamp($dfrom);
@@ -160,46 +173,80 @@ function prose_diff($dfrom, $dto) {
   if ($dto == "now") $tots = time();
   else $tots = datetime_to_timestamp($dto);
 
-  return prose_diff_ts($fromts, $tots);
+  return prose_diff_ts($fromts, $tots, $rounded);
 } // prose_diff
 
 // .......................................................................
 /**
-* Tell nice difference between too Unix timestamps
-* Returns a nice expression of the difference between the
-* two given timestamps, written in a nice English sentence
+* Tell nice difference between two Unix timestamps. Returns a nice
+* expression of the difference between the two given timestamps, written
+* in a nice English sentence. We take some executive decisions about
+* truncating information - eg. when we are int months of difference then
+* we don't bother reporting days, hours, & mins - a forced rounding up
+* is done to stop it all looking very silly.
 * @param integer $fromts From datetime as Unix timestamp
 * @param integer $tots   To datetime as Unix timestamp
+ * @param boolean $rounded Round to only YMWD (no hours, mins)
 * @return string Nice sentence describing the time interval
 */
-function prose_diff_ts($fromts, $tots) {
+function prose_diff_ts($fromts, $tots, $rounded=false) {
   $prose = "";
   $diff = $tots - $fromts;
   if ($diff >= 0) {
-    $weeks = floor($diff / 604800);
-    $diff = $diff - ($weeks * 604800);
-    $days  = floor($diff / 86400);
-    $diff = $diff - ($days * 86400);
-    $hours  = floor($diff / 3600);
-    $diff = $diff - ($hours * 3600);
-    $mins  = floor($diff / 60);
-    if ($weeks > 0) $prose .= "$weeks weeks";
-    if ($days > 0) {
-      if ($prose != "") $prose .= ", ";
-      $prose .= "$days days";
+    $years  = floor($diff / SECS_1_YEAR);  $diff = $diff - ($years  * SECS_1_YEAR);
+    $months = floor($diff / SECS_1_MONTH); $diff = $diff - ($months * SECS_1_MONTH);
+    $weeks  = floor($diff / SECS_1_WEEK);  $diff = $diff - ($weeks  * SECS_1_WEEK);
+    $days   = floor($diff / SECS_1_DAY);   $diff = $diff - ($days   * SECS_1_DAY);
+    $hours  = floor($diff / SECS_1_HOUR);  $diff = $diff - ($hours  * SECS_1_HOUR);
+    $mins   = floor($diff / 60);
+    if ($years > 0) {
+      $prose .= "$years year" . ($years > 1 ? "s" : "");
     }
-    if ($hours > 0) {
-      if ($prose != "") $prose .= ", ";
-      $prose .= "$hours hours";
+    if ($months > 0) {
+      if ($prose != "") {
+        $prose .= ", ";
+      }
+      $prose .= "$months month" . ($months > 1 ? "s" : "");
     }
-    if ($mins > 0) {
-      if ($prose != "") $prose .= ", and ";
-      $prose .= "$mins minutes";
+    if ($weeks > 0) {
+      if ($prose != "") {
+        $prose .= ", ";
+      }
+      if ($years > 0 || $months > 0) {
+        if ($days > 3) {
+          $weeks += 1;
+        }
+      }
+      $prose .= "$weeks week" . ($weeks > 1 ? "s" : "");
+    }
+    if ($years == 0 && $months == 0) {
+      if ($days > 0) {
+        if ($rounded && $hours > 12) {
+          $days += 1;
+        }
+        if ($prose != "") {
+          $prose .= ", ";
+        }
+        $prose .= "$days day" . ($days > 1 ? "s" : "");
+      }
+      if (!$rounded) {
+        if ($hours > 0) {
+          if ($prose != "") {
+            $prose .= ", ";
+          }
+          $prose .= "$hours hour" . ($hours > 1 ? "s" : "");
+        }
+        if ($mins > 0) {
+          if ($prose != "") {
+            $prose .= ", and ";
+          }
+          $prose .= "$mins minute" . ($mins > 1 ? "s" : "");
+        }
+      }
     }
   }
   return $prose;
 } // prose_diff_ts
-
 // .......................................................................
 /**
 * Tell minutes difference between too datetimes
@@ -222,7 +269,6 @@ function mins_diff($dfrom, $dto) {
 
   return $mins;
 }
-
 // -----------------------------------------------------------------------
 // DATE CONVERSION: USER DISPLAY -> DATABASE
 // -----------------------------------------------------------------------
@@ -503,7 +549,7 @@ function monthNameNow() {
 */
 function dayNow() {
   $tod = getdate();
-  return $tod["wday"];
+  return $tod["mday"];
 }
 
 // .......................................................................
@@ -716,4 +762,4 @@ class schedule {
 }
 
 // -----------------------------------------------------------------------
-?>
+?>
\ No newline at end of file
