@@ -397,30 +397,11 @@ class webdebugger extends RenderableObject {
   * @return string  HTML rendering of debug output content
   */
   function html() {
-    if (!$this->debug_hascontent()) return "";
-
-    // Get names of globals we will use. These depend on the
-    // version of Php, since we won't rely on the old ones
-    // sticking around forever..
-    $vname_get = "HTTP_GET_VARS";
-    $vname_post = "HTTP_POST_VARS";
-    $vname_cookie = "HTTP_COOKIE_VARS";
-    $vbits = explode(".", phpversion());
-    $v1 = $vbits[0]; $v2 = $vbits[1];
-    if (($v1 > 4) || ($v1 == 4 && $v2 >= 1)) {
-      $vname_get = "_GET";
-      $vname_post = "_POST";
-      $vname_cookie = "_COOKIE";
+    if (!$this->debug_hascontent()) {
+      return "";
     }
-    // Bring them in..
-    global $$vname_cookie;
-    global $$vname_get;
-    global $$vname_post;
-    global $PHP_SELF;
-    global $GLOBALS;
-
     // Header stuff.,
-    $header  = "<h4>PHP Web Page Debugger</h4>";
+    $header  = "<h4>Axyl Debug Output</h4>";
     $header .= "<p>";
     $header .= "<b>File: $PHP_SELF</b><br>";
     $header .= "<b>Debug filter: " . $this->report_classes() . "</b><br>";
@@ -429,31 +410,33 @@ class webdebugger extends RenderableObject {
     if ($this->debugclass & DBG_DUMP) {
       $s  ="<p>";
       $s .= "<table border=1 cellpadding=2 cellspacing=0>";
-      if (isset($$vname_cookie)) {
+      if (isset($_COOKIE)) {
         $s .= "<tr><td colspan=2><h4>Cookie Vars</h4></td></tr>";
-        reset($$vname_cookie);
-        while (list($key, $val) = each($$vname_cookie)) {
+        foreach ($_COOKIE as $key => $val) {
           $s .= "<tr><td>$key</td><td>" . displayvar($val) . "</td></tr>";
         }
       }
-      if (isset($$vname_get)) {
+      if (isset($_GET)) {
         $s .= "<tr><td colspan=2><h4>GET Vars</h4></td></tr>";
-        reset($$vname_get);
-        while (list($key, $val) = each($$vname_get)) {
+        foreach ($_GET as $key => $val) {
           $s .= "<tr><td>$key</td><td>" . displayvar($val) . "</td></tr>";
         }
       }
-      if (isset($$vname_post)) {
+      if (isset($_POST)) {
         $s .= "<tr><td colspan=2><h4>POSTed Vars</h4></td></tr>";
-        reset($$vname_post);
-        while (list($key, $val) = each($$vname_post)) {
+        foreach ($_POST as $key => $val) {
           $s .= "<tr><td>$key</td><td>" . displayvar($val) . "</td></tr>";
         }
       }
-      if (isset($GLOBALS)) {
-        $s .= "<tr><td colspan=2><h4>Globals</h4></td></tr>";
-        reset($GLOBALS);
-        while (list($key, $val) = each($GLOBALS)) {
+      if (isset($_SESSION)) {
+        $s .= "<tr><td colspan=2><h4>Session Vars</h4></td></tr>";
+        foreach ($_SESSION as $key => $val) {
+          $s .= "<tr><td>$key</td><td>" . displayvar($val) . "</td></tr>";
+        }
+      }
+      if (isset($_FILES)) {
+        $s .= "<tr><td colspan=2><h4>Uploaded Files</h4></td></tr>";
+        foreach ($_FILES as $key => $val) {
           $s .= "<tr><td>$key</td><td>" . displayvar($val) . "</td></tr>";
         }
       }
@@ -771,7 +754,12 @@ function displayvar($var) {
   $s = "";
   if (is_array($var)) {
     foreach ($var as $elem) {
-      $s .= "[$elem] ";
+      if (is_scalar($elem)) {
+        $s .= "[$elem] ";
+      }
+      else {
+        $s .= "[non-scalar]";
+      }
     }
   }
   elseif (is_bool($var)) {
