@@ -103,7 +103,7 @@ function get_file_extn($path){
   if ($path != "") {
     $fname = basename($path);
     $bits = explode(".", $fname);
-    $extn = strtolower(trim($bits[ count($bits) - 1 ]));
+    $extn = trim($bits[ count($bits) - 1 ]);
   }
   return $extn;
 } // get_file_extn
@@ -116,7 +116,7 @@ function get_file_stem($path){
   if ($path != "") {
     $fname = basename($path);
     $bits = explode(".", $fname);
-    $stem = strtolower(trim($bits[ 0 ]));
+    $stem = trim($bits[ 0 ]);
   }
   return $stem;
 } // get_file_stem
@@ -327,7 +327,7 @@ class csv_inputfile extends inputfile {
 */
 class stylesheet extends inputfile {
   /** @access private */
-  var $class;
+  var $cssclass;
   // ....................................................................
   /**
   * Constructor
@@ -342,14 +342,14 @@ class stylesheet extends inputfile {
       // are provided by inputfile, but we also read the
       // stylesheet into our special structure, so that
       // styles are easily accessible..
-      $this->class = array();
+      $this->cssclass = array();
       $this->readstyles();
     }
   }
   // ....................................................................
   /**
   * Read in the styles from stylesheet. We have repeated
-  * entries of the form: classlist { attrib: def; attrib: def; }
+  * entries of the form: cssclasslist { attrib: def; attrib: def; }
   * NB: this does not, as yet, cope with 'complex' stylesheets
   *     which have inheritance in the name definitions.
   * @access private
@@ -362,37 +362,33 @@ class stylesheet extends inputfile {
         $entries = explode("}", $content);
         foreach ($entries as $entry) {
           $entrybits = explode("{", $entry);
-          $classlist = trim($entrybits[0]);
-          $classes = explode(",", $classlist);
-          foreach ($classes as $classname) {
-            $classname = trim($classname);
-            if ($classname != "") {
-              if (substr($classname, 0, 1) == ".") {
-                $classname = substr($classname, 1);
+          $cssclasslist = trim($entrybits[0]);
+          $cssclasses = explode(",", $cssclasslist);
+          foreach ($cssclasses as $cssclassname) {
+            $cssclassname = trim($cssclassname);
+            if ($cssclassname != "") {
+              if (substr($cssclassname, 0, 1) == ".") {
+                $cssclassname = substr($cssclassname, 1);
               }
-              if (isset($this->class[$classname])) {
-                $classattr = $this->class[$classname];
-                //debugbr("ADDING TO CLASS $classname");
+              if (isset($this->cssclass[$cssclassname])) {
+                $cssclassattr = $this->cssclass[$cssclassname];
               }
               else {
-                $classattr = array();
-                //debugbr("FIRST TIME FOR CLASS $classname");
+                $cssclassattr = array();
               }
-              $classdefs = explode(";", $entrybits[1]);
-              foreach($classdefs as $classdef) {
-                $defbits = explode(":", $classdef);
+              $cssclassdefs = explode(";", $entrybits[1]);
+              foreach($cssclassdefs as $cssclassdef) {
+                $defbits = explode(":", $cssclassdef);
                 $name    = trim($defbits[0]);
                 $setting = trim($defbits[1]);
                 if ($name != "") {
-                  $classattr[$name] = $setting;
-                  //debugbr("[$classname][$name] -> [$setting]");
+                  $cssclassattr[$name] = $setting;
                 }
               }
-              // Store this class away..
-              $this->class[$classname] = $classattr;
-              //debugbr("CLASS: [$classname]");
+              // Store this cssclass away..
+              $this->cssclass[$cssclassname] = $cssclassattr;
             }
-          } // foreach classname
+          } // foreach cssclassname
         } // foreach entry
       } // if readall
       $this->closefile();
@@ -408,19 +404,19 @@ class stylesheet extends inputfile {
   * @param  string  $attrname  The name of the class attribute
   * @return boolean True if file was opened, else false
   */
-  function style($classname, $attrname="") {
+  function style($cssclassname, $attrname="") {
     $style = "";
-    $classname = strtolower($classname);
+    $cssclassname = strtolower($cssclassname);
     $attrname = strtolower($attrname);
-    if (isset($this->class[$classname])) {
-      $class = $this->class[$classname];
+    if (isset($this->cssclass[$cssclassname])) {
+      $cssclass = $this->cssclass[$cssclassname];
       if ($attrname != "") {
-        if (isset($class[$attrname])) {
-          $style = $class[$attrname];
+        if (isset($cssclass[$attrname])) {
+          $style = $cssclass[$attrname];
         }
       }
       else {
-        while (list($name, $setting) = each($class)) {
+        while (list($name, $setting) = each($cssclass)) {
           $style .= "$name:$setting;";
         }
       }
