@@ -173,7 +173,7 @@ class form extends HTMLObject {
   * @param object $element The form element object to add
   */
   function add($element) {
-    $this->elements[] = $element;
+    $this->elements[] = clone($element);
   } // add
   // ....................................................................
   /**
@@ -605,6 +605,9 @@ class form_field extends HTMLObject {
   /** If false, disable autocomplete on this field. Mainly used with
       password fields to stop browsers saving passwords insecurely. */
   var $autocomplete = true;
+  /** Whether the field is required/mandatory or not. If true then
+   * the field should not be left blank, once focussed */
+  var $required = false;
   // ....................................................................
   /**
   * Constructor
@@ -622,16 +625,27 @@ class form_field extends HTMLObject {
     $this->editable = $editable;
     $this->setcss($css);
   }
-  /** Set the field to be display-only (non-editable) */
-  function set_displayonly() {
-    $this->editable = false;
+  // ....................................................................
+  /**
+   * Set the field to be display-only (non-editable). How we do this
+   * depends on the field type.
+   */
+  function set_displayonly($mode=true) {
+    $this->editable = !$mode;
   }
+  // ....................................................................
+  /** Set the field to be required (mandatory) */
+  function set_required($mode=true) {
+    $this->required = mode;
+  }
+  // ....................................................................
   /** Set the label associated with the field
   * @param string $label The label to set for this field
   */
   function setlabel($label)  {
     $this->label = $label;
   }
+  // ....................................................................
   /** Set the value of the field
   * @param mixed $value The value to set for this field
   */
@@ -639,6 +653,7 @@ class form_field extends HTMLObject {
     if (!is_array($value)) $value = trim($value);
     $this->value = $value;
   }
+  // ....................................................................
   /**
   * Returns current element as a hidden field.
   * @return string HTML for hidden field version of current field.
@@ -647,6 +662,7 @@ class form_field extends HTMLObject {
     $hid = new form_hiddenfield($this->name, $this->value);
     return $hid->render();
   }
+  // ....................................................................
   /**
   * Returns current element as text, with associated hidden field.
   * @return string HTML for hidden field version of current field.
@@ -656,6 +672,7 @@ class form_field extends HTMLObject {
     if ( isset($this->value) ) $s .= "<strong>$this->value</strong>";
     return $s;
   }
+  // ....................................................................
   /**
   * Disable the autocomplete form functionality of the browser for
   * this field. Browsers have, mainly for password fields, been offering
@@ -667,6 +684,55 @@ class form_field extends HTMLObject {
   function disable_autocomplete() {
     $this->autocomplete = false;
   }
+  // ....................................................................
+  /**
+  * Check if this field is required. This means the field should not be
+  * left empty, or unset once it has been focussed. The default is to
+  * use an onblur event, with variations for other UI toolkits.
+  */
+  function check_if_mandatory() {
+    global $RESPONSE;
+    if ($this->required) {
+      switch ($RESPONSE->ui_toolkit) {
+        case "dojo":
+          $this->set_attribute("required", "true");
+          break;
+        default:
+          $this->set_onblur(
+              "isNonBlank(this, 'Please fill in a value for this required field.')",
+              SCRIPT_APPEND
+              );
+      } // switch
+    }
+  } // check_if_mandatory
+  // ....................................................................
+  /**
+  * This method checks the attributes of the field and makes any
+  * adjustments required. Used for calling before a field render().
+  * @access private
+  */
+  function validate_attributes() {
+    global $RESPONSE;
+    
+    // Assign ID for dojo widgets, if not already
+    if ($this->id == "" && $RESPONSE->ui_toolkit == "dojo") {
+      $this->id = $this->name;
+    }
+    // Check if the field has been flagged as mandatory. This
+    // will only be useful for certain field types.
+    switch ($this->type) {
+      // These elements support mandatory enforcement
+      case "text":
+      case "password":
+      case "textarea":
+      case "file":
+      case "select":
+        $this->check_if_mandatory();
+        break;
+    } // switch
+
+  } // validate_attributes
+  // ....................................................................
   /**
   * Render common field properties
   * This method renders the common field properties. Used in the
@@ -675,16 +741,21 @@ class form_field extends HTMLObject {
   * @access private
   */
   function field_attributes() {
-    global $RESPONSE;
-    $html = "";
-    // Add in standard HTML attributes..
-    $html .= $this->attributes();
+    // Check all attributes are kosher first
+    $this->validate_attributes();
+
+    // Start with standard HTML attributes
+    $html = $this->attributes();
+
     // Add in our field-specific attributes..
-    if ($this->disabled) $html .= " disabled";
+    if ($this->disabled) {
+      $html .= " disabled";
+    }
+
     // Readonly behaviour depends on type..
     if (!$this->editable) {
       switch ($this->type) {
-        // These elements support the readonly property..
+        // These elements support the readonly property
         case "text":
         case "password":
         case "textarea":
@@ -967,17 +1038,14 @@ class form_imagebutton extends form_buttonfield {
 
       // Onclick/confirmation popup option..
       if (!$this->onclick && $this->confirm_text != "") {
-        $this->onclick="return confirm('$this->confirm_text');";
+        $this->set_onclick("return confirm('$this->confirm_text');");
       }
       if ($this->onclick) {
         // Append return false if form submit not allowed. Since the onclick
         // event is defined, we assume that the user's Javascript handler will
         // submit the form if required, unless this flag has been set true..
         if (!$this->onclick_form_submit) {
-          if ($this->onclick != "" && substr($this->onclick, -1) != ";") {
-            $this->onclick .= ";";
-          }
-          $this->onclick .= "return false;";
+          $this->set_onclick("return false;", SCRIPT_APPEND);
         }
       }
       // Dimensions via style setting..
@@ -1008,6 +1076,9 @@ class form_textfield extends form_field {
   /** Maximum user-enterable chars for field
       @access private */
   var $maxlength;
+  /** Whether to enable a javascript datepicker and
+   * validator for the content of this field. */
+  var $datepicker_enabled = false;
   // ....................................................................
   /**
   * Constructor
@@ -1024,6 +1095,20 @@ class form_textfield extends form_field {
     $this->size = $width;
     $this->type = "text";
     $this->format = "*m";
+    global $RESPONSE;
+    switch ($RESPONSE->ui_toolkit) {
+      case "dojo":
+        $RESPONSE->head->add_named_script(
+            "dojo.require('dijit.form.TextBox');\n",
+            "dojo",
+            "javascript",
+            "append",
+            ADD_ONCE_ONLY
+            );
+        $this->set_attribute("dojoType", "dijit.form.TextBox");
+        break;
+    } // switch
+    
   } // form_textfield
   // ....................................................................
   /**
@@ -1047,6 +1132,17 @@ class form_textfield extends form_field {
   } // set_format
   // ....................................................................
   /**
+  * Control whether the datepicker is enabled for the content of this field.
+  * If enabled then when the field is rendered, the calendar datepicker will
+  * appear when the user clicks in the field, and the field will be checked
+  * for valid date content. 
+  * @param boolean $mode Whether to enable datepicker or not
+  */
+  function enable_datepicker($mode=true) {
+    $this->datepicker_enabled = ($mode === true);
+  } // enable_datepicker
+  // ....................................................................
+  /**
   * This renders the field as WML.
   * @return string The field as WML.
   */
@@ -1071,12 +1167,23 @@ class form_textfield extends form_field {
   * @return string The field as HTML.
   */
   function html($name="") {
-    if ($name != "") $this->name = $name;
+    global $RESPONSE, $LIBDIR;
+    if ($name != "") {
+      $this->name = $name;
+    }
+    if ($this->datepicker_enabled) {
+      $RESPONSE->add_scriptsrc("$LIBDIR/js/scw.js");
+      $this->set_onclick("scwShow(this,event)", SCRIPT_PREFIX);
+    }
     $html  = "<input";
     $html .= " type=\"$this->type\"";
     $html .= $this->field_attributes();
-    if (isset($this->value)) $html .= " value=" . quoted_valuestring($this->value);
-    if (isset($this->maxlength)) $html .= " maxlength=\"$this->maxlength\"";
+    if (isset($this->value)) {
+      $html .= " value=" . quoted_valuestring($this->value);
+    }
+    if (isset($this->maxlength)) {
+      $html .= " maxlength=\"$this->maxlength\"";
+    }
     $html .= ">";
     return $html;
   } // html
@@ -1179,7 +1286,7 @@ class form_fileuploadfield extends form_field {
   * This renders the field as HTML.
   * @return string The field as HTML.
   */
-  function html($name="") {
+  function html($name="") {    
     if ($name != "") $this->name = $name;
     $html  = "<input";
     $html .= " type=\"$this->type\"";
@@ -1196,6 +1303,13 @@ class form_fileuploadfield extends form_field {
 } // form_fileuploadfield class
 
 // ----------------------------------------------------------------------
+/**
+ * Defines to enable us to provide for <optgroup>..</optgroup> option
+ * groupings within a select element. These go in as the 'key' in an
+ * additem() call.
+ */
+ define("OPTGROUP_START", "OPT!GROUP_START_");
+ define("OPTGROUP_END",   "OPT!GROUP_END_");
 /**
 * Combo Field class
 * A field for producing combo boxes (dropdown select menus) or
@@ -1207,11 +1321,15 @@ class form_combofield extends form_textfield {
   // Public
   /** Boolean, multiple item select */
   var $multiselect;
+  /** Boolean, auto-completion, if supported */
+  var $autocomplete = false;
 
   // Private
   /** Items to display, assoc. array
       @access private */
   var $itemlist;
+  /** Label of the active optgroup, if any. */
+  var $active_optgroup = "";
   // ....................................................................
   /**
   * Constructor
@@ -1229,7 +1347,13 @@ class form_combofield extends form_textfield {
     $this->size = $lines;
     $this->multiselect = $multi;
     $this->itemlist = new dat_keyvalues();
-    $this->type = "select";
+    $this->type = "select";    
+    global $RESPONSE;
+    switch ($RESPONSE->ui_toolkit) {
+      case "dojo":
+        $this->set_attribute("dojoType", "dijit.form.FilteringSelect");
+        break;
+    } // switch
   } // form_combofield
   // ....................................................................
   /**
@@ -1252,6 +1376,16 @@ class form_combofield extends form_textfield {
   } // set_size
   // ....................................................................
   /**
+  * Set combo to autocomplete mode. This is a feature supported in some
+  * UI toolkits, whereby the user can start typing and the combo will
+  * zero in on the matching element.
+  * @param boolean $mode Whether to enable autocomplete, true or false
+  */
+  function set_autocomplete($mode=true) {
+    $this->autocomplete = $mode;
+  } // set_autocomplete
+  // ....................................................................
+  /**
   * Add a data item
   * Adds a key=>value pair into the combo options collection.
   * @param string $key   The key to use (the field 'value' or ID)
@@ -1262,6 +1396,58 @@ class form_combofield extends form_textfield {
     $this->itemlist->additem($key, $value);
   } // additem
   // ....................................................................
+  /**
+  * Start an option group <optgroup>.
+  * If another optgroup with a different label is already active, then
+  * this also creates an </optgroup> element to end it before starting
+  * the new one.
+  * If this method is called with the same label as the already-active
+  * optgroup (ie. called a second time with same label) then that is
+  * interpreted as a request to simply end that optgroup.
+  * Adds a special key=>value pair into the combo options collection.
+  * @param string $label The option group label to show.
+  */
+  function optgroup($label) {
+    if ($this->active_optgroup != "") {
+      if ($this->active_optgroup != $label) {
+        $this->optgroup_end();
+        $this->optgroup_start($label);
+      }
+      else {
+        $this->optgroup_end();
+      }
+    }
+    else {
+      $this->optgroup_start($label);
+    }
+  } // optgroup
+  // ....................................................................
+  /**
+  * Start an option group <optgroup label="blah">.
+  * Adds a special key=>value pair into the combo options collection
+  * suffixed by a counter so that each one is unique.
+  */
+  function optgroup_start($label) {
+    static $sogix = 0;
+    $this->additem(OPTGROUP_START . $sogix++, $label);
+    $this->active_optgroup = $label;
+  } // optgroup_end
+  // ....................................................................
+  /**
+  * End an option group ie. with a </optgroup>. Will do nothing if the
+  * active optgroup label is a nullstring, which indicates there is not
+  * an option group open.
+  * Adds a special key=>value pair into the combo options collection
+  * suffixed by a counter so that each one is unique.
+  */
+  function optgroup_end() {
+    static $eogix = 0;
+    if ($this->active_optgroup != "") {
+      $this->additem(OPTGROUP_END . $eogix++);
+      $this->active_optgroup = "";
+    }
+  } // optgroup_end
+  // ....................................................................
   /** Clears any existing items */
   function clearitems() {
     $this->itemlist->clearitems();
@@ -1293,21 +1479,28 @@ class form_combofield extends form_textfield {
   */
   function wml($name="") {
     $wml = "";
-    if ($name != "") $this->name = $name;
+    if ($name != "") {
+      $this->name = $name;
+    }
     $selix = $this->itemlist->getitemindex($this->value);
     if ($this->editable) {
       $wml .= "<select name='$this->name'";
-      if ($selix > 0) $wml .= " ivalue='$selix'";
+      if ($selix > 0) {
+        $wml .= " ivalue='$selix'";
+      }
       $wml .= ">";
       // Options list
       if ($this->itemlist->hasdata()) {
         foreach ($this->itemlist->data as $key => $displayvalue) {
-          $wml .= "<option value=" . $key . ">";
-          $wml .= $displayvalue . "</option>";
+          if (substr($key, 0, 9) != "OPT!GROUP") {
+            $wml .= "<option value=" . $key . ">";
+            $wml .= $displayvalue . "</option>";
+          }
         }
       }
       $wml .= "</select>";
-    } else {
+    }
+    else {
       $this->value = $this->itemlist->getitem($this->value);
       $f = new form_textfield($this->name, $this->label, $this->value, DISPLAY_ONLY, $this->style, $this->size);
       $wml = $f->wml();
@@ -1320,15 +1513,69 @@ class form_combofield extends form_textfield {
   * @return string The field as HTML.
   */
   function html($name="") {
+    global $RESPONSE;
+
     $html = "";
-    if ($name != "") $this->name = $name;
+
+    if ($name != "") {
+      $this->name = $name;
+    }
+
+    switch ($RESPONSE->ui_toolkit) {
+      case "dojo":
+        if ($this->multiselect) {
+          $RESPONSE->head->add_named_script(
+              "dojo.require('dijit.form.MultiSelect');\n"
+            . "function save_content_$this->name() {\n"
+            . " dojo.byId('$this->name').value=dijit.byId('_$this->name').getValue();\n"
+            . "}\n",
+              "dojo",
+              "javascript",
+              "append",
+              ADD_ONCE_ONLY
+              );
+          $this->set_attribute("dojoType", "dijit.form.MultiSelect");
+
+          // Hidden field for saving changed content - takes the name
+          // intended for this widget
+          $hidval = "";
+          if (is_array($this->value) && count($this->value) > 0) {
+            $hidval = implode(",", $this->value);
+          }
+          $hid = new form_hiddenfield($this->name, $hidval);
+          $html .= $hid->render();
+          
+          // This populates our hidden field for POSTs
+          $this->set_onchange("save_content_$this->name()");
+      
+          // Now we switch the name & id of this to $name prefixed by "_"
+          $name = $this->name;
+          $this->setname("_$name");
+          $this->setid("_$name");
+        }
+        else {
+          $RESPONSE->head->add_named_script(
+              "dojo.require('dijit.form.FilteringSelect');\n",
+              "dojo",
+              "javascript",
+              "append",
+              ADD_ONCE_ONLY
+              );
+          $this->set_attribute("dojoType", "dijit.form.FilteringSelect");
+        }
+        break;
+    } // switch
 
     // Standard SELECT in html..
     $saved_name = $this->name;
-    if ($this->multiselect) $this->name .= "[]";
+    if ($this->multiselect) {
+      $this->name .= "[]";
+    }
     $html .= "<select";
     $html .= $this->field_attributes();
-    if ($this->multiselect) $html .= " multiple";
+    if ($this->multiselect) {
+      $html .= " multiple";
+    }
     $html .= ">";
     $this->name = $saved_name;
 
@@ -1345,57 +1592,69 @@ class form_combofield extends form_textfield {
       $selvalues = "";
       foreach ($this->itemlist->data as $key => $displayvalue) {
         $selected = "";
-        if ($regexp != "") {
-          // Do regular expression match test..
-          if (!empty($regexp) && !empty($key)) {
-            if (ereg($regexp, $key)) {
-              $selected = "selected ";
-              $this->value = $key;
-            }
-          }
-        }
-        else {
-          // Might be in an array if multiselect..
-          if (is_array($this->value)) {
-            if (count($this->value) > 0) {
-              foreach($this->value as $elem) {
-                if ($key == $elem) {
-                  $selected = "selected ";
-                  break;
-                }
-              }
-            }
-            else {
-              // An empty array should match a nullstring..
-              if ($key == "") {
-                $selected = "selected ";
+        if (substr($key, 0, 9) != "OPT!GROUP") {
+          if ($regexp != "") {
+            # Do regular expression match test..
+            if (!empty($regexp) && !empty($key)) {
+              if (ereg($regexp, $key)) {
+                $selected = " selected";
+                $this->value = $key;
               }
             }
           }
           else {
-            // Do normal simple equality test. Take care over the
-            // sometime equivalence of 0 and nullstrings..
-            if ($this->value === "") {
-              if ($key === "") {
-                $selected = "selected ";
+            # Might be in an array if multiselect..
+            if (is_array($this->value)) {
+              if (count($this->value) > 0) {
+                foreach($this->value as $elem) {
+                  if ($key == $elem) {
+                    $selected = " selected";
+                    break;
+                  }
+                }
+              }
+              else {
+                # An empty array should match a nullstring..
+                if ($key == "") {
+                  $selected = " selected";
+                }
               }
             }
             else {
-              if ($key == $this->value) {
-                $selected = "selected ";
+              # Do normal simple equality test. Take care over the
+              # sometime equivalence of 0 and nullstrings..
+              if ($this->value === "") {
+                if ($key === "") {
+                  $selected = " selected";
+                }
+              }
+              else {
+                if ($key == $this->value) {
+                  $selected = " selected";
+                }
               }
             }
           }
+          # Render the select option..
+          $html .= "<option value=\"$key\"" . $selected . ">$displayvalue</option>";
+  
+          // Remember selected values..
+          if ($selected != "") {
+            if ($selvalues != "") {
+              $selvalues .= ",";
+            }
+            $selvalues .= $key;
+          }
         }
-        // Render the select option..
-        $html .= "<option " . $selected . "value=\"$key\">$displayvalue</option>";
-
-        // Remember selected values..
-        if ($selected != "") {
-          if ($selvalues != "") {
-            $selvalues .= ",";
+        # optgroup output
+        else {
+          $bits = explode("_", $key);
+          if ($bits[1] == "START") {
+            $html .= "<optgroup label=\"$displayvalue\">";
+          }
+          else {
+            $html .= "</optgroup>";
           }
-          $selvalues .= $key;
         }
       }
     }
@@ -1407,7 +1666,9 @@ class form_combofield extends form_textfield {
       // Implement as hidden field value, plus visible
       // normal text display-value..
       $name = $this->name;
-      if ($this->multiselect) $name .= "[]";
+      if ($this->multiselect) {
+        $name .= "[]";
+      }
       $hidf = new form_hiddenfield($name, $selvalues);
       $html .= $hidf->render();
     }
@@ -1525,7 +1786,7 @@ class form_jumpmenu extends form_combofield {
         $html .= " onclick=\"javascript:document.location.href='$jumpurl'\"";
         $html .= ">";
         $html .= $displayvalue;
-        $html .= '</option>';
+        $html .= "</option>";
       }
     }
     $html .= "</select>";
@@ -1574,6 +1835,19 @@ class form_memofield extends form_textfield {
     $this->rows = $rows;
     $this->type = "textarea";
     $this->wrapmode = $wrapmode;
+    global $RESPONSE;
+    switch ($RESPONSE->ui_toolkit) {
+      case "dojo":
+        $RESPONSE->head->add_named_script(
+            "dojo.require('dijit.form.SimpleTextarea');\n",
+            "dojo",
+            "javascript",
+            "append",
+            ADD_ONCE_ONLY
+            );
+        $this->set_attribute("dojoType", "dijit.form.SimpleTextarea");
+        break;
+    } // switch
   } // form_memofield
   // ....................................................................
   /**
@@ -1591,6 +1865,7 @@ class form_memofield extends form_textfield {
   */
   function html($name="") {
     global $RESPONSE;
+    
     // Figure out a legal wrapmode..
     if (isset($RESPONSE)) {
       if ($RESPONSE->browser == BROWSER_MOZILLA || $RESPONSE->browser == BROWSER_NETSCAPE) {
@@ -1651,6 +1926,19 @@ class form_checkbox extends form_field {
     if ($value != "") $this->value = $value;
     else $this->value = $name;
     $this->type = "checkbox";
+    global $RESPONSE;
+    switch ($RESPONSE->ui_toolkit) {
+      case "dojo":
+        $RESPONSE->head->add_named_script(
+            "dojo.require('dijit.form.CheckBox');\n",
+            "dojo",
+            "javascript",
+            "append",
+            ADD_ONCE_ONLY
+            );
+        $this->set_attribute("dojoType", "dijit.form.CheckBox");
+        break;
+    } // switch
   } // form_checkbox
   // ....................................................................
   /** Sets the checkbox to the checked state. */
@@ -1667,12 +1955,12 @@ class form_checkbox extends form_field {
   * This renders the field as HTML.
   * @return string The field as HTML.
   */
-  function html($name="") {
+  function html($name="") {    
     if ($name != "") $this->name = $name;
     $html  = "<input";
     $html .= " type=\"checkbox\"";
     $html .= $this->field_attributes();
-    if ($this->checked) $html .= " checked";
+    if ($this->checked) $html .= " checked=\"checked\"";
     $html .= " value=\"$this->value\"";
     $html .= ">";
     // Only send the readonly field if its checked..
@@ -1704,12 +1992,25 @@ class form_radiobutton extends form_field {
   * @param string  $css      CSS class or style to apply to the button
   * @param boolean $checked  True if element should be checked/ticked
   */
-  function form_radiobutton($name="", $label="", $value="", $editable=EDITABLE, $css="", $checked=FALSE) {
+  function form_radiobutton($name="", $label="", $value="", $editable=EDITABLE, $css="", $checked=false) {
     $this->form_field($name, $label, $value, $editable, $css="");
     $this->checked = $checked;
     if ($value != "") $this->value = $value;
     else $this->value = $name;
-    $this->type = "radio";
+    $this->type = "radio";    
+    global $RESPONSE;
+    switch ($RESPONSE->ui_toolkit) {
+      case "dojo":
+        $RESPONSE->head->add_named_script(
+            "dojo.require('dijit.form.CheckBox');\n",
+            "dojo",
+            "javascript",
+            "append",
+            ADD_ONCE_ONLY
+            );
+        $this->set_attribute("dojoType", "dijit.form.RadioButton");
+        break;
+    } // switch
   } // form_radiobutton
   // ....................................................................
   /** Sets the checkbox to the checked state. */
@@ -1731,7 +2032,7 @@ class form_radiobutton extends form_field {
     $html  = "<input";
     $html .= " type=\"radio\"";
     $html .= $this->field_attributes();
-    if ($this->checked) $html .= " checked";
+    if ($this->checked) $html .= " checked=\"checked\"";
     $html .= " value=\"$this->value\"";
     $html .= ">";
     if (!$this->editable) {
@@ -1770,6 +2071,7 @@ class form_radiogroup extends form_combofield {
   */
   function form_radiogroup($name="", $label="", $value="", $editable=EDITABLE, $css="", $orientation="horizontal") {
     $this->form_combofield($name, $label, $value, $editable, $css);
+    $this->remove_attribute("dojoType");
     $this->orientation = $orientation;
     if ($value != "") $this->value = $value;
     else $this->value = $name;
