@@ -61,7 +61,7 @@ class forum extends HTMLObject {
   var $new_topic;
 
   // forum title
-  var $forum_title = "Default Axyl Forums";
+  var $forum_title = "Axyl Forums";
   var $error_msg;
 
   var $forum_threads = array();
@@ -69,7 +69,6 @@ class forum extends HTMLObject {
 
   function forum ($forum_id=NEW_FORUM) {
     // Forum constructor.
-    debugbr("FORUM CONSTRUCTOR.");
     $forum_id = trim($forum_id);
     $this->forum_id = $forum_id;
     if ( $this->forum_id != NEW_FORUM && is_numeric($this->forum_id)) {
@@ -97,13 +96,7 @@ class forum extends HTMLObject {
       $this->forum_desc = $qQ->field("forum_desc");
       $this->enabled = $qQ->istrue("enabled");
       $this->private = $qQ->istrue("private");
-      debugbr("moderators: ".$qQ->field("moderator"));
       $this->moderator = $qQ->field("moderator");
-      /*if ( substr_count($this->moderator, ',') == 0 && trim($this->moderator) != "" ) {
-        $this->moderator[] = $qQ->field("moderator");
-      } else {
-        $this->moderator[]  = explode(',',$qQ->field("moderator"));
-      }*/
       $this->get_threads();
 
       // get forum members if it's a private forum
@@ -113,7 +106,7 @@ class forum extends HTMLObject {
 
         if ( $mM->hasdata ) {
           do {
-            $this->forum_members[$mM->fields("user_id")] = $mM->fields("user_id");
+            $this->forum_members[$mM->field("user_id")] = $mM->field("user_id");
           } while ( $mM->get_next() );
         }
       } // load members for private forum
@@ -131,7 +124,8 @@ class forum extends HTMLObject {
       $query = new dbinsert("ax_forum");
       $fid = get_next_sequencevalue("seq_forum_id", "ax_forum", "forum_id");
       $query->set("forum_id", $fid);
-    } else {
+    }
+    else {
       // is an update
       $query = new dbupdate("ax_forum");
       $query->where("forum_id=$this->forum_id");
@@ -141,13 +135,11 @@ class forum extends HTMLObject {
     $query->set("forum_desc", $this->forum_desc);
     $query->set("enabled", $this->enabled);
     $query->set("private", $this->private);
-    //$query->set("moderator", implode(',',$this->moderator));
     $query->set("moderator", $this->moderator);
 
     if ( $query->execute() ) {
       $this->error_msg = "Forum Record SAVED.";
       unset($mode);
-      unset($forum_id);
       if ( $this->forum_id == NEW_FORUM ) {
         $this->forum_id = $fid;
       }
@@ -158,7 +150,8 @@ class forum extends HTMLObject {
     // add a member to a private forum.
     if ($this->private) {
 
-    } else {
+    }
+    else {
       // this is a public board.
       // raise error and display
       $this->error_msg = "This is a PUBLIC forum. No need to add members to it, as all members have access to it.";
@@ -167,15 +160,12 @@ class forum extends HTMLObject {
 
   function new_topic () {
     // start a new thread in this forum
-    debugbr("forum_id within new_topic function: $this->forum_id");
     $this->new_topic = new forum_thread(NEW_THREAD, $this->forum_id);
   } // new_topic
 
   function get_threads() {
     // get the parent msgs for this forum
-    debugbr("AQUIRING THREADS! FORUM_ID=$this->forum_id");
     if ( $this->forum_id != NEW_FORUM ) {
-      debugbr("GETTING THREAD HEADERS!!!");
       $q = "select msg_id from ax_forum_msg where forum_id=$this->forum_id and ";
       $q .= "parent_thread_id is null order by sticky desc, last_modified desc";
       $qQ = new dbrecords($q);
@@ -215,8 +205,6 @@ class forum extends HTMLObject {
 
     $s = "";
 
-    debugbr("and the current mode is: $mode");
-
     if ( isset($BackForum_x) || isset($CancelForum_x) ) {
       $mode = '';
     }
@@ -290,7 +278,8 @@ class forum extends HTMLObject {
           $forumpriv = new form_checkbox("private");
           if ($this->private) {
             $forumpriv->check();
-          } else {
+          }
+          else {
             $forumpriv->uncheck();
           }
           $T->tr();
@@ -312,18 +301,17 @@ class forum extends HTMLObject {
           $T->td_alignment("right");
           $T->td($forumenabled->render(), "axchkbox");
 
-          debugbr("moderators: $this->moderators");
-          debugbr("is array? ".is_array($this->moderators));
-          debugbr("count of array: ".count($this->moderators));
-          //debugbr("list of moderators: ".implode(', ', $this->moderators));
-
           // Moderator
           $fm = "select u.user_id from ax_user u";
           if ( !$RESPONSE->ismemberof_group_in("Admin,Editor") ) {
             $tmp = ", ax_user_group ug where u.user_id=ug.user_id and ug.group_id=2";
           }
-          if ( trim($tmp) != "" ) $fm .= " $tmp and u.user_id != 'guest' order by lower(u.user_id)";
-          else $fm .= " where u.user_id != 'guest' order by lower(u.user_id)";
+          if ( trim($tmp) != "" ) {
+            $fm .= " $tmp and u.user_id != 'guest' order by lower(u.user_id)";
+          }
+          else {
+            $fm .= " where u.user_id != 'guest' order by lower(u.user_id)";
+          }
           $FM = new dbrecords($fm);
           $forummoderator = new form_combofield("moderator", "", $this->moderator, EDITABLE, "", 1, SINGLESELECT);
           $forummoderator->setstyle("width: 250");
@@ -353,7 +341,8 @@ class forum extends HTMLObject {
           $F->set_fieldwidth_pct(100);
           $F->add($T);
           $s = $F->render();
-        } else {
+        }
+        else {
           $T->tr();
           $T->td("Only site Admins and Editors can create/delete or edit forums.");
           $s = $T->render();
@@ -363,7 +352,6 @@ class forum extends HTMLObject {
       case "edmsg":
         // admins/editors and moderators can edit any message within a given forum
         if ( $RESPONSE->ismemberof_group_in("Admin,Editor") || $RESPONSE->userid == trim($this->moderator) ) {
-          debugbr("<font color=\"red\">EDIT MESSAGE SECTION 1</font>");
           $F = new form("EditMsg");
           $F->set_fieldwidth_pct(100);
           $F->add($this->forum_threads[$thread_id]);
@@ -373,7 +361,6 @@ class forum extends HTMLObject {
       case "delthd":
         // allows an admin / editor to delete a particular message
         if ( $RESPONSE->ismemberof_group_in("Admin,Editor") || $RESPONSE->userid == trim($this->moderator) ) {
-          debugbr("DELETING THREAD #$msg_id");
           if ( dbcommand("delete from ax_forum_msg where msg_id=$thread_id or parent_thread_id=$thread_id") ) {
             unset($this->forum_threads);
             $this->get_threads();
@@ -384,7 +371,6 @@ class forum extends HTMLObject {
         // get the thread.
         $thd = $this->forum_threads[$thread_id];
 
-        debugbr("<font color=\"red\">is thread an object: ".is_object($thd)."</font>");
         if ( trim($this->forum_id) != "" /*&& is_object($thd)*/ ) {
           // check the locked thread situation
           if ( ($RESPONSE->ismemberof_group_in("Admin,Editor") || $RESPONSE->userid == trim($this->moderator))
@@ -408,11 +394,9 @@ class forum extends HTMLObject {
               && (trim($sticky) == 1 || trim($sticky) == 0) ) {
             switch ($sticky) {
               case "1":
-                debugbr("<font color=\"red\">STICKY THREAD</font>");
                 $thd->stick_thread();
                 break;
               case "0":
-                debugbr("<font color=\"red\">UNSTICKY THREAD</font>");
                 $thd->unstick_thread();
                 break;
             }
@@ -453,30 +437,29 @@ class forum extends HTMLObject {
           if ( count($this->forum_threads) > 0 ) {
             // display the threads
             foreach ($this->forum_threads as $thread) {
-              //debugbr("<font color=\"red\">THREAD LOCKED: $thread->locked</font>");
               if ( trim($thread->subject) == "" ) $thread->subject = "(no thread topic)";
               debugbr("<font color=\"red\">MODERATOR: $thread->moderator</font>");
               debugbr("<font color=\"red\">$RESPONSE->userid ==== $thread->moderator</font>");
 
               if ($thread->enabled) {
                 if ($thread->locked && !$thread->sticky) {
-                  debugbr("<font color=\"red\">THREAD LOCKED AND ENABLED</font>");
                   $href = "$RESPONSE->requested?forum_id=$this->forum_id&thread_id=$thread->thread_id&mode=viewthread";
                   $tname = "<a href=\"$href\"><span class=\"axlocked\">$thread->subject</span></a>";
-                } elseif (!$thread->locked && $thread->sticky) {
-                  debugbr("<font color=\"red\">THREAD STICKY AND ENABLED</font>");
+                }
+                elseif (!$thread->locked && $thread->sticky) {
                   $href = "$RESPONSE->requested?forum_id=$this->forum_id&thread_id=$thread->thread_id&mode=viewthread";
                   $tname = "STICKY: <a href=\"$href\"><span class=\"axforumlink\">".strtoupper($thread->subject)."</span></a>";
-                } elseif ($thread->locked && $thread->sticky) {
-                  debugbr("<font color=\"red\">THREAD LOCKED AND STICKY AND ENABLED</font>");
+                }
+                elseif ($thread->locked && $thread->sticky) {
                   $href = "$RESPONSE->requested?forum_id=$this->forum_id&thread_id=$thread->thread_id&mode=viewthread";
                   $tname = "STICKY: <a href=\"$href\"><span class=\"axlocked\">".strtoupper($thread->subject)."</span></a>";
-                } else {
-                  debugbr("<font color=\"red\">THREAD UNLOCKED AND NOT STICKY AND ENABLED</font>");
+                }
+                else {
                   $href = "$RESPONSE->requested?forum_id=$this->forum_id&thread_id=$thread->thread_id&mode=viewthread";
                   $tname = "<a href=\"$href\"><span class=\"axforumlink\">$thread->subject</span></a>";
                 }
-              } else {
+              }
+              else {
               	$href = "$RESPONSE->requested?forum_id=$this->forum_id&thread_id=$thread->thread_id&mode=viewthread";
                 $tname = "<a href=\"$href\"><span class=\"axforumlocked\">$thread->subject</span></a>";
               }
@@ -484,23 +467,21 @@ class forum extends HTMLObject {
               if ( $RESPONSE->ismemberof_group_in("Admin,Editor") || $RESPONSE->userid == trim($thread->moderator) ) {
                 if ($this->enabled) {
                   if (!$thread->locked) {
-                    //debugbr("<font color=\"red\">THREAD UNLOCKED</font>");
                     $tname .= "<br>";
                     $href = "$RESPONSE->requested?forum_id=$this->forum_id&thread_id=$thread->thread_id&mode=view&locked=1";
                     $tname .= "<a href=\"$href\"><span class=\"axforumlinkother\">[LOCK]</span></a>";
-                  } else {
-                    //debugbr("<font color=\"red\">THREAD LOCKED</font>");
+                  }
+                  else {
                     $tname .= "<br>";
                     $href = "$RESPONSE->requested?forum_id=$this->forum_id&thread_id=$thread->thread_id&mode=view&locked=0";
                     $tname .= "<a href=\"$href\"><span class=\"axforumlinkother\">[UNLOCK]</span></a>";
                   }
 
                   if (!$thread->sticky) {
-                    //debugbr("<font color=\"red\">THREAD NOT STICKY</font>");
                     $href = "$RESPONSE->requested?forum_id=$this->forum_id&thread_id=$thread->thread_id&mode=view&sticky=1";
                     $tname .= "<a href=\"$href\"><span class=\"axforumlinkother\">[STICK]</span></a>";
-                  } else {
-                    //debugbr("<font color=\"red\">THREAD STICKY</font>");
+                  }
+                  else {
                     $href = "$RESPONSE->requested?forum_id=$this->forum_id&thread_id=$thread->thread_id&mode=view&sticky=0";
                     $tname .= "<a href=\"$href\"><span class=\"axforumlinkother\">[UNSTICK]</span></a>";
                   }
@@ -526,16 +507,12 @@ class forum extends HTMLObject {
               $T->td_colspan(4);
             } // foreach
           } // if count(array) > 0
-        } else {
+        }
+        else {
           if ( trim($this->forum_id) == "" ) {
             $T->tr();
             $T->td("That Forum Id does not exist within the database");
           }
-
-          /*if ( !is_object($thd) ) {
-            $T->tr();
-            $T->td("That Thread does not exist within the selected Forum");
-          }*/
         }
 
         $s = $T->render();
@@ -548,7 +525,8 @@ class forum extends HTMLObject {
           $F->set_fieldwidth_pct(100);
           $F->add($this->new_topic);
           $s = $F->render();
-        } else {
+        }
+        else {
           $T->tr();
           $T->td("You must be logged in in order to post a forum thread.");
           $s = $T->render();
@@ -563,7 +541,8 @@ class forum extends HTMLObject {
             $F->set_fieldwidth_pct(100);
             $F->add($thread);
             $s = $F->render();
-          } else {
+          }
+          else {
             $T->tr();
             $T->td("This either LOCKED or DISABLED, and as a result, cannot by replied to.");
             $s = $T->render();
@@ -578,21 +557,20 @@ class forum extends HTMLObject {
         // allows an admin / editor to delete a particular message
         // dbcommand("delete from ax_forum_msg where msg_id=$msg_id and parent_thread_id=$msg_id");
         if ( $RESPONSE->ismemberof_group_in("Admin,Editor") || $RESPONSE->userid == trim($this->moderator) ) {
-          debugbr("DELETING MESSAGE #$msg_id");
           dbcommand("delete from ax_forum_msg where msg_id=$msg_id");
         }
       case "viewthread":
         // view the messages within the thread
         if ( $this->forum_threads[$thread_id] ) {
           $thread = $this->forum_threads[$thread_id];
-          debugbr("thread object: $thread");
           if ( !isset($BackMsg_x) && !isset($CancelMsg_x) && !isset($SaveThread_x) && 
                !isset($SaveMsg_x) && trim($mode) != "edmsg" ) {
             $thread->inc_thread_views();
           }
 
           $s = $thread->render();
-        } else {
+        }
+        else {
           $T->tr();
           $T->td("That Thread Id does not exist within the database.");
           $s = $T->render();
@@ -604,13 +582,13 @@ class forum extends HTMLObject {
         if ( $RESPONSE->ismemberof_group_in("Admin,Editor") ) {
           if ( trim($hide) == 't' ) {
             $this->enable_forum();
-          } else {
+          }
+          else {
             $this->disable_forum();
           }
           $this->save_forum();
           if ( trim($hide) != "" ) {
             // enable or disable all threads & messages within this forum as required.
-            debugbr("ENABLING/DISABLING FORUM THREADS AND MESSAGES");
             $query = new dbupdate("ax_forum_msg");
             $query->where("forum_id=$this->forum_id");
             $query->set("enabled", $this->enabled);
@@ -620,7 +598,6 @@ class forum extends HTMLObject {
         //break;
       default:
         // display the forums that already exist.
-        debugbr("this is the default mode. displaying the forums list");
         $q = "select * from ax_forum";
         if ( !$RESPONSE->ismemberof_group_in("Admin,Editor") ) {
           $q .= " where enabled=TRUE";
@@ -654,7 +631,8 @@ class forum extends HTMLObject {
             if (!$qQ->istrue("enabled")) {
               $href = "$RESPONSE->requested?forum_id=".$qQ->field("forum_id")."&mode=view";
               $fname = "<a href=\"$href\"><span class=\"axforumlocked\">".strtoupper($qQ->field("forum_name"))."</span></a>";
-            } else {
+            }
+            else {
               $href = "$RESPONSE->requested?forum_id=".$qQ->field("forum_id")."&mode=view";
               $fname = "<a href=\"$href\"><span class=\"axforumlink\">".strtoupper($qQ->field("forum_name"))."</span></a>";
             }
@@ -670,19 +648,19 @@ class forum extends HTMLObject {
               if (!$qQ->istrue("enabled")) {
               	$href = "$RESPONSE->requested?forum_id=".$qQ->field("forum_id")."&mode=hidden&hide=t";
                 $T->td("<a href=\"$href\"><span class=\"axforumlink\">[ENABLE]</span></a>");
-              } else {
+              }
+              else {
               	$href = "$RESPONSE->requested?forum_id=".$qQ->field("forum_id")."&mode=hidden&hide=f";
                 $T->td("<a href=\"$href\"><span class=\"axforumlink\">[DISABLE]</span></a>");
               }
               $T->td_width("10%");
-            } else {
+            }
+            else {
               $T->td_colspan(4);
             }
-            //if ( $RESPONSE->ismemberof_group_in("Admin,Editor") ) {
-              $T->tr();
-              $T->td("<hr>");
-              $T->td_colspan(4);
-            //}
+            $T->tr();
+            $T->td("<hr>");
+            $T->td_colspan(4);
           } while ( $qQ->get_next() );
         }
 
@@ -702,12 +680,9 @@ class forum extends HTMLObject {
     global $msg_subject, $msg_text, $date_posted, $author, $mode;
     global $msg_id, $thread_id;
 
-    debugbr("POST PROCESS!!!");
-
     if ( isset($SaveForum_x) ) {
       // saving new and modified forum details
       if ( trim($forum_name) != "" ) {
-        debugbr("SAVING FORUM!!!");
         $this->forum_name = trim($forum_name);
         $this->forum_desc = trim($forum_desc);
         $this->enabled    = isset($enabled);
@@ -716,18 +691,17 @@ class forum extends HTMLObject {
 
         $this->save_forum();
         $mode = '';
-      } else {
-        debugbr("NOT SAVING FORUM!!!");
+      }
+      else {
         if (trim($forum_name) == "") {
           debugbr("FORUM NAME IS BLANK!");
           $this->error_msg .= "Forum must have a NAME.";
         }
       }
-    } else
-    if ( isset($SaveThread_x) ) {
+    }
+    elseif ( isset($SaveThread_x) ) {
       // saving new thread post
       if ( trim($msg_subject) != "" ) {
-        debugbr("SAVING THREAD!!!");
         $this->new_topic();
         $this->new_topic->subject = trim($msg_subject);
         $this->new_topic->text = trim($msg_text);
@@ -736,23 +710,16 @@ class forum extends HTMLObject {
         $this->new_topic->save_thread();
         $this->get_threads();
         $mode = 'viewthread';
-      } else {
-        debugbr("NOT SAVING THREAD!!!");
+      }
+      else {
         if (trim($msg_subject) == "") {
-          debugbr("THREAD'S SUBJECT IS BLANK!");
           $this->new_topic->newmsg->error_msg .= "Thread must have a SUBJECT.";
         }
-
       }
-    } else
-    if ( isset($SaveMsg_x) ) {
-      debugbr("SAVING THE MESSAGE REPLY!!! OR MSG EDIT");
+    }
+    elseif ( isset($SaveMsg_x) ) {
       if ( trim($msg_subject) != "" ) {
-        debugbr("SAVING MSG!!!");
-        debugbr("msg_id = $msg_id and thread_id = $thread_id");
-        debugbr("subject: $msg_subject, text: $msg_text");
         $thread = $this->forum_threads[$thread_id];
-
         if ( trim($mode) != "edmsg" ) {
           $thread->new_msg();
           $thread->newmsg->msg_subject = trim($msg_subject);
@@ -762,23 +729,19 @@ class forum extends HTMLObject {
           if ( $thread->newmsg->save_msg() ) {
             $thread->modify_replies();
           }
-        } else {
+        }
+        else {
           $thread->render();
           $thread->get_thread_header();
           $thread->get_thread();
         }
         $mode = 'viewthread';
-      } else {
-        debugbr("NOT SAVING THREAD!!!");
+      }
+      else {
         if (trim($msg_subject) == "") {
-          debugbr("MSG'S SUBJECT IS BLANK!");
           $thread->error_msg .= "Message must have a SUBJECT.";
         }
-
       }
-      // reset the mode so it doesn't stay at the enter msg screen.
-      //$mode = "viewthread";
-      //$this->render();
     }
   } // POSTprocess
 } // class forum
@@ -811,12 +774,9 @@ class forum_thread extends forum {
       $this->thread_id = trim($thread_id);
       $this->forum_id = trim($forum_id);
     }
-    debugbr("thread_id within the thread object: $this->thread_id");
     if ( $this->thread_id != NEW_THREAD && is_numeric($this->thread_id) ) {
-      debugbr("getting the thread head message");
       $this->get_thread_header();
     }
-
     if ( $this->thread_id == NEW_THREAD ) {
       $this->newmsg = new thread_msg(NEW_MSG, $this->thread_id);
     }
@@ -853,15 +813,14 @@ class forum_thread extends forum {
     // remember, it's just a message that has no parent message.
     global $mode, $thread_id;
 
-    debugbr("the forum_id = $this->forum_id");
-
     if ( trim($this->thread_id) == NEW_THREAD ) {
       // then it's an insert
       $query = new dbinsert("ax_forum_msg");
       $tid = get_next_sequencevalue("seq_msg_id", "ax_forum_msg", "msg_id");
       $query->set("msg_id", $tid);
       $query->set("last_modified", 'now()');
-    } else {
+    }
+    else {
       // else it's an update
       $query = new dbupdate("ax_forum_msg");
       $query->where("msg_id=$this->thread_id");
@@ -924,7 +883,6 @@ class forum_thread extends forum {
 
   function inc_thread_views() {
     // this function writed to the views field in the thread message
-    debugbr("<font color=\"red\">UPDATING THE VIEWS</font>");
     $this->views = $this->views + 1;
     $tup = new dbupdate("ax_forum_msg");
     $tup->set("views", $this->views);
@@ -934,7 +892,6 @@ class forum_thread extends forum {
 
   function modify_replies() {
     // adjusts the threads replies field
-    debugbr("<font color=\"red\">UPDATING THE REPLIES</font>");
     $this->replies = $this->replies + 1;
     $tup = new dbupdate("ax_forum_msg");
     $tup->set("replies", $this->replies);
@@ -956,7 +913,6 @@ class forum_thread extends forum {
       // increment the "views" field in the thread record.
       //$this->inc_thread_views();
     }
-    debugbr("the count of msgs in this thread: ".count($this->thread_msgs));
   } // get_thread
 
   function new_msg() {
@@ -972,7 +928,8 @@ class forum_thread extends forum {
     $s = "";
     if ( $this->thread_id == NEW_THREAD ) {
       $s = $this->newmsg->new_msg();
-    } else {
+    }
+    else {
       switch ($mode) {
       case "reply":
         $this->new_msg();
@@ -980,11 +937,11 @@ class forum_thread extends forum {
         break;
       case "edmsg":
         // edit a message. admin and editor function only.
-        debugbr("EDITING THE MESSAGE");
         $emsg = new thread_msg($msg_id, $this->thread_id);
         if ( !isset($SaveMsg_x) ) {
           $s = $emsg->edit_msg();
-        } else {
+        }
+        else {
           $emsg->msg_subject = trim($msg_subject);
           $emsg->msg_text = trim($msg_text);
           $emsg->save_msg();
@@ -1006,7 +963,8 @@ class forum_thread extends forum {
         $fl = "<a href=\"$RESPONSE->requested?mode=\"><span class=\"axforumsectionnav\">Forum List</span></a>";
         if ($this->locked) {
           $T->td("$fl >> $tl >> <b>$this->subject (This thread has been LOCKED)</b>", "axforumsectionnav");
-        } else {
+        }
+        else {
           $T->td("$fl >> $tl >> <b>$this->subject</b>", "axforumsectionnav");
         }
         $T->td_colspan(2);
@@ -1025,7 +983,8 @@ class forum_thread extends forum {
         if ($this->enabled && !$this->locked) {
           $href = "$RESPONSE->requested?mode=reply&forum_id=$this->forum_id&thread_id=$this->thread_id&quote=$this->thread_id";
           $quote = "<a href=\"$href\"><span class=\"axmsglinkother\">[REPLY]</span></a>";
-        } else {
+        }
+        else {
           $quote = "&nbsp;";
         }
         if ( $RESPONSE->ismemberof_group_in("Admin,Editor")  || $RESPONSE->userid == trim($this->moderator) ) {
@@ -1056,7 +1015,6 @@ class forum_thread extends forum {
           foreach ( $this->thread_msgs as $msg ) {
             // display the thread header message
             // subject
-            debugbr("subject: $msg->msg_subject, text: $msg->msg_text");
             if ( trim($temp) != "" ) {
               $T->tr();
               $T->td("<hr>");
@@ -1072,7 +1030,8 @@ class forum_thread extends forum {
             if ($this->enabled && !$this->locked) {
           	  $href = "$RESPONSE->requested?mode=reply&forum_id=$msg->forum_id&thread_id=$msg->thread_id&quote=$msg->msg_id";
               $quote = "<a href=\"$href\"><span class=\"axmsglinkother\">[REPLY]</span></a>";
-            } else {
+            }
+            else {
               $quote = "&nbsp;";
             }
             if ( $RESPONSE->ismemberof_group_in("Admin,Editor")  || $RESPONSE->userid == trim($this->moderator)) {
@@ -1112,7 +1071,8 @@ class forum_thread extends forum {
 	            $TQ->td($qs, "axqoutedtext");
 	            
 	            $quote = $TQ->render();
-            } else {
+            }
+            else {
             	$quote = "";
             	$msg = $msg_text;
             }
@@ -1156,7 +1116,6 @@ class thread_msg extends forum_thread {
   function thread_msg ($msg_id=NEW_MSG, $thread_id) {
     // Msg Constructor
 
-    debugbr("message_id: $msg_id and thread_id: $thread_id");
     if ( isset($thread_id) ) {
       $this->thread_id = trim($thread_id);
       $this->msg_id = trim($msg_id);
@@ -1171,7 +1130,6 @@ class thread_msg extends forum_thread {
 
   function get_msg() {
     // get the message object
-    debugbr("getting the message to EDIT");
     $q  = "select *, to_char(last_modified, 'DD/MM/YYYY HH:MI am') as date_posted ";
     $q .= "from ax_forum_msg where msg_id=$this->msg_id";
     $qQ = new dbrecords($q);
@@ -1212,13 +1170,13 @@ class thread_msg extends forum_thread {
       $query->set("msg_id", $mid);
       $query->set("parent_thread_id", $this->thread_id);
       $query->set("msg_author", $this->author);
-      //$query->set("last_modified", $this->date_posted);
       $query->set("last_modified", 'now()');
       $query->set("forum_id", trim($forum_id));
       $query->set("enabled", $this->enabled);
       $query->set("sticky", $this->sticky);
       $query->set("locked", $this->locked);
-    } else {
+    }
+    else {
       // else it's an update
       $query = new dbupdate("ax_forum_msg");
       $query->where("msg_id=$this->msg_id");
@@ -1236,7 +1194,6 @@ class thread_msg extends forum_thread {
       if ( $this->msg_id == NEW_MSG && $this->thread_id != NEW_THREAD ) {
         $q = new dbupdate("ax_forum_msg");
         $q->where("msg_id=$this->thread_id");
-
         $q->set("last_modified", "now()");
         $q->execute();
       }
@@ -1244,7 +1201,10 @@ class thread_msg extends forum_thread {
       // set the msg id
       $this->msg_id = $mid;
       return TRUE;
-    } else { return FALSE; }
+    }
+    else {
+      return FALSE;
+    }
   } // save_msg
 
   function display_msg() {
@@ -1302,9 +1262,8 @@ class thread_msg extends forum_thread {
         $oldsub = $Q->field("msg_subject");
         $this->msg_subject = "RE: ".$Q->field("msg_subject");
         $oldtxt = $Q->field("msg_text");
-
-		$quote = str_replace("[quote]", "", $Q->field("msg_text"));
-		$quote = str_replace("[/quote]", "", $quote);
+		    $quote = str_replace("[quote]", "", $Q->field("msg_text"));
+		    $quote = str_replace("[/quote]", "", $quote);
         $this->msg_text  = "[quote]".$quote."[/quote]\n\n";
       }
     }
@@ -1334,8 +1293,8 @@ class thread_msg extends forum_thread {
       $T->td_alignment("right", "top");
       $T->td_width("25%");
       $oldtxt = str_replace("[quote]", "", $oldtxt);
-	  $oldtxt = str_replace("[/quote]", "", $oldtxt);
-	  $oldtxt = str_replace("\n", "<br>", $oldtxt);
+	    $oldtxt = str_replace("[/quote]", "", $oldtxt);
+	    $oldtxt = str_replace("\n", "<br>", $oldtxt);
       $T->td($oldtxt, "axmsgtext");
       $T->tr();
       $T->td("<hr>");
@@ -1343,20 +1302,15 @@ class thread_msg extends forum_thread {
 
       $pb = new form_imagebutton("SaveMsg", "Save Msg", "", "$LIBDIR/img/_save.gif", "", 57, 15);
       $cb = new form_imagebutton("CancelMsg", "Cancel", "", "$LIBDIR/img/_cancel.gif", "", 57, 15);
-      //$bb = new form_imagebutton("BackMsg", "Back To Msgs", "", "$LIBDIR/img/_back.gif", "", 42, 15);
-    } else {
+    }
+    else {
       $T->tr();
       $T->td("&nbsp;");
       $T->td("NEW THREAD", "axforumformheadings");
-      /*$T->td_contentcss("font-size:12pt;
-                         color: #FF6600;
-                         font-weight: bold;");*/
       $pb = new form_imagebutton("SaveThread", "Save Thread", "", "$LIBDIR/img/_save.gif", "", 57, 15);
       $cb = new form_imagebutton("CancelThread", "Cancel", "", "$LIBDIR/img/_cancel.gif", "", 57, 15);
-      //$bb = new form_imagebutton("BackThread", "Back To Threads", "", "$LIBDIR/img/_back.gif", "", 42, 15);
     }
 
-    debugbr("error message: $this->error_msg");
     if ( trim($this->error_msg) != "" ) {
       $T->tr();
       $T->td($this->error_msg, "formerror");
@@ -1373,15 +1327,11 @@ class thread_msg extends forum_thread {
     //$T->td_contentcss("font-size:9pt");
     $T->tr();
     $T->td("Subject:&nbsp;", "axforumform");
-    /*$T->td_contentcss("font-size:9pt;
-                       color: #FF6600;");*/
     $T->td_width("25%");
     $T->td_alignment("right");
     $T->td($ms->render());
     $T->tr();
     $T->td("Text:&nbsp;", "axforumform");
-    /*$T->td_contentcss("font-size:9pt;
-                       color: #FF6600;");*/
     $T->td_width("25%");
     $T->td_alignment("right", "top");
     $T->td($mt->render());
@@ -1414,20 +1364,6 @@ class thread_msg extends forum_thread {
     global $RESPONSE, $LIBDIR, $forum_id, $mode;
     global $quote;
 
-    // set the non-entered fields for a message
-
-    debugbr("===================================================");
-    debugbr("message id: $this->msg_id");
-    debugbr("thread id: $this->thread_id");
-    debugbr("message subject: $this->msg_subject");
-    debugbr("message text: $this->msg_text");
-    debugbr("author: $this->author");
-    debugbr("date posted: $this->date_posted");
-    debugbr("enabled: $this->enabled");
-    debugbr("parent message id: $this->ParentMsg");
-    debugbr("forum id: $this->forum_id");
-    debugbr("===================================================");
-
     $s = "";
 
     // form objects.
@@ -1447,13 +1383,9 @@ class thread_msg extends forum_thread {
     $T->tr();
     $T->td("&nbsp;");
     $T->td("EDIT MESSAGE / THREAD", "axforumformheadings");
-    /*$T->td_contentcss("font-size:12pt;
-                       color: #FF6600;
-                       font-weight: bold;");*/
     $pb = new form_imagebutton("SaveMsg", "Save Msg", "", "$LIBDIR/img/_save.gif", "", 57, 15);
     $cb = new form_imagebutton("CancelMsg", "Cancel", "", "$LIBDIR/img/_cancel.gif", "", 57, 15);
 
-    debugbr("error message: $this->error_msg");
     if ( trim($this->error_msg) != "" ) {
       $T->tr();
       $T->td("<font color=\"red\">$this->error_msg</font>");
@@ -1467,18 +1399,13 @@ class thread_msg extends forum_thread {
     $T->tr();
     $T->td("&nbsp;");
     $T->td("Posted by $this->author on $this->date_posted", "axmsgpostinfo");
-    //$T->td_contentcss("font-size:9pt");
     $T->tr();
     $T->td("Subject:&nbsp;", "axforumform");
-    /*$T->td_contentcss("font-size:9pt;
-                       color: #FF6600;");*/
     $T->td_width("25%");
     $T->td_alignment("right");
     $T->td($ms->render());
     $T->tr();
     $T->td("Text:&nbsp;", "axforumform");
-    /*$T->td_contentcss("font-size:9pt;
-                       color: #FF6600;");*/
     $T->td_width("25%");
     $T->td_alignment("right", "top");
     $T->td($mt->render());
@@ -1507,4 +1434,4 @@ class thread_msg extends forum_thread {
   } // edit_msg
 } // class thread_msg
 // ----------------------------------------------------------------------
-?>
+?>
\ No newline at end of file
