@@ -28,35 +28,27 @@
 /** Form elements */
 include_once("form-defs.php");
 
-// NOTES: How to implement HTMLAreas in your forms:
-//
-//  // Include htmlarea classes at the top of the page..
-//  include_once("htmlarea-defs.php");
-//  // Define which plugins to load..
-//  htmlarea_plugins("ContextMenu,CSS");
-//  ...
-//  // Build your form element..
-//  $Fld = new form_wysiwygfield("my_content", "Article", $my_content);
-//  // Register plugins this editor will use..
-//  $Fld->register_plugins("all");
-//  // Render the field..
-//  $myfield = $Fld->render();
-//  ...
-//  ... more htmlareas as required ...
-//
-// Set this global externally to override. We choose the default to
-// be Xinha, as this is a more recent fork of htmlarea.
-if (!isset($wysiwyg_editor)) {
-  $wysiwyg_editor = "xinha";
-}
+/**
+ *  NOTES: How to implement HTMLAreas in your forms:
+ *
+ *  // Include htmlarea classes at the top of the page..
+ *  include_once("htmlarea-defs.php");
+ *  // Define which plugins to load..
+ *  add_wysiwyg_plugins("ContextMenu,CSS");
+ *  ...
+ *  // Build your form element..
+ *  $Fld = new form_wysiwygfield("my_content", "Article", $my_content);
+ *  // Register plugins this editor will use..
+ *  $Fld->register_plugins("all");
+ *  // Render the field..
+ *  $myfield = $Fld->render();
+ *  ...
+ *  ... more htmlareas as required ...
+ *
+ */
 
-// Locations of the editors javaswcript trees
-$wysiwyg_editor_dirs = array(
-  "htmlarea" => "js/htmlarea",
-  "xinha"    => "js/xinha"
-  );
-// The one we will be using here..
-$wysiwyg_editor_dir = $wysiwyg_editor_dirs[$wysiwyg_editor];
+// We are using the Xinha Wysiswyg editor, which is a fork of htmlarea.
+$wysiwyg_editor_dir = "js/xinha";
 
 // ----------------------------------------------------------------------
 /**
@@ -319,6 +311,51 @@ class htmlarea_config {
   /** Constructor for new HTMLArea configuration object  */
   function htmlarea_config() {
   } // HTMLArea_config
+  
+  // .....................................................................
+  /** Set a new toolbar definition. Toolbars are arrays of arrays of lists
+  * of HTMLArea widgets. Each array is a line of these widgets. For an
+  * example see the default setting for the toolbar in this class. You
+  * can EITHER give a full toolbar definition here as an array of arrays
+  * of toolbar widgets, OR give a preset toolbar ID string. Presets that
+  * we have defined so far are:
+  *   "basic"  - Just enough to enter text, bold/italic etc.
+  *   "medium" - As above but with colour, links, raw HTML etc.
+  *   "full"   - Everything available
+  * @param mixed $new_toolbat Array of toolbar lines, or preset toolbar id
+  */
+  function set_toolbar($new_toolbar) {
+    if (is_array($new_toolbar)) {
+      // Trust them, they know what they are doing
+      $this->toolbar = $new_toolbar;
+    }
+    elseif (is_string($new_toolbar)) {
+      // Assign a pre-defined recipe toolbar
+      switch ($new_toolbar) {
+        case "basic":
+          $this->toolbar = $this->toolbar_basic;
+          break;
+        case "medium":
+          $this->toolbar = $this->toolbar_medium;
+          break;
+        case "full":
+          $this->toolbar = $this->toolbar_full;
+          break;
+        default:
+          $this->toolbar = $this->toolbar_full;
+      } // switch
+    }
+  } // set_toolbar
+  // .....................................................................
+  /**
+   * Add a new tool element to the existing toolbar array.
+   * @param string $tool The name of the new tool to add to the toolbar
+   */
+  function add_tool($tool) {
+    if (is_string($tool) && $tool != "") {
+      $this->toolbar[] = $tool;
+    }
+  } // add_tool
   // .....................................................................
   /**
   * Render this config as a string of Javascript which could be put into
@@ -355,20 +392,8 @@ class htmlarea_config {
     if (isset($this->htmlRemoveTags) && $this->htmlRemoveTags != "") {
       $s .= "$configvar.htmlRemoveTags = '$this->htmlRemoveTags';\n";
     }
-    if (isset($this->toolbar)) {
+    if (isset($this->toolbar) && is_array($this->toolbar)) {
       $toolbar = $this->toolbar;
-      if (is_string($toolbar)) {
-        switch ($toolbar) {
-          case "basic":
-            $toolbar = $this->toolbar_basic;
-            break;
-          case "medium":
-            $toolbar = $this->toolbar_medium;
-            break;
-          default:
-            $toolbar = $this->toolbar_full;
-        } // switch
-      }
       $toolbar_lines = array();
       foreach ($toolbar as $toolbar_line) {
         $toolbar_lines[] = "[\"" . implode("\",\"", $toolbar_line) . "\"]";
@@ -424,12 +449,12 @@ $HTMLAREA = new htmlarea();
 *    FullPage
 * @param string $plugins A comma-delimited list of plugins
 */
-function htmlarea_plugins($plugins) {
+function add_wysiwyg_plugins($plugins) {
   global $HTMLAREA;
   if (is_object($HTMLAREA) && method_exists($HTMLAREA, "load_plugins")) {
     $HTMLAREA->load_plugins($plugins);
   }
-} // htmlarea_plugins
+} // add_wysiwyg_plugins
 
 // ----------------------------------------------------------------------
 /**
@@ -524,7 +549,7 @@ class form_wysiwygfield extends form_memofield {
   * @param mixed $new_toolbat Array of toolbar lines, or preset toolbar id
   */
   function set_toolbar($new_toolbar) {
-    $this->config->toolbar = $new_toolbar;
+    $this->config->set_toolbar($new_toolbar);
   } // set_toolbar
   // .....................................................................
   /** Set a new list of selectable font families. This array should be an
@@ -619,7 +644,7 @@ class form_wysiwygfield extends form_memofield {
   /**
   * Set the plugins to register for this Wysiwyg editor. This is a subset
   * of the allowed plugins which were given in the original call to the
-  * @see htmlarea_plugins() function. If you want to just register all
+  * @see add_wysiwyg_plugins() function. If you want to just register all
   * of the possibilities, then just leave the argument list empty, or
   * explicitly set it to "all" (the default).
   * @param string $pluginlist Comma-delimited list of plugins to register
