@@ -59,6 +59,7 @@ $RESPONSE->body->add_script(
 function render_layouts($s) {
   $rs = $s;
   if (stristr($rs, "LAYOUTID=")) {
+    $matches = array();
     preg_match_all("/<!--LAYOUTID=\"(.+)\"-->/i", $rs, $matches);
     for ($i=0; $i< count($matches[0]); $i++) {
       $layouttag = $matches[0][$i];
@@ -98,7 +99,7 @@ class layout extends RenderableObject {
   var $format_last_modified = NICE_DATE;
   /** The prefix string for last modified datetime */
   var $prefix_last_modified = "";
-  /** The index category of the current layout - used with Lucene indexing */
+  /** The index category of the current layout - used with indexing */
   var $index_category = "";
   /** Table width specification */
   var $table_width = "";
@@ -329,7 +330,7 @@ class layout extends RenderableObject {
         $this->format_last_modified = NICE_DATE;
       }
       $this->prefix_last_modified = $Lq->field("prefix_last_modified");
-      $this->show_last_modified = ($Lq->field("show_last_modified") == "t");
+      $this->show_last_modified = $Lq->istrue("show_last_modified");
       if ($this->show_last_modified) {
         $lmts = 0;
         $q  = "SELECT MAX(last_modified) AS lastmod FROM ax_block";
@@ -491,7 +492,7 @@ class layout extends RenderableObject {
   // ....................................................................
   /**
   * Index all blocks in this layout.
-  * If Lucene indexing is enabled, then we call the indexer for all of
+  * If search engine indexing is enabled, then we call the indexer for all of
   * the blocks which are in the hosted layout, using the webpage path and title as
   * provided in the call to this method.
   * @param string $path The relative path to the webpage the hosted layout is in
@@ -517,8 +518,8 @@ class layout extends RenderableObject {
   // ....................................................................
   /**
   * Un-Index all blocks in this layout. After calling this method all
-  * the bloacks in the layout will have been removed from the Lucene
-  * index.
+  * the blocks in the layout will have been removed from the search
+  * engine index.
   */
   function unindex() {
     $lcq = dbrecordset("SELECT block_id FROM ax_block WHERE layout_id=" . $this->layoutid);
@@ -653,7 +654,7 @@ class layout extends RenderableObject {
                 if (isset($profile[$c])) {
                   $pwdth = $profile[$c];
                   if (strstr($pwdth, "%")) {
-                    if ($tblwdth != "" && !strstr($tbldwdth, "%")) {
+                    if ($tblwdth != "" && !strstr($tblwdth, "%")) {
                       $w = (int) ($tblwdth * $pwdth / 100);
                       $edbox->setstyle("width:" . $w . "px;");
                     }
@@ -1437,7 +1438,7 @@ class named_layout extends layout {
 
       // How many versions do we have..
       $q  = "SELECT COUNT(*) AS vercnt FROM ax_layout";
-      $q .= " WHERE layout_name='". addslashes($name) . "'";
+      $q .= " WHERE layout_name='". escape_string($name) . "'";
       $Lcnt = dbrecordset($q);
       if ($Lcnt->hasdata) {
         $this->version_count = $Lcnt->field("vercnt");
@@ -1448,7 +1449,7 @@ class named_layout extends layout {
       // accessing it for the very first time, so we create it,.
       if ($this->version_count == 0) {
         // Create new set if required..
-        $checkSet = dbrecordset("SELECT * FROM ax_layout_set WHERE layout_name='". addslashes($name) . "'");
+        $checkSet = dbrecordset("SELECT * FROM ax_layout_set WHERE layout_name='". escape_string($name) . "'");
         if ($checkSet->rowcount == 0) {
           $LSin = new dbinsert("ax_layout_set");
           $LSin->set("layout_name", $name);
@@ -1463,7 +1464,7 @@ class named_layout extends layout {
 
       // Grab all relevant versions of the layout..
       $LQ = new dbselect("ax_layout");
-      $LQ->where("layout_name='". addslashes($name) . "'");
+      $LQ->where("layout_name='". escape_string($name) . "'");
       $LQ->orderby("layout_id DESC");
       $LQ->execute();
       if ($LQ->hasdata) {
@@ -1519,7 +1520,7 @@ class named_layout extends layout {
   function index() {
     // Find page we belong to..
     $q  = "SELECT * FROM ax_layout_set ls, ax_sitepage pg";
-    $q .= " WHERE ls.layout_name='" . addslashes($this->layout_name) . "'";
+    $q .= " WHERE ls.layout_name='" . escape_string($this->layout_name) . "'";
     $q .= "   AND pg.page_id=ls.page_id";
     $sitepage = dbrecordset($q);
     if ($sitepage->hasdata) {
