@@ -81,7 +81,7 @@ class layouteditor extends RenderableObject {
       if ($layoutname != "") {
         $this->layout->layout_name = $layoutname;
         $q  = "SELECT * FROM ax_layout_set";
-        $q .= " WHERE layout_name='" . addslashes($layoutname) . "'";
+        $q .= " WHERE layout_name='" . escape_string($layoutname) . "'";
         $chkset = dbrecordset($q);
         if ($chkset->rowcount == 0) {
           $LSin = new dbinsert("ax_layout_set");
@@ -328,7 +328,6 @@ class layouteditor extends RenderableObject {
 
     // TOOLBAR: Table
     $Tbar = new table("toolbar");
-    //$Tbar->setwidth(500);
     $Tbar->tr("axtitle");
     $Tbar->th("<b>$verhdg</b> [" . $this->layout->layout_name . "]", "axtitle");
     $tools = "";
@@ -374,12 +373,12 @@ class layouteditor extends RenderableObject {
     $lastmodCombo = new form_combofield("format_last_modified");
     $lastmodCombo->setclass("axcombo");
     $lastmodCombo->setstyle("width:$pwidth;");
-    $lastmodCombo->additem(NICE_FULLDATETIME,        "Mar 3rd 1999 1:30pm");
-    $lastmodCombo->additem(NICE_DATE,                "Mar 3rd 1999");
-    $lastmodCombo->additem(DAY_AND_DATE,             "Friday, 20th July 2001");
-    $lastmodCombo->additem(DISPLAY_DATE_ONLY,        "31/12/1999");
-    $lastmodCombo->additem(DISPLAY_DATE_FORMAT,      "31/12/1999 23:59");
-    $lastmodCombo->additem(DISPLAY_TIMESTAMP_FORMAT, "31/12/1999 23:59:59");
+    $lastmodCombo->additem(NICE_FULLDATETIME,        "Mar 3rd 2008 1:30pm");
+    $lastmodCombo->additem(NICE_DATE,                "Mar 3rd 2008");
+    $lastmodCombo->additem(DAY_AND_DATE,             "Friday, 20th July 2008");
+    $lastmodCombo->additem(DISPLAY_DATE_ONLY,        "31/12/2008");
+    $lastmodCombo->additem(DISPLAY_DATE_FORMAT,      "31/12/2008 23:59");
+    $lastmodCombo->additem(DISPLAY_TIMESTAMP_FORMAT, "31/12/2008 23:59:59");
     $lastmodCombo->additem(NICE_TIME_ONLY,           "1:30pm");
     $lastmodCombo->setvalue($this->layout->format_last_modified);
 
@@ -536,9 +535,10 @@ class layouteditor extends RenderableObject {
     $Tpriv->setwidth("500");
     $Tpriv->setcss("margin-left:100px");
     $Tpriv->tr();
-    $blurb  = "To change the access privileges for layout and block content editing for ";
-    $blurb .= "this layout, highlight the group and select one or more privileges for it.";
-    $blurb .= "Repeat for each group as required, then click the save button.";
+    $blurb = "To change the access privileges for layout and block content editing for "
+           . "this layout, highlight the group and select one or more privileges for it. "
+           . "Repeat for each group as required, then click the save button."
+           ;
     $Tpriv->td($blurb);
     $Tpriv->td_colspan(2);
     $Tpriv->tr();
@@ -554,7 +554,7 @@ class layouteditor extends RenderableObject {
 
     // Checkbox for each privilege
     // Editor
-    $Fld = $genchk;
+    $Fld = clone($genchk);
     $Fld->setname("priv_editor");
     $Fld->checked = isset($this->layout->privileges["editor|$group_id"]);
     $privs_maintainer->register_field($Fld);
@@ -563,7 +563,7 @@ class layouteditor extends RenderableObject {
     $Tpriv->td("Editor/Publisher");
 
     // Author
-    $Fld = $genchk;
+    $Fld = clone($genchk);
     $Fld->setname("priv_author");
     $Fld->checked = isset($this->layout->privileges["author|$group_id"]);
     $privs_maintainer->register_field($Fld);
@@ -572,7 +572,7 @@ class layouteditor extends RenderableObject {
     $Tpriv->td("Author of content");
 
     // Entry
-    $Fld = $genchk;
+    $Fld = clone($genchk);
     $Fld->setname("priv_entry");
     $Fld->checked = isset($this->layout->privileges["entry|$group_id"]);
     $privs_maintainer->register_field($Fld);
