@@ -296,7 +296,7 @@ class metadata_scheme extends RenderableObject {
       $title .= "&nbsp;" . $schref->render();
     }
     elseif ($this->tag_name != "") {
-        $title .= " ($this->tag_name)";
+      $title .= " ($this->tag_name)";
     }
     if ($this->preferred) {
       $title .= " <span class=\"axhl\"><small>*preferred*</small></span>";
@@ -1329,11 +1329,10 @@ class layout_metadata_elements {
   * @param reference Reference to Webpage object to insert metatags into
   */
   function insert_metatags(&$webpage) {
-    global $RESPONSE;
     foreach ($this->metadata_elements as $element_id => $element) {
       if ($element->instantiated) {
         $metatag = $element->metatag();
-        $RESPONSE->insert_metatag($element_id, $metatag);
+        $webpage->insert_metatag($element_id, $metatag);
       }
     }
   } // insert_metatags
