@@ -63,10 +63,6 @@ class DB_dbsequence extends dbsequence {
     }
   }
   // ....................................................................
-  /** Get schema info for sequence */
-  function getschema() {
-  }
-  // ....................................................................
   /** Return Postgres SQL required to create this sequence. */
   function create() {
     $s .= "create sequence \"$this->name\"";
@@ -926,7 +922,15 @@ class DB_dbtable extends dbtable {
       $s .= " and attrelid = (select oid from pg_class where relname='$this->name');\n";
     }
     else {
-      $s = "alter table $this->name\n";
+      $s = "";
+      if (isset($this->fields[$column->name])) {
+        $field = $this->fields[$column->name];
+        if ($field->defaultval != "") {
+          $s .= "update $this->name\n";
+          $s .= "  set $column->name = '" . $field->defaultval . "';\n";
+        }
+      }
+      $s .= "alter table $this->name\n";
       $s .= "  alter column $column->name";
       if ($column->notnull) {
         $s .= " set not null;\n";
