@@ -131,38 +131,76 @@ class page_section extends RenderableObject {
   // .....................................................................
   /**
   * Add more scripting to this page section.
-  * @param string $script   Script content (omit <script> tags)
-  * @param string $language The language the script is in
+  * @param string  $script   Script content (omit <script> tags)
+  * @param string  $language The language the script is in
+  * @param string  $mode     Add mode: 'append' (default), 'prefix', or 'replace'
+  * @param boolean $once     If true duplicate content is rejected, default is false
   */
-  function add_script($script, $language="javascript") {
-    $this->add_named_script($script, "default", $language);
+  function add_script(
+    $script,
+    $language="javascript",
+    $mode="append",
+    $once=ADD_MULTIPLE)
+  {
+    $this->add_named_script($script, "default", $language, $mode, $once);
   } // add_script
   // .....................................................................
   /**
   * This adds a specific lump of script to the webpage under a unique name.
   * It allows you to collect multiple additions of script content under
   * a single grouping, and so cause the final rendering to group it all
-  * together.
-  * @param string $script   Script content (omit <script> tags)
-  * @param string $name     Script content grouping identity
-  * @param string $language The language the script is in
+  * together. Three modes of adding are supported with the mode parameter.
+  * If 'append' (default) then the script is appended. If 'prefix' then it
+  * is prefixed to the front of any existing script. If 'replace' then it
+  * replaces any existing script. The 'once' flag allows control of content
+  * which has already been added; if true then no duplicates will be allowed
+  * then it will only be appended once, and not again. If 'replace' then
+  * it will delete existing and replace it. Note 'add' is for backward
+  * compatibility, and you probably want to use 'once' mostly.
+  * @param string  $script   Script content (omit <script> tags)
+  * @param string  $name     Script content grouping identity
+  * @param string  $language The language the script is in
+  * @param string  $mode     Add mode: 'append' (default), 'prefix', or 'replace'
+  * @param boolean $once     If true duplicate content is rejected, default is false
   */
-  function add_named_script($script, $name, $language="javascript") {
+  function add_named_script(
+    $script,
+    $name="",
+    $language="javascript",
+    $mode="append",
+    $once=ADD_MULTIPLE)
+  {
     if ($name == "") {
       $name = "default";
     }
-    $this->script[$name][$language] .= $script;
+    $original = $this->script[$name][$language];
+    $this->script[$name][$language] = add_content_to($original, $script, $mode, $once);
   } // add_named_script
   // .....................................................................
   /**
-  * Add script reference link
-  * Add more scripting to this section in the form of
-  * a link to a script source file.
+  * Add more scripting to this section in the form of a link to a script
+  * source file. This method will only add the link if it doesn't exist
+  * in the list of links already added.
   * @param string $src      URL pointing to the script
   * @param string $language The language the script is in
+  * @param string $parms    Additional script src parameters
   */
-  function add_scriptsrc($src, $language="javascript") {
-    $this->scriptsrc[$language][] = $src;
+  function add_scriptsrc($src, $language="javascript", $parms="") {
+    $doit = true;
+    if ($parms != "") {
+      $src .= "|$parms";
+    }
+    if (isset($this->scriptsrc[$language])) {
+      foreach ($this->scriptsrc[$language] as $src_already) {
+        if (strcasecmp($src_already, $src) == 0) {
+          $doit = false;
+          break;
+        }
+      }
+    }
+    if ($doit) {
+      $this->scriptsrc[$language][] = $src;
+    }
   } // add_scriptsrc
   // .....................................................................
   /**
@@ -178,7 +216,15 @@ class page_section extends RenderableObject {
     if (isset($this->scriptsrc) && is_array($this->scriptsrc)) {
       foreach ($this->scriptsrc as $language => $srcs) {
         foreach ($srcs as $src) {
-          $s .= "<script type=\"text/$language\" src=\"$src\"></script>\n";
+          $s .= "<script type=\"text/$language\"";
+          if (strstr($src, "|")) {
+            $srcbits = explode("|", $src);
+            $s .= " src=\"" . $srcbits[0] . "\" " . $srcbits[1];
+          }
+          else {
+            $s .= " src=\"$src\"";
+          }
+          $s .= "></script>\n";
         }
       }
     }
