@@ -76,6 +76,7 @@ class transaction {
   */
   function begin($mode=ROLLBACK_ON_FAIL) {
     global $RESPONSE;
+    $tok = false;
     if ($RESPONSE->db_backed) {
       if (!$this->open) {
         $RESPONSE->datasource->begin_transaction();
@@ -86,12 +87,14 @@ class transaction {
         if (debugging()) {
           debugbr("TOK: Start transaction.", DBG_SQL);
         }
+        $tok = true;
       }
       else {
         debugbr("TWARN: Nested transactions are not supported", DBG_SQL);
       }
     }
-  }
+    return $tok;
+  } // begin
   // ....................................................................
   /**
   * Commit transaction
@@ -633,6 +636,9 @@ class dbquery extends sqlquery {
 class dbrows extends dbquery {
   /** An array containing the current DB row */
   var $current_row;
+  /** True if query has just been validly run and primed
+   *  with the first row */
+  var $primed = false;
   // ....................................................................
   /**
   * Constructor
@@ -656,6 +662,7 @@ class dbrows extends dbquery {
     dbquery::execute();
     if ($this->valid) {
       $this->get_first();
+      $this->primed = true;
     }
     return $this->valid;
   } // execute
@@ -803,9 +810,16 @@ class dbrows extends dbquery {
   } // get_previous
   // ....................................................................
   /**
-  * Get next row
+  * Get next row. Acquires the record data for the next resultset row.
   * If current query is invalid, try to execute it first, then get
-  * the next row from the resultset.
+  * the next row from the resultset. This is best used at the bottom
+  * of a while loop, after checking for data like so:
+  *    $myquery = dbrecordset("select * from foo");
+  *    if ($myquery->hasdata) {
+  *        do {
+  *            $foo = $myquery->field("bar");
+  *        } while ($myquery->get_next());
+  *    }
   * @return mixed The row if it is available, else returns FALSE.
   */
   function get_next() {
@@ -817,6 +831,30 @@ class dbrows extends dbquery {
   } // get_next
   // ....................................................................
   /**
+  * Get the next row - variation on get_next().
+  * This variant is designed to be run at the top of the loop, and avoid
+  * having to do a check for presence of resultset data eg:
+  *    $myquery = dbrecordset("select * from foo");
+  *    while ($myquery->get_next_row()) {
+  *        $foo = $myquery->field("bar");
+  *    }
+  * If current query is invalid, try to execute it first, then get
+  * the next row from the resultset.
+  * @return mixed The row if it is available, else returns FALSE.
+  */
+  function get_next_row() {
+    $res = true;
+    if ($this->primed) {
+      $this->primed = false;
+      $res = $this->get_current();
+    }
+    else {
+      $res = $this->get_next();
+    }
+    return $res;
+  } // get_next_row
+  // ....................................................................
+  /**
   * Return the EOF (end-of-file) indicator for this query. Returns
   * true if no more results can be returned with get_next(), ie. we
   * are at the end of the results set.
