@@ -175,7 +175,7 @@ class recmaintainer extends RenderableObject {
         break;
     } // switch
     // Set new onclick script..
-    $button->set_onclick($new_onclick, SCRIPT_APPEND);
+    $button->set_onclick($new_onclick, SCRIPT_PREFIX);
   } // register_button
   // ....................................................................
   /**
@@ -199,6 +199,7 @@ class recmaintainer extends RenderableObject {
   * database queries. The array is therefore expected to contain the
   * normal fieldname=>data pairs. The ordering of adding these records
   * should be identical to the ordering of the records in the keycombo.
+  * @param string $keyval The key identifier for this record
   * @param array $record An associative arrray containing a record of data
   */
   function add_record($keyval, $record) {
@@ -281,7 +282,6 @@ class recmaintainer extends RenderableObject {
           $args[] = "'$fldval'";
         }
         else {
-          //debugbr("block recmaint: field $fieldname NOT MULTILANG");
           $fldval = rawurlencode($fldval);
           $args[] = "'$fldval'";
         }
