@@ -1503,7 +1503,7 @@ if (file_exists("$DOCUMENT_ROOT/application.xml") && isset($application) && $app
     $WEBMASTER_PERSON = "The " . ((APP_NAME != "") ? (APP_NAME . " ") : "") . "Webmaster";
   }
   if ($WEBMASTER_EMAIL == "") {
-    $WEBMASTER_EMAIL = "webmaster@" . $this->http_host;
+    $WEBMASTER_EMAIL = "webmaster@" . $RESPONSE->http_host;
   }
 
   // DEBUGGING
