@@ -246,7 +246,6 @@ class webstream extends session {
   */
   function replace($tag, $newstuff) {
     $this->replacement[$tag] = $newstuff;
-    return $this;
   } // replace
   // .....................................................................
   /**
@@ -321,7 +320,6 @@ class webstream extends session {
       } // switch
     }
     $this->content = $content;
-    return $this;
   } // make_content
   // .....................................................................
   /**
@@ -474,6 +472,9 @@ class webstream extends session {
 */
 class webpage extends webstream {
   // Public
+  /** User interface rendering toolkit setting. Currently we have the
+   * following options: axyl, dojo. */
+  var $ui_toolkit = "axyl";
   /** Webpage head object */
   var $head;
   /** Webpage body object */
@@ -564,12 +565,21 @@ class webpage extends webstream {
   } // webpage constructor
   // .....................................................................
   /**
+  * Set the interface rendering mode. This setting affects certain
+  * display elements, such as form widgets. Current options for this
+  * setting are 'axyl' (default), and 'dojo'.
+  * @param string $interface Interface mode to render output with
+  */
+  function set_ui_toolkit($toolkit="axyl") {
+    $this->ui_toolkit = $toolkit;
+  } // set_ui_toolkit
+  // .....................................................................
+  /**
   * Add to the body content
   * @param string $morestuff  Content to append to the body of the webpage
   */
   function add($morestuff) {
     $this->body->add($morestuff);
-    return $this;
   } // add
   // .....................................................................
   /**
@@ -578,21 +588,36 @@ class webpage extends webstream {
   * It allows you to collect multiple additions of script content under
   * a single grouping, and so cause the final rendering to group it all
   * together.
-  * @param string $script   Script content (omit <script> tags)
-  * @param string $name     Script content grouping identity
-  * @param string $language The language the script is in
+  * @param string  $script   Script content (omit <script> tags)
+  * @param string  $name     Script content grouping identity
+  * @param string  $language The language the script is in
+  * @param string  $mode     Add mode: 'append' (default), 'prefix', or 'replace'
+  * @param boolean $once     If true duplicate content is rejected, default is false
   */
-  function add_named_script($script, $name, $language="javascript") {
-    $this->body->add_named_script($script, $name, $language);
+  function add_named_script(
+    $script,
+    $name="",
+    $language="javascript",
+    $mode="append",
+    $once=ADD_MULTIPLE)
+  {
+    $this->body->add_named_script($script, $name, $language, $mode, $once);
   } // add_named_script
   // .....................................................................
   /**
-  * Add named script to the body
-  * @param string $script   Script to insert into the body of the webpage
-  * @param string $language Language of this script (default javascript)
+  * Add script to the body
+  * @param string  $script   Script content (omit <script> tags)
+  * @param string  $language The language the script is in
+  * @param string  $mode     Add mode: 'append' (default), 'prefix', or 'replace'
+  * @param boolean $once     If true duplicate content is rejected, default is false
   */
-  function add_script($script, $language="javascript") {
-    $this->body->add_script($script, $language);
+  function add_script(
+    $script,
+    $language="javascript",
+    $mode="append",
+    $once=ADD_MULTIPLE)
+  {
+    $this->body->add_script($script, $language, $mode, $once);
   } // add_script
   // .....................................................................
   /**
@@ -819,7 +844,6 @@ class webpage extends webstream {
   */
   function set_onload($onload) {
     $this->body->set_onload($onload);
-    return $this;
   } // set_onload
   // .....................................................................
   /**
@@ -828,7 +852,6 @@ class webpage extends webstream {
   */
   function set_title($title) {
     $this->head->set_title($title);
-    return $this;
   } // set_title
   // .....................................................................
   /**
@@ -840,7 +863,6 @@ class webpage extends webstream {
   */
   function set_style($style) {
     $this->head->set_style($style);
-    return $this;
   } // set_style
   // .....................................................................
   /**
@@ -960,8 +982,25 @@ class webpage extends webstream {
   * buffer, in preparation for delivery to the browser.
   */
   function generate() {
-    global $HTMLAREA;
+    global $LIBDIR;
     if (!$this->generated) {
+      switch ($this->ui_toolkit) {
+        case "dojo":
+          $this->head->add_scriptsrc(
+                  "$LIBDIR/js/dojo/dojo/dojo.js",
+                  "javascript",
+                  "djConfig=\"parseOnLoad:true\""
+                  );
+          $this->head->add_script("dojo.require('dojo.parser');\n");
+          break;
+        default:
+          // Set up the javascript environment for any
+          // htmlarea widgets which have been used
+          global $HTMLAREA;
+          if (isset($HTMLAREA) && $HTMLAREA->activated) {
+            $HTMLAREA->render();
+          }
+      }
       if ($this->pluginset->hascontent) {
         foreach ($this->pluginset->plugins as $id => $plugin) {
           if (is_object($plugin)) {
@@ -971,11 +1010,6 @@ class webpage extends webstream {
           }
         }
       }
-      // Set up the javascript environment for any
-      // htmlarea widgest which have been used..
-      if (isset($HTMLAREA) && $HTMLAREA->activated) {
-        $HTMLAREA->render();
-      }
       // Produce the content..
       if ($this->buffered) {
         // Acquire content via the Php buffer..
@@ -1165,6 +1199,7 @@ class head extends page_section {
       $bits = explode("<head>", $template);
       if (isset($bits[0]) && $bits[0] != "") {
         // Always use DTD from template if found..
+        $matches = array();
         if (preg_match("/<!DOCTYPE (.+)>/i", $bits[0], $matches)) {
           $this->set_dtd($matches[0]);
         }
@@ -1186,7 +1221,6 @@ class head extends page_section {
         }
       }
     }
-    return $this;
   } // load_template
   // ....................................................................
   /**
@@ -1670,7 +1704,6 @@ class templated_webpage extends webstream {
       fclose ($fp);
       echo $content;
     }
-    return $this;
   } // set_template
   // .....................................................................
   /**
