@@ -1,4 +1,4 @@
-#!/usr/bin/php4 -q
+#!/usr/bin/php -q
 <?php
 /* ******************************************************************** */
 /* CATALYST PHP Source Code                                             */
@@ -157,6 +157,22 @@ function logit($msg) {
   echo "$msg\n";
 }
 
+/*
+function escape_string($str) {
+  if (is_string($str)) {
+    $str = pg_escape_string(stripslashes($str));
+  }
+  return $str;
+} // escape_string
+
+function unescape_string($str) {
+  if (is_string($str)) {
+    $str = stripslashes($str);
+  }
+  return $str;
+} // unescape_string
+*/
+
 function connect_pgdb($dbname, $dbuser="", $dbpass="", $dbhost="", $dbport=0) {
   $connstr = " dbname=" . $dbname;
   if ($dbuser != "") $connstr .= " user=" . $dbuser;
@@ -331,6 +347,7 @@ $AXYL_HOME = "";
 $AXYL_DATA = "";
 $LUCENE_PORT = 0;
 $LUCENE_INSTALLED = false;
+$FORCED_DBUSER="";
 
 // Axyl configuration settings..
 $CONF_FILE = "/etc/axyl/axyl.conf";
@@ -562,8 +579,15 @@ logit("\nUPDATING..");
 logit("Axyl database upgrade..");
 // Create axyl_core database from latest schema..
 logit(" ++ axyl core database..");
+echo "Default database name: " . $RESPONSE->datasource->db_name_default . "\n";
+
 $curdb = $RESPONSE->datasource->database[ $RESPONSE->datasource->db_name_default ];
 
+if (is_object($curdb)) {
+  echo "Database name: " . $curdb->name . "\n";
+  echo "Database connection username: " . $curdb->user . "\n";
+}
+
 // If Axyl core DB already exists, drop it..
 $dbid = connect_pgdb("axyl_core", $curdb->user, $curdb->passwd, $curdb->host, $curdb->port);
 if ($dbid !== false) {
@@ -598,7 +622,7 @@ if ($controltable->hasdata) {
   if ($chkcontrol->hasdata) {
     logit(" -- updating ax_control record..");
     // Update control record..
-    $upcontrol = new dbupdte("ax_control");
+    $upcontrol = new dbupdate("ax_control");
     $upcontrol->set("app_prefix", "'" . APP_PREFIX . "'");
     $upcontrol->set("site_docroot", "'$WWW_PATH'");
     $chkver = dbrecordset("SELECT * FROM ax_control");
@@ -850,7 +874,7 @@ while ($upgrading_schema) {
     logit(" -- that ax_menu and ax_menuoption will need creating.");
   }
   $outputlines = array();
-  exec("$AXYL_HOME/scripts/pgdiff.php --no-drops --target=" . $curdb->name . " --ref=axyl_core", $outputlines, $ret);
+  exec("$AXYL_HOME/scripts/pgdiff.php --pgversion=7.4 --no-drops --target=" . $curdb->name . " --ref=axyl_core", $outputlines, $ret);
   if ($ret == 0) {
     logit("\n -- pgdiff output begins");
     $diffs = array();
@@ -887,7 +911,7 @@ while ($upgrading_schema) {
 
         // Final check that diff is now reporting identical schemas..
         if ($ok) {
-          exec("$AXYL_HOME/scripts/pgdiff.php --no-drops --target=" . $curdb->name . " --ref=axyl_core", $outputlines);
+          exec("$AXYL_HOME/scripts/pgdiff.php --pgversion=7.4 --no-drops --target=" . $curdb->name . " --ref=axyl_core", $outputlines);
           foreach($outputlines as $line) {
             if (trim($line) != "" && substr($line, 0, 2) != "--") {
               $ok = false;
@@ -965,6 +989,12 @@ if ($do_menu_changes) {
       $menu_name = $oldmenuop->field("menu_id");
       $label     = $oldmenuop->field("label");
 
+      // Fix abuse of menu option labels by some idiots..
+      if (strstr($label, "src='img/")) {
+        $label = str_replace("src='img/", "src='/img/", $label);
+        logit(" -- menus update: fixing up img tag abuse of menu label '$label'");
+      }
+
       $menu_id   = $menuid_lookup[$menu_name];
 
       $moin = new dbinsert("ax_menuoption");
@@ -1101,43 +1131,50 @@ logit(" -- saved application.xml");
 // 1) for the image references, we need to replace $LIBDIR with $LIBDIR/img
 // 2) for include_once() we need to strip the "" prefix, since
 //    the PHP include_path will do the trick for these now.
-logit("\nfixing up Php files with LIBDIR references..");
-$dir = ".";
-$dh  = opendir($dir);
-while (false !== ($filename = readdir($dh))) {
-  if (substr($filename, -4) == ".php" || substr($filename, -4) == ".inc") {
-    $in  = new inputfile($filename);
-    $out = new outputfile($filename);
-    $updated = false;
-    if ($in->opened && $out->opened) {
-      $end_of_file = false;
-      while (!$end_of_file) {
-        $line = $in->readln();
-        if ($line === false) {
-          $end_of_file = true;
-        }
-        else {
-          if (preg_match("/LIBDIR\/_/", $line)) {
-            $line = str_replace("LIBDIR", "LIBDIR/img", $line);
-            $updated = true;
+logit("\nfixing up Php files with LIBDIR and INCDIR references..");
+$dirs = array(".", "inc");
+
+foreach ($dirs as $dir) { 
+  $dh  = opendir($dir);
+  while (false !== ($filename = readdir($dh))) {
+    if (substr($filename, -4) == ".php" || substr($filename, -4) == ".inc") {
+      logit(" -- trying dir '$dir' $filename");
+      $filepath = $dir . "/" . $filename;
+      $in  = new inputfile($filepath);
+      $out = new outputfile($filepath);
+      $updated = false;
+      if ($in->opened && $out->opened) {
+        $end_of_file = false;
+        while (!$end_of_file) {
+          $line = $in->readln();
+          if ($line === false) {
+            $end_of_file = true;
           }
-          if (preg_match("/include_once\(|include\(|require_once\(|require\(/", $line)) {
-            $replacepat = "/\\\$LIBDIR\//";
-            $line = preg_replace($replacepat, "", $line);
-            $updated = true;
+          else {
+            if (preg_match("/LIBDIR\/_/", $line)) {
+              $line = str_replace("LIBDIR", "LIBDIR/img", $line);
+              $updated = true;
+            }
+            if (preg_match("/include_once\(|include\(|require_once\(|require\(/", $line)) {
+              $replacepat = "/\\\$LIBDIR\//";
+              $line = preg_replace($replacepat, "", $line);
+              $replacepat = "/\\\$INCDIR\//";
+              $line = preg_replace($replacepat, "", $line);
+              $updated = true;
+            }
+            $out->writeln($line);
           }
-          $out->writeln($line);
+        } // while
+        $in->closefile();
+        $out->closefile();
+        if ($updated) {
+          logit(" -- fixed up LIBDIR/INCDIR refs in $filename");
         }
-      } // while
-      $in->closefile();
-      $out->closefile();
-      if ($updated) {
-        logit(" -- fixed up LIBDIR refs in $filename");
       }
     }
   }
+  closedir($dh);
 }
-closedir($dh);
 
 // ----------------------------------------------------------------------
 // FIX HARD-CODED IMAGE REFERENCES
@@ -1375,6 +1412,10 @@ if (is_dir($CMDIR)) {
       do {
         $pgid = $managed_content->field("page_id");
         $oldpath = $managed_content->field("page_path");
+        
+        if (substr(basename($oldpath), 0, 3) != "cm-") {
+          continue;
+        }
 
         // Has database been changed already? If so then they are probably
         // re-running this script. We can possibly deal to that in a sane
@@ -1448,7 +1489,7 @@ if (is_dir($CMDIR)) {
             do {
               $bktid = $blocklets->field("blocklet_id");
               $oldcontent = $blocklets->field("content");
-              $newcontent = str_replace("HREF=\"$oldpath\"", "HREF=\"/$CMDIR/$oldpath\"", $oldcontent);
+              $newcontent = preg_replace("/HREF=\"$oldpath\"/i", "HREF=\"/$CMDIR/$oldpath\"", $oldcontent);
               if ($newcontent != $oldcontent) {
                 $bup = new dbupdate("ax_blocklet");
                 $bup->set("content", $newcontent);
@@ -1456,8 +1497,14 @@ if (is_dir($CMDIR)) {
                 $bup->execute();
                 logit(" -- HREF update in blocklet $bktid");
               }
+              else {
+                logit(" -- no HREF update needed in blocklet $bktid");
+              }
             } while ($blocklets->get_next());
           }
+          else {
+            logit(" -- no blocklets to examine");
+          }
           $blocklets->tidyup();
           unset($blocklets);
 
@@ -1638,7 +1685,7 @@ if ($VHSERVERNAMES != "") {
     }
   }
   // Directive to insert into Apache VirtualHost config..
-  $php_include_path = "php_value include_path \".:$AXYL_HOME/lib:$WWW_PATH\"";
+  $php_include_path = "php_value include_path \".:$AXYL_HOME/lib:$WWW_PATH:$WWW_PATH/inc\"";
   foreach ($VHpaths as $VHpath => $dummy) {
     $in = new inputfile($VHpath);
     if ($in->opened) {
@@ -1736,13 +1783,9 @@ if ($VHSERVERNAMES != "") {
             logit(" -- apache configuration reload..");
             exec("invoke-rc.d apache reload");
           }
-          if (file_exists("/usr/sbin/apache-perl")) {
-            logit(" -- apache-perl configuration reload..");
-            exec("invoke-rc.d apache-perl reload");
-          }
-          if (file_exists("/usr/sbin/apache-ssl")) {
-            logit(" -- apache-ssl configuration reload..");
-            exec("invoke-rc.d apache-ssl reload");
+          if (file_exists("/usr/sbin/apache2")) {
+            logit(" -- apache2 configuration reload..");
+            exec("invoke-rc.d apache2 reload");
           }
         }
         else {
@@ -1832,7 +1875,4 @@ $THISDIR = realpath(".");
 if ($THISDIR != "" && $THISDIR != "/") {
   exec("$AXYL_HOME/install/set-axyl-website-perms.sh");
 }
-?>
-
-
-
+?>
\ No newline at end of file
