@@ -37,8 +37,15 @@ $HEADING = "Media Catalog";
 $RESPONSE->page($HEADING, "maint", $theme);
 $RESPONSE->body->add_script(
     "function go(mode, catid) {\n"
-  . "  if (mode == 'remove') {\n"
-  . "    if (!confirm('Really remove this catalog item?')) return false;\n"
+  . "  if (mode == 'detach') {\n"
+  . "    if (!confirm('NOTICE:\\nThis will remove the catalog item record, but\\n"
+                    . "leave the physical file alone.\\n\\n"
+                    . "Is that what you want?')) return false;\n"
+  . "  }\n"
+  . "  else if (mode == 'delete') {\n"
+  . "    if (!confirm('NOTICE:\\nThis will remove both the catalog item record,\\n"
+                    . "AND the physical file itself.\\n\\n"
+                    . "Is that what you want?')) return false;\n"
   . "  }\n"
   . "  else {\n"
   . "    if (mode != 'edit' && document.forms.upload_fm.upload_name.value == '') {\n"
@@ -74,8 +81,12 @@ $catalog = new catalog();
 // category should have a simple one-word code, and a descriptive name
 // associated with it. Define these as you like, but always leave the
 // Nullstring option in the list since this is required to denote "Any"
-// or "All" categories.
-$categories = array("" => ""); // always need this entry at least
+// or "All" categories. The ones below are just examples.
+$categories = array(
+    ""      => "",
+    "news"  => "News",
+    "misc"  => "Miscellaneous"
+    );
 
 // Add microsites as categories, which allows filtering..
 if ($RESPONSE->microsite_detected != "") {
@@ -134,7 +145,7 @@ switch ($mode) {
     break;
 
   // REMOVE CATALOG ITEM
-  case "remove":
+  case "delete":
     if (isset($catid)) {
       $catalog_item->get($catid);
       if (!$catalog_item->delete()) {
@@ -143,6 +154,15 @@ switch ($mode) {
     }
     break;
 
+  case "detach":
+    if (isset($catid)) {
+      $catalog_item->get($catid);
+      if (!$catalog_item->detach()) {
+        $errmsgs[] = "Failed to detach catalog item record $catid. Database issues?";
+      }
+    }
+    break;
+
   // CANCEL EDITING
   case "cancel":
     $mode = "view";
@@ -201,14 +221,12 @@ if ($mode == "edit" && isset($catid)) {
 // ERROR MESSAGES
 // Messages added to the errmsgs[] array above..
 $s = "";
-if (isset($errmsgs)) {
-  foreach ($errmsgs as $errmsg) {
-    $s .= "$errmsg<br>";
-  }
+if (isset($errmsgs) && count($errmsgs) > 0) {
+    $s .= "<span class=\"axerror\">" . implode("<br>", $errmsgs) . "</span>";
 }
 if ($s != "") {
   $uT->tr();
-  $uT->td( $s );
+  $uT->td($s, "text-align:center");
   $uT->td_colspan(2);
 }
 
@@ -312,23 +330,35 @@ $uT->td( $hid_auth->render() .  $hid_mode->render() . $hid_catid->render() );
 $uT->td_colspan(2);
 
 // ADD BUTTONS
-$btns = "";
+$btns = array();
 if ($mode == "edit") {
   $btn = new form_imagebutton("_save", "Save", "", "$LIBDIR/img/_save.gif", "Save changes", 57, 15);
   $btn->set_onclick("go('save','$catid')");
-  $btns .= $btn->render();
+  $btns[] = $btn->render();
+  $btn = new form_imagebutton("_detach", "Detach", "", "$LIBDIR/img/_detach.gif", "Remove catalog item record, leave file", 57, 15);
+  $btn->set_onclick("go('detach','$catid')");
+  $btns[] = $btn->render();
+  $btn = new form_imagebutton("_delete", "Delete", "", "$LIBDIR/img/_delete.gif", "Delete file AND item record", 57, 15);
+  $btn->set_onclick("go('delete','$catid')");
+  $btns[] = $btn->render();
+  
+  $btn = new form_imagebutton("_show", "Show", "", "$LIBDIR/img/_show.gif", "Show the media item", 57, 15);
+  $href = "/axyl-media-viewer.php";
+  $href = href_addparm($href, "cat_id", $catid);
+  $btn->set_onclick("show('$href','" . ceil($width * 1.08) . "','" . ceil($height * 1.05) . "')");
+  $btns[] = $btn->render();
   $btn = new form_imagebutton("_cancel", "Cancel", "", "$LIBDIR/img/_cancel.gif", "Cancel edit", 57, 15);
   $btn->set_onclick("go('cancel','')");
-  $btns .= $btn->render();
+  $btns[] = $btn->render();
 }
 else {
   $btn = new form_imagebutton("_add", "Add", "", "$LIBDIR/img/_add.gif", "Add this catalog item", 57, 15);
   $btn->set_onclick("go('add','')");
-  $btns .= $btn->render();
+  $btns[] = $btn->render();
 }
 $uT->tr();
 $uT->td();
-$uT->td( $btns );
+$uT->td( implode("&nbsp;", $btns) );
 
 // RENDER THE UPLOAD FIELDS
 $UPLOAD_FIELDS = $uT->render();
@@ -357,7 +387,7 @@ $fT->td( "Sorted by:", "axfmlbl" );
 $fT->td( $fld->render() );
 
 // Filter by keywords..
-if ( isset($CONTEXT) && $CONTEXT->configvalue("Lucene Site Indexing") ) {
+if ($SE_AVAILABLE) {
   $fld = new form_textfield("filt_keywords", "", $filt_keywords);
   $fld->setclass("axtxtbox");
   $fld->setstyle("width:$pxwidth;");
@@ -440,7 +470,6 @@ if (!$firsttime) {
       );
 
     // Buttons used for every catalog item line..
-    $removeBtn = new form_imagebutton("catremove", "", "", "$LIBDIR/img/_x.gif",   "Remove", 14, 14);
     $editBtn   = new form_imagebutton("catedit",   "", "", "$LIBDIR/img/_e.gif",   "Edit",   14, 14);
     $showBtn   = new form_imagebutton("catshow",   "", "", "$LIBDIR/img/_dot.gif", "Show",   14, 14);
 
@@ -515,7 +544,6 @@ if (!$firsttime) {
       $buttons = "";
       $editBtn->set_onclick("go('edit','$cat_id')");
       $editBtn->settitle("Edit $file");
-      $removeBtn->set_onclick("go('remove','$cat_id')");
 
       if (file_exists($RESPONSE->site_docroot . $path)) {
         $href = "/axyl-media-viewer.php";
@@ -523,7 +551,7 @@ if (!$firsttime) {
         $showBtn->set_onclick("show('$href','" . ceil($width * 1.08) . "','" . ceil($height * 1.05) . "')");
         $buttons .= $showBtn->render() . "&nbsp;";
       }
-      $buttons .= $editBtn->render() . "&nbsp;" . $removeBtn->render();
+      $buttons .= $editBtn->render();
       $Tcat->td( $buttons );
       $Tcat->td_alignment("right");
     }
