@@ -3,15 +3,56 @@
 /* CATALYST Php  Source Code                                            */
 /* Copyright (C)2002 Catalyst IT Limited                                */
 /*                                                                      */
-/* Filename:    axyl-story-admin.php                                    */
+/* Filename:    axyl-news.php                                           */
 /* Author:      Paul Waite                                              */
 /* Date:        June 2004                                               */
 /* Description: Page where news stories are added/administered.         */
+/*              Also the RSS feed for Axyl news - mainly provided as    */
+/*              an example of how to use Axyl RSS classes.              */
 /*                                                                      */
 /************************************************************************/
 include_once("application.php");
 include_once("story-defs.php");
 
+// -----------------------------------------------------------------------
+// Is it an RSS Feed request?
+if (isset($rss) && $rss == "newsfeed") {
+  include_once("rss-defs.php");
+  $rss = new RSS2channel(
+              "Axyl News",
+              $RESPONSE->site_url . "/" . $RESPONSE->requested,
+              "Axyl Latest News"
+              );
+  $q = "SELECT * FROM ax_story s"
+     . " WHERE s.visible=TRUE"
+     . "   AND s.deleted=FALSE"
+     . "   AND s.story_date <= CURRENT_TIMESTAMP"
+     . "   AND (s.expiry_date IS NULL OR s.expiry_date > CURRENT_TIMESTAMP)"
+     . " ORDER BY story_date DESC"
+     ;
+  $stories = dbrecordset($q);
+  if ($fstories->hasdata) {
+    do {
+      $story_id = $stories->field("story_id");
+      $story = new story($story_id);
+      if ($story->valid) {
+        $rss_item = new RSS2item(
+                          $story->story_headline,
+                          $RESPONSE->site_url . "/" . $RESPONSE->requested . "?story_id=$story_id",
+                          ($story->precis != "") ? $story->precis : $story->make_precis()
+                          );
+        $rss_item->author = $story->story_author_name;
+        $rss->add_item($rss_item);
+      }
+    } while ($stories->get_next());
+  }
+  # Send the RSS XML
+  $RESPONSE->discard();
+  $RESPONSE->set_encoding("utf-8", "application/xml");
+  echo $rss->render();
+  exit;
+}
+
 // -----------------------------------------------------------------------
 // Define the webpage..
 // Usage: $RESPONSE->page(title, templatename, theme, stylesheet);
@@ -34,7 +75,7 @@ $NEWS_ARTICLE = "";
 if (!isset($story_id)) {
   if ($RESPONSE->microsite_detected != "") {
     $q  = "SELECT * FROM ax_microsite_story ms, ax_story s, ax_story_location sl, ax_content_location l";
-    $q .= " WHERE ms.microsite_name='" . addslashes($RESPONSE->microsite_detected) . "'";
+    $q .= " WHERE ms.microsite_name='" . escape_string($RESPONSE->microsite_detected) . "'";
     $q .= "   AND s.story_id=ms.story_id";
     $q .= "   AND s.visible=TRUE";
     $q .= "   AND s.deleted=FALSE";
@@ -158,7 +199,7 @@ if (isset($story_id) && is_numeric($story_id)) {
 // Top 10 or All articles list..
 if ($RESPONSE->microsite_detected != "") {
   $q  = "SELECT * FROM ax_microsite_story ms, ax_story s";
-  $q .= " WHERE ms.microsite_name='" . addslashes($RESPONSE->microsite_detected) . "'";
+  $q .= " WHERE ms.microsite_name='" . escape_string($RESPONSE->microsite_detected) . "'";
   $q .= "   AND s.story_id=ms.story_id";
   $q .= "   AND s.visible=TRUE";
   $q .= "   AND s.deleted=FALSE";
